@@ -27,14 +27,10 @@ import java.util.Map;
 
 public abstract class AuthConfigFactory {
 
-    public static final String DEFAULT_FACTORY_SECURITY_PROPERTY =
-            "authconfigprovider.factory";
-    public static final String GET_FACTORY_PERMISSION_NAME =
-            "getProperty.authconfigprovider.factory";
-    public static final String SET_FACTORY_PERMISSION_NAME =
-            "setProperty.authconfigprovider.factory";
-    public static final String PROVIDER_REGISTRATION_PERMISSION_NAME =
-            "setProperty.authconfigfactory.provider";
+    public static final String DEFAULT_FACTORY_SECURITY_PROPERTY = "authconfigprovider.factory";
+    public static final String GET_FACTORY_PERMISSION_NAME = "getProperty.authconfigprovider.factory";
+    public static final String SET_FACTORY_PERMISSION_NAME = "setProperty.authconfigprovider.factory";
+    public static final String PROVIDER_REGISTRATION_PERMISSION_NAME = "setProperty.authconfigfactory.provider";
 
     public static final SecurityPermission getFactorySecurityPermission =
             new SecurityPermission(GET_FACTORY_PERMISSION_NAME);
@@ -63,24 +59,23 @@ public abstract class AuthConfigFactory {
             if (factory == null) {
                 final String className = getFactoryClassName();
                 try {
-                    factory = AccessController.doPrivileged(
-                            (PrivilegedExceptionAction<AuthConfigFactory>) () -> {
-                                // Load this class with the same class loader as used for
-                                // this class. Note that the Thread context class loader
-                                // should not be used since that would trigger a memory leak
-                                // in container environments.
-                                if (className.equals("org.apache.catalina.authenticator.jaspic.AuthConfigFactoryImpl")) {
-                                    return new org.apache.catalina.authenticator.jaspic.AuthConfigFactoryImpl();
-                                } else {
-                                    Class<?> clazz = Class.forName(className);
-                                    return (AuthConfigFactory) clazz.getConstructor().newInstance();
-                                }
-                            });
+                    factory = AccessController.doPrivileged((PrivilegedExceptionAction<AuthConfigFactory>) () -> {
+                        // Load this class with the same class loader as used for
+                        // this class. Note that the Thread context class loader
+                        // should not be used since that would trigger a memory leak
+                        // in container environments.
+                        if (className.equals("org.apache.catalina.authenticator.jaspic.AuthConfigFactoryImpl")) {
+                            return new org.apache.catalina.authenticator.jaspic.AuthConfigFactoryImpl();
+                        } else {
+                            Class<?> clazz = Class.forName(className);
+                            return (AuthConfigFactory) clazz.getConstructor().newInstance();
+                        }
+                    });
                 } catch (PrivilegedActionException e) {
                     Exception inner = e.getException();
                     if (inner instanceof InstantiationException) {
-                        throw new SecurityException("AuthConfigFactory error:" +
-                                inner.getCause().getMessage(), inner.getCause());
+                        throw new SecurityException("AuthConfigFactory error:" + inner.getCause().getMessage(),
+                                inner.getCause());
                     } else {
                         throw new SecurityException("AuthConfigFactory error: " + inner, inner);
                     }
@@ -100,16 +95,15 @@ public abstract class AuthConfigFactory {
             RegistrationListener listener);
 
     @SuppressWarnings("rawtypes") // JASPIC API uses raw types
-    public abstract String registerConfigProvider(String className, Map properties, String layer,
-            String appContext, String description);
+    public abstract String registerConfigProvider(String className, Map properties, String layer, String appContext,
+            String description);
 
-    public abstract String registerConfigProvider(AuthConfigProvider provider, String layer,
-            String appContext, String description);
+    public abstract String registerConfigProvider(AuthConfigProvider provider, String layer, String appContext,
+            String description);
 
     public abstract boolean removeRegistration(String registrationID);
 
-    public abstract String[] detachListener(RegistrationListener listener, String layer,
-            String appContext);
+    public abstract String[] detachListener(RegistrationListener listener, String layer, String appContext);
 
     public abstract String[] getRegistrationIDs(AuthConfigProvider provider);
 
@@ -125,8 +119,8 @@ public abstract class AuthConfigFactory {
     }
 
     private static String getFactoryClassName() {
-        String className = AccessController.doPrivileged(
-                (PrivilegedAction<String>) () -> Security.getProperty(DEFAULT_FACTORY_SECURITY_PROPERTY));
+        String className = AccessController
+                .doPrivileged((PrivilegedAction<String>) () -> Security.getProperty(DEFAULT_FACTORY_SECURITY_PROPERTY));
 
         if (className != null) {
             return className;
@@ -135,7 +129,7 @@ public abstract class AuthConfigFactory {
         return DEFAULT_JASPI_AUTHCONFIGFACTORYIMPL;
     }
 
-    public static interface RegistrationContext {
+    public interface RegistrationContext {
 
         String getMessageLayer();
 
