@@ -19,32 +19,28 @@ package javax.servlet.http;
 import java.util.EventListener;
 
 /**
- * Objects that are bound to a session may listen to container events notifying
- * them that sessions will be passivated and that session will be activated. A
- * container that migrates session between VMs or persists sessions is required
- * to notify all attributes bound to sessions implementing
- * HttpSessionActivationListener.
+ * Objects that are bound to a session may listen to container events notifying them that sessions will be passivated
+ * and that session will be activated. A container that migrates session between VMs or persists sessions is required to
+ * notify all attributes bound to sessions implementing HttpSessionActivationListener.
  *
  * @since Servlet 2.3
  */
 public interface HttpSessionActivationListener extends EventListener {
 
     /**
-     * Notification that the session is about to be passivated.
-     * The default implementation is a NO-OP.
+     * Notification that the session is about to be passivated. The default implementation is a NO-OP.
      *
      * @param se Information about the session this is about to be passivated
      */
-    public default void sessionWillPassivate(HttpSessionEvent se) {
+    default void sessionWillPassivate(HttpSessionEvent se) {
     }
 
     /**
-     * Notification that the session has just been activated.
-     * The default implementation is a NO-OP.
+     * Notification that the session has just been activated. The default implementation is a NO-OP.
      *
      * @param se Information about the session this has just been activated
      */
-    public default void sessionDidActivate(HttpSessionEvent se) {
+    default void sessionDidActivate(HttpSessionEvent se) {
     }
 }
 
