@@ -32,10 +32,10 @@ import org.apache.tools.ant.BuildException;
  * <li>Create remote Mbeans with different classloader</li>
  * </ul>
  * <p>
- * Examples:
- * <br>
+ * Examples: <br>
  * create a new Mbean at jmx.server connection
  * </p>
+ *
  * <pre>
  *   &lt;jmx:create
  *           ref="jmx.server"
@@ -46,15 +46,16 @@ import org.apache.tools.ant.BuildException;
  *   &lt;/jmxCreate/&gt;
  * </pre>
  * <p>
- * <b>WARNING</b>Not all Tomcat MBeans can create remotely and autoregister by its parents!
- * Please, use the MBeanFactory operation to generate valves and realms.
+ * <b>WARNING</b>Not all Tomcat MBeans can create remotely and auto register by its parents! Please, use the MBeanFactory
+ * operation to generate valves and realms.
  * </p>
  * <p>
- * First call to a remote MBeanserver save the JMXConnection a reference <em>jmx.server</em>
+ * First call to a remote MBean server save the JMXConnection a reference <em>jmx.server</em>
  * </p>
  * These tasks require Ant 1.6 or later interface.
  *
  * @author Peter Rossbach
+ *
  * @since 5.5.12
  */
 public class JMXAccessorCreateTask extends JMXAccessorTask {
@@ -62,7 +63,7 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
 
     private String className;
     private String classLoader;
-    private List<Arg> args=new ArrayList<>();
+    private List<Arg> args = new ArrayList<>();
 
     // ------------------------------------------------------------- Properties
 
@@ -94,7 +95,7 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
         this.className = className;
     }
 
-    public void addArg(Arg arg ) {
+    public void addArg(Arg arg) {
         args.add(arg);
     }
 
@@ -104,6 +105,7 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
     public List<Arg> getArgs() {
         return args;
     }
+
     /**
      * @param args The args to set.
      */
@@ -114,15 +116,13 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
     // ------------------------------------------------------ protected Methods
 
     @Override
-    public String jmxExecute(MBeanServerConnection jmxServerConnection)
-        throws Exception {
+    public String jmxExecute(MBeanServerConnection jmxServerConnection) throws Exception {
 
         if (getName() == null) {
             throw new BuildException("Must specify a 'name'");
         }
         if ((className == null)) {
-            throw new BuildException(
-                    "Must specify a 'className' for get");
+            throw new BuildException("Must specify a 'className' for get");
         }
         jmxCreate(jmxServerConnection, getName());
         return null;
@@ -132,25 +132,25 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
      * Create new MBean from ClassLoader identified by an ObjectName.
      *
      * @param jmxServerConnection Connection to the JMX server
-     * @param name MBean name
+     * @param name                MBean name
+     *
      * @throws Exception Error creating MBean
      */
-    protected void jmxCreate(MBeanServerConnection jmxServerConnection,
-            String name) throws Exception {
-        Object argsA[] = null;
-        String sigA[] = null;
+    protected void jmxCreate(MBeanServerConnection jmxServerConnection, String name) throws Exception {
+        Object[] argsA = null;
+        String[] sigA = null;
         if (args != null) {
-            argsA = new Object[ args.size()];
+            argsA = new Object[args.size()];
             sigA = new String[args.size()];
-            for( int i=0; i<args.size(); i++ ) {
-                Arg arg=args.get(i);
+            for (int i = 0; i < args.size(); i++) {
+                Arg arg = args.get(i);
                 if (arg.getType() == null) {
                     arg.setType("java.lang.String");
-                    sigA[i]=arg.getType();
-                    argsA[i]=arg.getValue();
+                    sigA[i] = arg.getType();
+                    argsA[i] = arg.getValue();
                 } else {
-                    sigA[i]=arg.getType();
-                    argsA[i]=convertStringToType(arg.getValue(),arg.getType());
+                    sigA[i] = arg.getType();
+                    argsA[i] = convertStringToType(arg.getValue(), arg.getType());
                 }
             }
         }
@@ -158,20 +158,21 @@ public class JMXAccessorCreateTask extends JMXAccessorTask {
             if (isEcho()) {
                 handleOutput("create MBean " + name + " from class " + className + " with classLoader " + classLoader);
             }
-            if(args == null) {
+            if (args == null) {
                 jmxServerConnection.createMBean(className, new ObjectName(name), new ObjectName(classLoader));
             } else {
-                jmxServerConnection.createMBean(className, new ObjectName(name), new ObjectName(classLoader),argsA,sigA);
+                jmxServerConnection.createMBean(className, new ObjectName(name), new ObjectName(classLoader), argsA,
+                        sigA);
             }
 
         } else {
             if (isEcho()) {
                 handleOutput("create MBean " + name + " from class " + className);
             }
-            if(args == null) {
+            if (args == null) {
                 jmxServerConnection.createMBean(className, new ObjectName(name));
             } else {
-                jmxServerConnection.createMBean(className, new ObjectName(name),argsA,sigA);
+                jmxServerConnection.createMBean(className, new ObjectName(name), argsA, sigA);
             }
         }
     }
