@@ -29,6 +29,7 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
 
+import org.apache.catalina.Globals;
 import org.apache.catalina.Realm;
 import org.apache.catalina.Session;
 import org.apache.catalina.connector.Request;
@@ -80,7 +81,7 @@ public class FormAuthenticator extends AuthenticatorBase {
     // ------------------------------------------------------------- Properties
 
     /**
-     * Return the character encoding to use to read the user name and password.
+     * Return the character encoding to use to read the username and password.
      *
      * @return The name of the character encoding
      */
@@ -90,7 +91,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
 
     /**
-     * Set the character encoding to be used to read the user name and password.
+     * Set the character encoding to be used to read the username and password.
      *
      * @param encoding The name of the encoding to use
      */
@@ -135,7 +136,7 @@ public class FormAuthenticator extends AuthenticatorBase {
      * Configures the maximum session timeout to be used during authentication if the authentication process creates a
      * session.
      *
-     * @param authenticationSessionTimeout The maximum session timeout to use duriing authentication if the
+     * @param authenticationSessionTimeout The maximum session timeout to use during authentication if the
      *                                         authentication process creates a session
      */
     public void setAuthenticationSessionTimeout(int authenticationSessionTimeout) {
@@ -160,7 +161,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
         // References to objects we will need later
         Session session = null;
-        Principal principal = null;
+        Principal principal;
 
         // Have we authenticated this user before but have caching disabled?
         if (!cache) {
@@ -226,9 +227,9 @@ public class FormAuthenticator extends AuthenticatorBase {
         // No -- Save this request and redirect to the form login page
         if (!loginAction) {
             // If this request was to the root of the context without a trailing
-            // '/', need to redirect to add it else the submit of the login form
+            // '/', need to redirect to add it else the submission of the login form
             // may not go to the correct web application
-            if (request.getServletPath().length() == 0 && request.getPathInfo() == null) {
+            if (request.getServletPath().isEmpty() && request.getPathInfo() == null) {
                 StringBuilder location = new StringBuilder(requestURI);
                 location.append('/');
                 if (request.getQueryString() != null) {
@@ -368,9 +369,7 @@ public class FormAuthenticator extends AuthenticatorBase {
         Session session = request.getSessionInternal(false);
         if (session != null) {
             SavedRequest savedRequest = (SavedRequest) session.getNote(Constants.FORM_REQUEST_NOTE);
-            if (savedRequest != null && decodedRequestURI.equals(savedRequest.getDecodedRequestURI())) {
-                return true;
-            }
+            return savedRequest != null && decodedRequestURI.equals(savedRequest.getDecodedRequestURI());
         }
 
         return false;
@@ -428,7 +427,7 @@ public class FormAuthenticator extends AuthenticatorBase {
         }
 
         String loginPage = config.getLoginPage();
-        if (loginPage == null || loginPage.length() == 0) {
+        if (loginPage == null || loginPage.isEmpty()) {
             String msg = sm.getString("formAuthenticator.noLoginPage", context.getName());
             log.warn(msg);
             response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, msg);
@@ -484,7 +483,7 @@ public class FormAuthenticator extends AuthenticatorBase {
             throws IOException {
 
         String errorPage = config.getErrorPage();
-        if (errorPage == null || errorPage.length() == 0) {
+        if (errorPage == null || errorPage.isEmpty()) {
             String msg = sm.getString("formAuthenticator.noErrorPage", context.getName());
             log.warn(msg);
             response.sendError(HttpServletResponse.SC_INTERNAL_SERVER_ERROR, msg);
@@ -509,7 +508,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
     /**
      * Does this request match the saved one (so that it must be the redirect we signaled after successful
-     * authentication?
+     * authentication?)
      *
      * @param request The request to be verified
      *
@@ -626,7 +625,7 @@ public class FormAuthenticator extends AuthenticatorBase {
             // If no content type specified, use default for POST
             String savedContentType = saved.getContentType();
             if (savedContentType == null && "POST".equalsIgnoreCase(method)) {
-                savedContentType = "application/x-www-form-urlencoded";
+                savedContentType = Globals.CONTENT_TYPE_FORM_URL_ENCODING;
             }
 
             contentType.setString(savedContentType);
@@ -641,14 +640,14 @@ public class FormAuthenticator extends AuthenticatorBase {
         // HttpInputBuffer. Processing the saved request body will overwrite
         // these bytes. Configuring the HttpInputBuffer to retain these bytes as
         // it would in a normal request would require some invasive API changes.
-        // Therefore force the conversion to String now so the correct values
+        // Therefore, force the conversion to String now so the correct values
         // are presented if the application requests them.
         request.getCoyoteRequest().requestURI().toStringType();
         request.getCoyoteRequest().queryString().toStringType();
         request.getCoyoteRequest().protocol().toStringType();
 
-        if (saved.getOriginalMaxInactiveInterval() > 0) {
-            session.setMaxInactiveInterval(saved.getOriginalMaxInactiveInterval());
+        if (saved.getOriginalMaxInactiveIntervalOptional() != null) {
+            session.setMaxInactiveInterval(saved.getOriginalMaxInactiveIntervalOptional().intValue());
         }
 
         return true;
@@ -667,7 +666,7 @@ public class FormAuthenticator extends AuthenticatorBase {
 
         // Create and populate a SavedRequest object for this request
         SavedRequest saved = new SavedRequest();
-        Cookie cookies[] = request.getCookies();
+        Cookie[] cookies = request.getCookies();
         if (cookies != null) {
             for (Cookie cookie : cookies) {
                 saved.addCookie(cookie);
@@ -720,17 +719,19 @@ public class FormAuthenticator extends AuthenticatorBase {
         if (session instanceof HttpSession) {
             if (((HttpSession) session).isNew()) {
                 int originalMaxInactiveInterval = session.getMaxInactiveInterval();
-                if (originalMaxInactiveInterval > getAuthenticationSessionTimeout()) {
+                if (originalMaxInactiveInterval > getAuthenticationSessionTimeout() || originalMaxInactiveInterval <= 0) {
                     saved.setOriginalMaxInactiveInterval(originalMaxInactiveInterval);
                     session.setMaxInactiveInterval(getAuthenticationSessionTimeout());
                 }
-            } else if (previousSavedRequest != null && previousSavedRequest.getOriginalMaxInactiveInterval() > 0) {
+            } else if (previousSavedRequest != null &&
+                    previousSavedRequest.getOriginalMaxInactiveIntervalOptional() != null) {
                 /*
-                 * The user may have refreshed the browser page during authentication. Transfer the original max
-                 * inactive interval from previous saved request to current one else, once authentication is completed,
-                 * the session will retain the the shorter authentication session timeout
+                 * The user may have refreshed the browser page during authentication. Transfer the original max inactive
+                 * interval from previous saved request to current one else, once authentication is completed, the session
+                 * will retain the shorter authentication session timeout
                  */
-                saved.setOriginalMaxInactiveInterval(previousSavedRequest.getOriginalMaxInactiveInterval());
+                saved.setOriginalMaxInactiveInterval(
+                        previousSavedRequest.getOriginalMaxInactiveIntervalOptional().intValue());
             }
         }
 
