@@ -30,13 +30,11 @@ import javax.servlet.http.Cookie;
 import org.apache.tomcat.util.buf.ByteChunk;
 
 /**
- * Object that saves the critical information from a request so that
- * form-based authentication can reproduce it once the user has been
- * authenticated.
+ * Object that saves the critical information from a request so that form-based authentication can reproduce it once the
+ * user has been authenticated.
  * <p>
- * <b>IMPLEMENTATION NOTE</b> - It is assumed that this object is accessed
- * only from the context of a single thread, so no synchronization around
- * internal collection classes is performed.
+ * <b>IMPLEMENTATION NOTE</b> - It is assumed that this object is accessed only from the context of a single thread, so
+ * no synchronization around internal collection classes is performed.
  *
  * @author Craig R. McClanahan
  */
@@ -59,12 +57,10 @@ public final class SavedRequest implements Serializable {
 
 
     /**
-     * The set of Headers associated with this Request.  Each key is a header
-     * name, while the value is a List containing one or more actual
-     * values for this header.  The values are returned as an Iterator when
-     * you ask for them.
+     * The set of Headers associated with this Request. Each key is a header name, while the value is a List containing
+     * one or more actual values for this header. The values are returned as an Iterator when you ask for them.
      */
-    private final Map<String, List<String>> headers = new HashMap<>();
+    private final Map<String,List<String>> headers = new HashMap<>();
 
     public void addHeader(String name, String value) {
         headers.computeIfAbsent(name, k -> new ArrayList<>()).add(value);
@@ -141,8 +137,7 @@ public final class SavedRequest implements Serializable {
 
 
     /**
-     * The decode request URI associated with this Request. Path parameters are
-     * also excluded
+     * The decode request URI associated with this Request. Path parameters are also excluded
      */
     private String decodedRequestURI = null;
 
@@ -168,6 +163,7 @@ public final class SavedRequest implements Serializable {
         this.body = body;
     }
 
+
     /**
      * The content type of the request, used if this is a POST.
      */
@@ -180,4 +176,31 @@ public final class SavedRequest implements Serializable {
     public void setContentType(String contentType) {
         this.contentType = contentType;
     }
+
+
+    /**
+     * The original maxInactiveInterval for the session.
+     */
+    private Integer originalMaxInactiveInterval = null;
+
+    public Integer getOriginalMaxInactiveIntervalOptional() {
+        return originalMaxInactiveInterval;
+    }
+
+    /**
+     * Obtain the original session maxInactiveInterval.
+     *
+     * @return the original session maxInactiveInterval
+     *
+     * @deprecated This method will be removed in Tomcat 12.0.x onwards. Use
+     *                 {@link SavedRequest#getOriginalMaxInactiveIntervalOptional()}
+     */
+    @Deprecated
+    public int getOriginalMaxInactiveInterval() {
+        return (originalMaxInactiveInterval == null) ? -1 : originalMaxInactiveInterval.intValue();
+    }
+
+    public void setOriginalMaxInactiveInterval(int originalMaxInactiveInterval) {
+        this.originalMaxInactiveInterval = Integer.valueOf(originalMaxInactiveInterval);
+    }
 }
