@@ -62,7 +62,7 @@ public final class ApplicationFilterFactory {
         }
 
         // Create and initialize a filter chain object
-        ApplicationFilterChain filterChain = null;
+        ApplicationFilterChain filterChain;
         if (request instanceof Request) {
             Request req = (Request) request;
             if (Globals.IS_SECURITY_ENABLED) {
@@ -95,7 +95,7 @@ public final class ApplicationFilterFactory {
         // Acquire the information we will need to match filter mappings
         DispatcherType dispatcher = (DispatcherType) request.getAttribute(Globals.DISPATCHER_TYPE_ATTR);
 
-        String requestPath = FilterUtil.getRequestPath(request) ;
+        String requestPath = FilterUtil.getRequestPath(request);
 
         String servletName = wrapper.getName();
 
