@@ -74,7 +74,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
     /**
      * The set of attribute names that are special for request dispatchers.
      */
-    protected static final String specials[] =
+    protected static final String[] specials =
             { RequestDispatcher.INCLUDE_REQUEST_URI, RequestDispatcher.INCLUDE_CONTEXT_PATH,
                     RequestDispatcher.INCLUDE_SERVLET_PATH, RequestDispatcher.INCLUDE_PATH_INFO,
                     RequestDispatcher.INCLUDE_QUERY_STRING, RequestDispatcher.INCLUDE_MAPPING,
@@ -93,7 +93,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
     }
 
     private static final int shortestSpecialNameLength =
-            specialsMap.keySet().stream().mapToInt(s -> s.length()).min().getAsInt();
+            specialsMap.keySet().stream().mapToInt(String::length).min().getAsInt();
 
 
     private static final int SPECIALS_FIRST_FORWARD_INDEX = 6;
@@ -189,6 +189,11 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
     protected final Object[] specialAttributes = new Object[specials.length];
 
 
+    /*
+     * Used to speed up getAttribute(). See that method for details.
+     */
+    private ApplicationHttpRequest wrappedApplicationHttpRequest;
+
     /**
      * Construct a new wrapped request around the specified servlet request.
      *
@@ -235,7 +240,17 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
         int pos = getSpecial(name);
         if (pos == -1) {
-            return getRequest().getAttribute(name);
+            /*
+             * With nested includes there will be nested ApplicationHttpRequests. The calls to getSpecial() are
+             * relatively expensive and it is known at this point that the attribute is not special. Therefore, jump to
+             * the first wrapped request that isn't an instance of ApplicationHttpRequest before calling getAttribute()
+             * to avoid a call to getSpecial() for each nested ApplicationHttpRequest.
+             */
+            ApplicationHttpRequest request = this;
+            while (request.wrappedApplicationHttpRequest != null) {
+                request = request.wrappedApplicationHttpRequest;
+            }
+            return request.getRequest().getAttribute(name);
         } else {
             if ((specialAttributes[pos] == null) && (specialAttributes[SPECIALS_FIRST_FORWARD_INDEX] == null) &&
                     (pos >= SPECIALS_FIRST_FORWARD_INDEX)) {
@@ -331,7 +346,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
         // Add the path info, if there is any
         String pathInfo = getPathInfo();
-        String requestPath = null;
+        String requestPath;
 
         if (pathInfo == null) {
             requestPath = servletPath;
@@ -340,7 +355,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
         }
 
         int pos = requestPath.lastIndexOf('/');
-        String relative = null;
+        String relative;
         if (context.getDispatchersUseEncodedPaths()) {
             if (pos >= 0) {
                 relative = URLEncoder.DEFAULT.encode(requestPath.substring(0, pos + 1), StandardCharsets.UTF_8) + path;
@@ -584,11 +599,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
             } catch (IOException e) {
                 // Ignore
             }
-            if ((session != null) && session.isValid()) {
-                return true;
-            } else {
-                return false;
-            }
+            return (session != null) && session.isValid();
 
         } else {
             return super.isRequestedSessionIdValid();
@@ -666,6 +677,13 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
 
         super.setRequest(request);
 
+        // Type specific version of the wrapped request to speed up getAttribute()
+        if (request instanceof ApplicationHttpRequest) {
+            wrappedApplicationHttpRequest = (ApplicationHttpRequest) request;
+        } else {
+            wrappedApplicationHttpRequest = null;
+        }
+
         // Initialize the attributes for this request
         dispatcherType = (DispatcherType) request.getAttribute(Globals.DISPATCHER_TYPE_ATTR);
         requestDispatcherPath = request.getAttribute(Globals.DISPATCHER_REQUEST_PATH_ATTR);
@@ -710,7 +728,12 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
             return;
         }
 
-        parameters = new ParameterMap<>(getRequest().getParameterMap());
+        Map<String,String[]> requestParameters = getRequest().getParameterMap();
+        if (requestParameters instanceof ParameterMap<?,?>) {
+            parameters = new ParameterMap<>((ParameterMap<String,String[]>) requestParameters);
+        } else {
+            parameters = new ParameterMap<>(requestParameters);
+        }
         mergeParameters();
         ((ParameterMap<String,String[]>) parameters).setLocked(true);
         parsedParams = true;
@@ -803,17 +826,13 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      */
     private String[] mergeValues(String[] values1, String[] values2) {
 
-        List<Object> results = new ArrayList<>();
+        List<String> results = new ArrayList<>();
 
-        if (values1 == null) {
-            // Skip - nothing to merge
-        } else {
+        if (values1 != null) {
             results.addAll(Arrays.asList(values1));
         }
 
-        if (values2 == null) {
-            // Skip - nothing to merge
-        } else {
+        if (values2 != null) {
             results.addAll(Arrays.asList(values2));
         }
 
@@ -830,7 +849,7 @@ class ApplicationHttpRequest extends HttpServletRequestWrapper {
      */
     private void mergeParameters() {
 
-        if ((queryParamString == null) || (queryParamString.length() < 1)) {
+        if ((queryParamString == null) || (queryParamString.isEmpty())) {
             return;
         }
 
