@@ -165,10 +165,10 @@ import org.apache.tomcat.util.buf.StringUtils;
  * <h4>
  * {@code ExpiresExcludedResponseStatusCodes}</h4>
  * <p>
- * This directive defines the http response status codes for which the
+ * This directive defines the HTTP response status codes for which the
  * {@code ExpiresFilter} will not generate expiration headers. By default, the
  * {@code 304} status code (&quot;{@code Not modified}&quot;) is skipped. The
- * value is a comma separated list of http status codes.
+ * value is a comma separated list of HTTP status codes.
  * </p>
  * <p>
  * This directive is useful to ease usage of {@code ExpiresDefault} directive.
@@ -332,7 +332,7 @@ import org.apache.tomcat.util.buf.StringUtils;
  * </p>
  * <p>
  * To trap the &#x27;before write response body&#x27; event, the
- * {@code ExpiresFilter} wraps the http servlet response&#x27;s writer and
+ * {@code ExpiresFilter} wraps the HTTP servlet response&#x27;s writer and
  * outputStream to intercept calls to the methods {@code write()},
  * {@code print()}, {@code close()} and {@code flush()}. For empty response
  * body (e.g. empty files), the {@code write()}, {@code print()},
@@ -445,7 +445,7 @@ public class ExpiresFilter extends FilterBase {
     /**
      * Duration unit
      */
-    protected enum DurationUnit {
+    public enum DurationUnit {
         DAY(Calendar.DAY_OF_YEAR),
         HOUR(Calendar.HOUR),
         MINUTE(Calendar.MINUTE),
@@ -510,14 +510,14 @@ public class ExpiresFilter extends FilterBase {
      * ({@link StartingPoint#ACCESS_TIME}) or the last time the HTML-page/servlet-response was modified (
      * {@link StartingPoint#LAST_MODIFICATION_TIME}).
      */
-    protected enum StartingPoint {
+   public enum StartingPoint {
         ACCESS_TIME,
         LAST_MODIFICATION_TIME
     }
 
     /**
      * <p>
-     * Wrapping extension of the {@link HttpServletResponse} to yrap the "Start Write Response Body" event.
+     * Wrapping extension of the {@link HttpServletResponse} to wrap the "Start Write Response Body" event.
      * </p>
      * <p>
      * For performance optimization : this extended response holds the {@link #lastModifiedHeader} and
@@ -528,12 +528,12 @@ public class ExpiresFilter extends FilterBase {
     public class XHttpServletResponse extends HttpServletResponseWrapper {
 
         /**
-         * Value of the {@code Cache-Control} http response header if it has been set.
+         * Value of the {@code Cache-Control} HTTP response header if it has been set.
          */
         private String cacheControlHeader;
 
         /**
-         * Value of the {@code Last-Modified} http response header if it has been set.
+         * Value of the {@code Last-Modified} HTTP response header if it has been set.
          */
         private long lastModifiedHeader;
 
@@ -568,8 +568,12 @@ public class ExpiresFilter extends FilterBase {
         @Override
         public void addHeader(String name, String value) {
             super.addHeader(name, value);
-            if (HEADER_CACHE_CONTROL.equalsIgnoreCase(name) && cacheControlHeader == null) {
-                cacheControlHeader = value;
+            if (HEADER_CACHE_CONTROL.equalsIgnoreCase(name)) {
+                if (cacheControlHeader == null) {
+                    cacheControlHeader = value;
+                } else {
+                    cacheControlHeader = StringUtils.join(cacheControlHeader, value);
+                }
             }
         }
 
@@ -1027,7 +1031,7 @@ public class ExpiresFilter extends FilterBase {
     private static final String PARAMETER_EXPIRES_EXCLUDED_RESPONSE_STATUS_CODES = "ExpiresExcludedResponseStatusCodes";
 
     /**
-     * Convert a comma delimited list of numbers into an {@code int[]}.
+     * Convert a comma-delimited list of numbers into an {@code int[]}.
      *
      * @param commaDelimitedInts can be {@code null}
      *
@@ -1076,7 +1080,7 @@ public class ExpiresFilter extends FilterBase {
     }
 
     /**
-     * Convert an array of ints into a comma delimited string
+     * Convert an array of ints into a comma-delimited string
      *
      * @param ints The int array
      *
@@ -1104,7 +1108,7 @@ public class ExpiresFilter extends FilterBase {
      * @return {@code true} if the given {@code str} is {@code null} or has a zero characters length.
      */
     protected static boolean isEmpty(String str) {
-        return str == null || str.length() == 0;
+        return str == null || str.isEmpty();
     }
 
     /**
@@ -1389,8 +1393,7 @@ public class ExpiresFilter extends FilterBase {
                     ExpiresConfiguration expiresConfiguration = parseExpiresConfiguration(value);
                     this.expiresConfigurationByContentType.put(contentType, expiresConfiguration);
                 } else if (name.equalsIgnoreCase(PARAMETER_EXPIRES_DEFAULT)) {
-                    ExpiresConfiguration expiresConfiguration = parseExpiresConfiguration(value);
-                    this.defaultExpiresConfiguration = expiresConfiguration;
+                    this.defaultExpiresConfiguration = parseExpiresConfiguration(value);
                 } else if (name.equalsIgnoreCase(PARAMETER_EXPIRES_EXCLUDED_RESPONSE_STATUS_CODES)) {
                     this.excludedResponseStatusCodes = commaDelimitedListToIntArray(value);
                 } else {
@@ -1418,9 +1421,17 @@ public class ExpiresFilter extends FilterBase {
      */
     protected boolean isEligibleToExpirationHeaderGeneration(HttpServletRequest request,
             XHttpServletResponse response) {
-        boolean expirationHeaderHasBeenSet =
-                response.containsHeader(HEADER_EXPIRES) || contains(response.getCacheControlHeader(), "max-age");
-        if (expirationHeaderHasBeenSet) {
+
+        // Don't add cache headers unless the request is a GET or a HEAD request
+        String method = request.getMethod();
+        if (!"GET".equals(method) && !"HEAD".equals(method)) {
+            if (log.isDebugEnabled()) {
+                log.debug(sm.getString("expiresFilter.invalidMethod", request.getRequestURI(), method));
+            }
+            return false;
+        }
+
+        if (response.containsHeader(HEADER_EXPIRES) || contains(response.getCacheControlHeader(), "max-age")) {
             if (log.isDebugEnabled()) {
                 log.debug(sm.getString("expiresFilter.expirationHeaderAlreadyDefined", request.getRequestURI(),
                         Integer.valueOf(response.getStatus()), response.getContentType()));
@@ -1428,6 +1439,14 @@ public class ExpiresFilter extends FilterBase {
             return false;
         }
 
+        if (contains(response.getCacheControlHeader(), "no-store")) {
+            if (log.isDebugEnabled()) {
+                log.debug(sm.getString("expiresFilter.cacheControlNoStore", request.getRequestURI(),
+                        Integer.valueOf(response.getStatus()), response.getContentType()));
+            }
+            return false;
+        }
+
         for (int skippedStatusCode : this.excludedResponseStatusCodes) {
             if (response.getStatus() == skippedStatusCode) {
                 if (log.isDebugEnabled()) {
