@@ -75,7 +75,7 @@ import org.apache.tomcat.util.res.StringManager;
  * proxies:
  * </p>
  * <ul>
- * <li>Loop on the comma delimited list of IPs and hostnames passed by the preceding load balancer or proxy in the given
+ * <li>Loop on the comma-delimited list of IPs and hostnames passed by the preceding load balancer or proxy in the given
  * request's Http header named <code>$remoteIpHeader</code> (default value <code>x-forwarded-for</code>). Values are
  * processed in right-to-left order.</li>
  * <li>For each ip/host of the list:
@@ -151,7 +151,7 @@ import org.apache.tomcat.util.res.StringManager;
  * </tr>
  * <tr>
  * <td>protocolHeaderHttpsValue</td>
- * <td>Value of the <code>protocolHeader</code> to indicate that it is an Https request</td>
+ * <td>Value of the <code>protocolHeader</code> to indicate that it is a Https request</td>
  * <td>N/A</td>
  * <td>String like <code>https</code> or <code>ON</code></td>
  * <td><code>https</code></td>
@@ -194,7 +194,7 @@ import org.apache.tomcat.util.res.StringManager;
  * <p>
  * XForwardedFilter configuration:
  * </p>
- * <code>
+ * <pre>
  * &lt;filter&gt;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;filter-class&gt;org.apache.catalina.filters.RemoteIpFilter&lt;/filter-class&gt;
@@ -220,7 +220,7 @@ import org.apache.tomcat.util.res.StringManager;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;url-pattern&gt;/*&lt;/url-pattern&gt;
  *    &lt;dispatcher&gt;REQUEST&lt;/dispatcher&gt;
- * &lt;/filter-mapping&gt;</code>
+ * &lt;/filter-mapping&gt;</pre>
  * <table border="1">
  * <caption>Request Values</caption>
  * <tr>
@@ -273,7 +273,7 @@ import org.apache.tomcat.util.res.StringManager;
  * <p>
  * RemoteIpFilter configuration:
  * </p>
- * <code>
+ * <pre>
  * &lt;filter&gt;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;filter-class&gt;org.apache.catalina.filters.RemoteIpFilter&lt;/filter-class&gt;
@@ -299,7 +299,7 @@ import org.apache.tomcat.util.res.StringManager;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;url-pattern&gt;/*&lt;/url-pattern&gt;
  *    &lt;dispatcher&gt;REQUEST&lt;/dispatcher&gt;
- * &lt;/filter-mapping&gt;</code>
+ * &lt;/filter-mapping&gt;</pre>
  * <table border="1">
  * <caption>Request Values</caption>
  * <tr>
@@ -335,7 +335,7 @@ import org.apache.tomcat.util.res.StringManager;
  * <p>
  * RemoteIpFilter configuration:
  * </p>
- * <code>
+ * <pre>
  * &lt;filter&gt;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;filter-class&gt;org.apache.catalina.filters.RemoteIpFilter&lt;/filter-class&gt;
@@ -361,7 +361,7 @@ import org.apache.tomcat.util.res.StringManager;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;url-pattern&gt;/*&lt;/url-pattern&gt;
  *    &lt;dispatcher&gt;REQUEST&lt;/dispatcher&gt;
- * &lt;/filter-mapping&gt;</code>
+ * &lt;/filter-mapping&gt;</pre>
  * <table border="1">
  * <caption>Request Values</caption>
  * <tr>
@@ -398,7 +398,7 @@ import org.apache.tomcat.util.res.StringManager;
  * <p>
  * RemoteIpFilter configuration:
  * </p>
- * <code>
+ * <pre>
  * &lt;filter&gt;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;filter-class&gt;org.apache.catalina.filters.RemoteIpFilter&lt;/filter-class&gt;
@@ -424,7 +424,7 @@ import org.apache.tomcat.util.res.StringManager;
  *    &lt;filter-name&gt;RemoteIpFilter&lt;/filter-name&gt;
  *    &lt;url-pattern&gt;/*&lt;/url-pattern&gt;
  *    &lt;dispatcher&gt;REQUEST&lt;/dispatcher&gt;
- * &lt;/filter-mapping&gt;</code>
+ * &lt;/filter-mapping&gt;</pre>
  * <table border="1">
  * <caption>Request Values</caption>
  * <tr>
@@ -538,7 +538,7 @@ public class RemoteIpFilter extends GenericFilter {
         public Enumeration<String> getHeaders(String name) {
             Map.Entry<String,List<String>> header = getHeaderEntry(name);
             if (header == null || header.getValue() == null) {
-                return Collections.enumeration(Collections.<String>emptyList());
+                return Collections.enumeration(Collections.emptyList());
             }
             return Collections.enumeration(header.getValue());
         }
@@ -748,7 +748,8 @@ public class RemoteIpFilter extends GenericFilter {
                     "100\\.6[4-9]{1}\\.\\d{1,3}\\.\\d{1,3}|" + "100\\.[7-9]{1}\\d{1}\\.\\d{1,3}\\.\\d{1,3}|" +
                     "100\\.1[0-1]{1}\\d{1}\\.\\d{1,3}\\.\\d{1,3}|" + "100\\.12[0-7]{1}\\.\\d{1,3}\\.\\d{1,3}|" +
                     "172\\.1[6-9]{1}\\.\\d{1,3}\\.\\d{1,3}|" + "172\\.2[0-9]{1}\\.\\d{1,3}\\.\\d{1,3}|" +
-                    "172\\.3[0-1]{1}\\.\\d{1,3}\\.\\d{1,3}|" + "0:0:0:0:0:0:0:1|::1");
+                    "172\\.3[0-1]{1}\\.\\d{1,3}\\.\\d{1,3}|" + "0:0:0:0:0:0:0:1|::1|" +
+                    "fe[89ab]\\p{XDigit}:.*|" + "f[cd]\\p{XDigit}{2}+:.*");
 
     /**
      * @see #setProtocolHeader(String)
@@ -851,13 +852,13 @@ public class RemoteIpFilter extends GenericFilter {
                     xRequest.setRemoteHost(remoteIp);
                 }
 
-                if (proxiesHeaderValue.size() == 0) {
+                if (proxiesHeaderValue.isEmpty()) {
                     xRequest.removeHeader(proxiesHeader);
                 } else {
                     String commaDelimitedListOfProxies = StringUtils.join(proxiesHeaderValue);
                     xRequest.setHeader(proxiesHeader, commaDelimitedListOfProxies);
                 }
-                if (newRemoteIpHeaderValue.size() == 0) {
+                if (newRemoteIpHeaderValue.isEmpty()) {
                     xRequest.removeHeader(remoteIpHeader);
                 } else {
                     String commaDelimitedRemoteIpHeaderValue = StringUtils.join(newRemoteIpHeaderValue);
@@ -1174,7 +1175,7 @@ public class RemoteIpFilter extends GenericFilter {
      * @param internalProxies The regexp
      */
     public void setInternalProxies(String internalProxies) {
-        if (internalProxies == null || internalProxies.length() == 0) {
+        if (internalProxies == null || internalProxies.isEmpty()) {
             this.internalProxies = null;
         } else {
             this.internalProxies = Pattern.compile(internalProxies);
@@ -1227,7 +1228,7 @@ public class RemoteIpFilter extends GenericFilter {
 
     /**
      * <p>
-     * Case insensitive value of the protocol header to indicate that the incoming http request uses HTTPS.
+     * Case-insensitive value of the protocol header to indicate that the incoming http request uses HTTPS.
      * </p>
      * <p>
      * Default value : <code>https</code>
@@ -1250,7 +1251,7 @@ public class RemoteIpFilter extends GenericFilter {
      * Name of the http header that holds the list of trusted proxies that has been traversed by the http request.
      * </p>
      * <p>
-     * The value of this header can be comma delimited.
+     * The value of this header can be comma-delimited.
      * </p>
      * <p>
      * Default value : <code>X-Forwarded-By</code>
@@ -1267,7 +1268,7 @@ public class RemoteIpFilter extends GenericFilter {
      * Name of the http header from which the remote ip is extracted.
      * </p>
      * <p>
-     * The value of this header can be comma delimited.
+     * The value of this header can be comma-delimited.
      * </p>
      * <p>
      * Default value : <code>X-Forwarded-For</code>
@@ -1280,7 +1281,7 @@ public class RemoteIpFilter extends GenericFilter {
     }
 
     /**
-     * Should this filter set request attributes for IP address, Hostname, protocol and port used for the request? This
+     * Should this filter set request attributes for IP address, Hostname, protocol and port used for the request? These
      * are typically used in conjunction with an {@link AccessLog} which will otherwise log the original values. Default
      * is <code>true</code>. The attributes set are:
      * <ul>
@@ -1309,7 +1310,7 @@ public class RemoteIpFilter extends GenericFilter {
      * @param trustedProxies The trusted proxies regexp
      */
     public void setTrustedProxies(String trustedProxies) {
-        if (trustedProxies == null || trustedProxies.length() == 0) {
+        if (trustedProxies == null || trustedProxies.isEmpty()) {
             this.trustedProxies = null;
         } else {
             this.trustedProxies = Pattern.compile(trustedProxies);
