@@ -855,7 +855,7 @@ public class DeltaManager extends ClusterManagerBase {
      */
     protected Member findSessionMasterMember() {
         Member mbr = null;
-        Member mbrs[] = cluster.getMembers();
+        Member[] mbrs = cluster.getMembers();
         if (mbrs.length != 0) {
             mbr = mbrs[0];
         }
@@ -896,6 +896,7 @@ public class DeltaManager extends ClusterManagerBase {
                     try {
                         Thread.sleep(100);
                     } catch (Exception sleep) {
+                        // Ignore
                     }
                 } while ((!getStateTransferred()) && (!isNoContextManagerReceived()));
                 reqNow = System.currentTimeMillis();
@@ -938,7 +939,7 @@ public class DeltaManager extends ClusterManagerBase {
         if (log.isInfoEnabled()) {
             log.info(sm.getString("deltaManager.expireSessions", getName()));
         }
-        Session sessions[] = findSessions();
+        Session[] sessions = findSessions();
         for (Session value : sessions) {
             DeltaSession session = (DeltaSession) value;
             if (!session.isValid()) {
@@ -1002,7 +1003,7 @@ public class DeltaManager extends ClusterManagerBase {
      * @return a SessionMessage to be sent,
      */
     public ClusterMessage requestCompleted(String sessionId, boolean expires) {
-        DeltaSession session = null;
+        DeltaSession session;
         SessionMessage msg = null;
         try {
             session = (DeltaSession) findSession(sessionId);
@@ -1123,7 +1124,7 @@ public class DeltaManager extends ClusterManagerBase {
      * Expire all find sessions.
      */
     public void expireAllLocalSessions() {
-        Session sessions[] = findSessions();
+        Session[] sessions = findSessions();
         int expireDirect = 0;
         int expireIndirect = 0;
 
@@ -1285,7 +1286,7 @@ public class DeltaManager extends ClusterManagerBase {
     }
 
     /**
-     * handle receive session is expire at other node ( expire session also here)
+     * handle receive session is expired at other node ( expire session also here)
      *
      * @param msg    Session message
      * @param sender Member which sent the message
@@ -1385,6 +1386,7 @@ public class DeltaManager extends ClusterManagerBase {
                     try {
                         Thread.sleep(getSendAllSessionsWaitTime());
                     } catch (Exception sleep) {
+                        // Ignore
                     }
                 }
             }
