@@ -30,7 +30,6 @@ import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.Engine;
 import org.apache.catalina.Host;
-import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleState;
 import org.apache.catalina.Manager;
@@ -58,17 +57,14 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * A <b>Cluster </b> implementation using simple multicast. Responsible for
- * setting up a cluster and provides callers with a valid multicast
- * receiver/sender.
- *
- * FIXME wrote testcases
+ * A <b>Cluster </b> implementation using simple multicast. Responsible for setting up a cluster and provides callers
+ * with a valid multicast receiver/sender.
  *
  * @author Remy Maucherat
  * @author Peter Rossbach
  */
 public class SimpleTcpCluster extends LifecycleMBeanBase
-        implements CatalinaCluster, MembershipListener, ChannelListener{
+        implements CatalinaCluster, MembershipListener, ChannelListener {
 
     public static final Log log = LogFactory.getLog(SimpleTcpCluster.class);
 
@@ -108,13 +104,14 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     /**
      * The cluster name to join
      */
-    protected String clusterName ;
+    protected String clusterName;
 
     /**
      * call Channel.heartbeat() at container background thread
+     *
      * @see org.apache.catalina.tribes.group.GroupChannel#heartbeat()
      */
-    protected boolean heartbeatBackgroundEnabled =false ;
+    protected boolean heartbeatBackgroundEnabled = false;
 
     /**
      * The Container associated with this Cluster.
@@ -129,7 +126,7 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     /**
      * The context name &lt;-&gt; manager association for distributed contexts.
      */
-    protected final Map<String, ClusterManager> managers = new HashMap<>();
+    protected final Map<String,ClusterManager> managers = new HashMap<>();
 
     protected ClusterManager managerTemplate = new DeltaManager();
 
@@ -162,6 +159,7 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     /**
      * Return heartbeat enable flag (default false)
+     *
      * @return the heartbeatBackgroundEnabled
      */
     public boolean isHeartbeatBackgroundEnabled() {
@@ -170,44 +168,26 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     /**
      * enabled that container backgroundThread call heartbeat at channel
+     *
      * @param heartbeatBackgroundEnabled the heartbeatBackgroundEnabled to set
      */
     public void setHeartbeatBackgroundEnabled(boolean heartbeatBackgroundEnabled) {
         this.heartbeatBackgroundEnabled = heartbeatBackgroundEnabled;
     }
 
-    /**
-     * Set the name of the cluster to join, if no cluster with this name is
-     * present create one.
-     *
-     * @param clusterName
-     *            The clustername to join
-     */
     @Override
     public void setClusterName(String clusterName) {
         this.clusterName = clusterName;
     }
 
-    /**
-     * Return the name of the cluster that this Server is currently configured
-     * to operate within.
-     *
-     * @return The name of the cluster associated with this server
-     */
     @Override
     public String getClusterName() {
-        if(clusterName == null && container != null) {
-            return container.getName() ;
+        if (clusterName == null && container != null) {
+            return container.getName();
         }
         return clusterName;
     }
 
-    /**
-     * Set the Container associated with our Cluster
-     *
-     * @param container
-     *            The Container to use
-     */
     @Override
     public void setContainer(Container container) {
         Container oldContainer = this.container;
@@ -215,11 +195,6 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         support.firePropertyChange("container", oldContainer, this.container);
     }
 
-    /**
-     * Get the Container associated with our Cluster
-     *
-     * @return The Container associated with our Cluster
-     */
     @Override
     public Container getContainer() {
         return this.container;
@@ -233,23 +208,15 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     }
 
     /**
-     * @param notifyListenerOnFailure
-     *            The notifyLifecycleListenerOnFailure to set.
+     * @param notifyListenerOnFailure The notifyLifecycleListenerOnFailure to set.
      */
-    public void setNotifyLifecycleListenerOnFailure(
-            boolean notifyListenerOnFailure) {
+    public void setNotifyLifecycleListenerOnFailure(boolean notifyListenerOnFailure) {
         boolean oldNotifyListenerOnFailure = this.notifyLifecycleListenerOnFailure;
         this.notifyLifecycleListenerOnFailure = notifyListenerOnFailure;
-        support.firePropertyChange("notifyLifecycleListenerOnFailure",
-                oldNotifyListenerOnFailure,
+        support.firePropertyChange("notifyLifecycleListenerOnFailure", oldNotifyListenerOnFailure,
                 this.notifyLifecycleListenerOnFailure);
     }
 
-    /**
-     * Add cluster valve
-     * Cluster Valves are only add to container when cluster is started!
-     * @param valve The new cluster Valve.
-     */
     @Override
     public void addValve(Valve valve) {
         if (valve instanceof ClusterValve && (!valves.contains(valve))) {
@@ -257,30 +224,21 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         }
     }
 
-    /**
-     * get all cluster valves
-     * @return current cluster valves
-     */
     @Override
     public Valve[] getValves() {
         return valves.toArray(new Valve[0]);
     }
 
     /**
-     * Get the cluster listeners associated with this cluster. If this Array has
-     * no listeners registered, a zero-length array is returned.
+     * Get the cluster listeners associated with this cluster. If this Array has no listeners registered, a zero-length
+     * array is returned.
+     *
      * @return the listener array
      */
     public ClusterListener[] findClusterListeners() {
         return clusterListeners.toArray(new ClusterListener[0]);
     }
 
-    /**
-     * Add cluster message listener and register cluster to this listener.
-     *
-     * @param listener The new listener
-     * @see org.apache.catalina.ha.CatalinaCluster#addClusterListener(org.apache.catalina.ha.ClusterListener)
-     */
     @Override
     public void addClusterListener(ClusterListener listener) {
         if (listener != null && !clusterListeners.contains(listener)) {
@@ -289,12 +247,6 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         }
     }
 
-    /**
-     * Remove message listener and deregister Cluster from listener.
-     *
-     * @param listener The listener to remove
-     * @see org.apache.catalina.ha.CatalinaCluster#removeClusterListener(org.apache.catalina.ha.ClusterListener)
-     */
     @Override
     public void removeClusterListener(ClusterListener listener) {
         if (listener != null) {
@@ -303,18 +255,11 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         }
     }
 
-    /**
-     * @return the current Deployer
-     */
     @Override
     public ClusterDeployer getClusterDeployer() {
         return clusterDeployer;
     }
 
-    /**
-     * set a new Deployer, must be set before cluster started!
-     * @param clusterDeployer The associated deployer
-     */
     @Override
     public void setClusterDeployer(ClusterDeployer clusterDeployer) {
         this.clusterDeployer = clusterDeployer;
@@ -345,25 +290,17 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
      * has members
      */
     protected boolean hasMembers = false;
+
     @Override
     public boolean hasMembers() {
         return hasMembers;
     }
 
-    /**
-     * Get all current cluster members
-     * @return all members or empty array
-     */
     @Override
     public Member[] getMembers() {
         return channel.getMembers();
     }
 
-    /**
-     * Return the member that represents this node.
-     *
-     * @return Member
-     */
     @Override
     public Member getLocalMember() {
         return channel.getLocalMember(true);
@@ -372,11 +309,8 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     // --------------------------------------------------------- Public Methods
 
-    /**
-     * @return Returns the managers.
-     */
     @Override
-    public Map<String, ClusterManager> getManagers() {
+    public Map<String,ClusterManager> getManagers() {
         return managers;
     }
 
@@ -395,25 +329,17 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     /**
      * returns the SendOptions as a comma separated list of names for use by JMX
+     *
      * @return a comma separated list of the option names
      */
-    public String getChannelSendOptionsName(){
+    public String getChannelSendOptionsName() {
         return Channel.getSendOptionsAsString(channelSendOptions);
     }
 
-    /**
-     * Create new Manager without add to cluster (comes with start the manager)
-     *
-     * @param name
-     *            Context Name of this manager
-     * @see org.apache.catalina.Cluster#createManager(java.lang.String)
-     * @see DeltaManager#start()
-     */
     @Override
     public synchronized Manager createManager(String name) {
         if (log.isDebugEnabled()) {
-            log.debug("Creating ClusterManager for context " + name +
-                    " using class " + getManagerTemplate().getClass().getName());
+            log.debug(sm.getString("simpleTcpCluster.createManager", name, getManagerTemplate().getClass().getName()));
         }
         ClusterManager manager = null;
         try {
@@ -421,9 +347,9 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
             manager.setName(name);
         } catch (Exception x) {
             log.error(sm.getString("simpleTcpCluster.clustermanager.cloneFailed"), x);
-            manager = new org.apache.catalina.ha.session.DeltaManager();
+            manager = new DeltaManager();
         } finally {
-            if ( manager != null) {
+            if (manager != null) {
                 manager.setCluster(this);
             }
         }
@@ -433,7 +359,7 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     @Override
     public void registerManager(Manager manager) {
 
-        if (! (manager instanceof ClusterManager)) {
+        if (!(manager instanceof ClusterManager)) {
             log.warn(sm.getString("simpleTcpCluster.clustermanager.notImplement", manager));
             return;
         }
@@ -449,19 +375,13 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         fireLifecycleEvent(AFTER_MANAGERREGISTER_EVENT, manager);
     }
 
-    /**
-     * Remove an application from cluster replication bus.
-     *
-     * @param manager The manager
-     * @see org.apache.catalina.Cluster#removeManager(Manager)
-     */
     @Override
     public void removeManager(Manager manager) {
         if (manager instanceof ClusterManager) {
             ClusterManager cmgr = (ClusterManager) manager;
             // Notify our interested LifecycleListeners
-            fireLifecycleEvent(BEFORE_MANAGERUNREGISTER_EVENT,manager);
-            managers.remove(getManagerName(cmgr.getName(),manager));
+            fireLifecycleEvent(BEFORE_MANAGERUNREGISTER_EVENT, manager);
+            managers.remove(getManagerName(cmgr.getName(), manager));
             cmgr.setCluster(null);
             // Notify our interested LifecycleListeners
             fireLifecycleEvent(AFTER_MANAGERUNREGISTER_EVENT, manager);
@@ -470,16 +390,15 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     @Override
     public String getManagerName(String name, Manager manager) {
-        String clusterName = name ;
+        String clusterName = name;
         if (clusterName == null) {
             clusterName = manager.getContext().getName();
         }
         if (getContainer() instanceof Engine) {
             Context context = manager.getContext();
             Container host = context.getParent();
-            if (host instanceof Host && clusterName != null &&
-                    !(clusterName.startsWith(host.getName() +"#"))) {
-                clusterName = host.getName() +"#" + clusterName ;
+            if (host instanceof Host && clusterName != null && !(clusterName.startsWith(host.getName() + "#"))) {
+                clusterName = host.getName() + "#" + clusterName;
             }
         }
         return clusterName;
@@ -492,27 +411,19 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     // ------------------------------------------------------ Lifecycle Methods
 
-    /**
-     * Execute a periodic task, such as reloading, etc. This method will be
-     * invoked inside the classloading context of this container. Unexpected
-     * throwables will be caught and logged.
-     * @see org.apache.catalina.ha.deploy.FarmWarDeployer#backgroundProcess()
-     * @see org.apache.catalina.tribes.group.GroupChannel#heartbeat()
-     *
-     */
     @Override
     public void backgroundProcess() {
         if (clusterDeployer != null) {
             clusterDeployer.backgroundProcess();
         }
 
-        //send a heartbeat through the channel
-        if ( isHeartbeatBackgroundEnabled() && channel !=null ) {
+        // send a heartbeat through the channel
+        if (isHeartbeatBackgroundEnabled() && channel != null) {
             channel.heartbeat();
         }
 
         // periodic event
-        fireLifecycleEvent(Lifecycle.PERIODIC_EVENT, null);
+        fireLifecycleEvent(PERIODIC_EVENT, null);
     }
 
 
@@ -530,16 +441,14 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
             name.append(",component=Deployer");
             onameClusterDeployer = register(clusterDeployer, name.toString());
         }
-        channel.setUtilityExecutor(Container.getService(getContainer()).getServer().getUtilityExecutor());
     }
 
 
     /**
-     * Start Cluster and implement the requirements
-     * of {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
+     * Start Cluster and implement the requirements of {@link org.apache.catalina.util.LifecycleBase#startInternal()}.
      *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
+     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
+     *                                   used
      */
     @Override
     protected void startInternal() throws LifecycleException {
@@ -548,6 +457,8 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
             log.info(sm.getString("simpleTcpCluster.start"));
         }
 
+        channel.setUtilityExecutor(Container.getService(getContainer()).getServer().getUtilityExecutor());
+
         try {
             checkDefaults();
             registerClusterValve();
@@ -568,20 +479,20 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     }
 
     protected void checkDefaults() {
-        if ( clusterListeners.size() == 0 && managerTemplate instanceof DeltaManager ) {
+        if (clusterListeners.isEmpty() && managerTemplate instanceof DeltaManager) {
             addClusterListener(new ClusterSessionListener());
         }
-        if ( valves.size() == 0 ) {
+        if (valves.isEmpty()) {
             addValve(new JvmRouteBinderValve());
             addValve(new ReplicationValve());
         }
-        if ( clusterDeployer != null ) {
+        if (clusterDeployer != null) {
             clusterDeployer.setCluster(this);
         }
-        if ( channel == null ) {
+        if (channel == null) {
             channel = new GroupChannel();
         }
-        if ( channel instanceof GroupChannel && !((GroupChannel)channel).getInterceptors().hasNext()) {
+        if (channel instanceof GroupChannel && !((GroupChannel) channel).getInterceptors().hasNext()) {
             channel.addInterceptor(new MessageDispatchInterceptor());
             channel.addInterceptor(new TcpFailureDetector());
         }
@@ -594,12 +505,11 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
      * register all cluster valve to host or engine
      */
     protected void registerClusterValve() {
-        if(container != null ) {
+        if (container != null) {
             for (Valve v : valves) {
                 ClusterValve valve = (ClusterValve) v;
-                if (log.isDebugEnabled()) {
-                    log.debug("Invoking addValve on " + getContainer()
-                            + " with class=" + valve.getClass().getName());
+                if (log.isTraceEnabled()) {
+                    log.trace("Invoking addValve on " + getContainer() + " with class=" + valve.getClass().getName());
                 }
                 if (valve != null) {
                     container.getPipeline().addValve(valve);
@@ -615,9 +525,8 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     protected void unregisterClusterValve() {
         for (Valve v : valves) {
             ClusterValve valve = (ClusterValve) v;
-            if (log.isDebugEnabled()) {
-                log.debug("Invoking removeValve on " + getContainer()
-                        + " with class=" + valve.getClass().getName());
+            if (log.isTraceEnabled()) {
+                log.trace("Invoking removeValve on " + getContainer() + " with class=" + valve.getClass().getName());
             }
             if (valve != null) {
                 container.getPipeline().removeValve(valve);
@@ -628,11 +537,10 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
 
     /**
-     * Stop Cluster and implement the requirements
-     * of {@link org.apache.catalina.util.LifecycleBase#stopInternal()}.
+     * Stop Cluster and implement the requirements of {@link org.apache.catalina.util.LifecycleBase#stopInternal()}.
      *
-     * @exception LifecycleException if this component detects a fatal error
-     *  that prevents this component from being used
+     * @exception LifecycleException if this component detects a fatal error that prevents this component from being
+     *                                   used
      */
     @Override
     protected void stopInternal() throws LifecycleException {
@@ -645,7 +553,7 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         }
         this.managers.clear();
         try {
-            if ( clusterDeployer != null ) {
+            if (clusterDeployer != null) {
                 clusterDeployer.setCluster(null);
             }
             channel.stop(channelStartOptions);
@@ -655,6 +563,8 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         } catch (Exception x) {
             log.error(sm.getString("simpleTcpCluster.stopUnable"), x);
         }
+
+        channel.setUtilityExecutor(null);
     }
 
 
@@ -668,34 +578,17 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     }
 
 
-    /**
-     * Return a String rendering of this object.
-     */
     @Override
     public String toString() {
         return ToStringUtil.toString(this);
     }
 
 
-    /**
-     * send message to all cluster members
-     * @param msg message to transfer
-     *
-     * @see org.apache.catalina.ha.CatalinaCluster#send(org.apache.catalina.ha.ClusterMessage)
-     */
     @Override
     public void send(ClusterMessage msg) {
         send(msg, null);
     }
 
-    /**
-     * send a cluster message to one member
-     *
-     * @param msg message to transfer
-     * @param dest Receiver member
-     * @see org.apache.catalina.ha.CatalinaCluster#send(org.apache.catalina.ha.ClusterMessage,
-     *      org.apache.catalina.tribes.Member)
-     */
     @Override
     public void send(ClusterMessage msg, Member dest) {
         send(msg, dest, this.channelSendOptions);
@@ -707,16 +600,16 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
             msg.setAddress(getLocalMember());
             if (dest != null) {
                 if (!getLocalMember().equals(dest)) {
-                    channel.send(new Member[] {dest}, msg, sendOptions);
+                    channel.send(new Member[] { dest }, msg, sendOptions);
                 } else {
                     log.error(sm.getString("simpleTcpCluster.unableSend.localMember", msg));
                 }
             } else {
                 Member[] destmembers = channel.getMembers();
-                if (destmembers.length>0) {
-                    channel.send(destmembers,msg, sendOptions);
+                if (destmembers.length > 0) {
+                    channel.send(destmembers, msg, sendOptions);
                 } else if (log.isDebugEnabled()) {
-                    log.debug("No members in cluster, ignoring message:"+msg);
+                    log.debug(sm.getString("simpleTcpCluster.noMembers", msg));
                 }
             }
         } catch (Exception x) {
@@ -724,11 +617,6 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
         }
     }
 
-    /**
-     * New cluster member is registered
-     *
-     * @see org.apache.catalina.tribes.MembershipListener#memberAdded(org.apache.catalina.tribes.Member)
-     */
     @Override
     public void memberAdded(Member member) {
         try {
@@ -749,11 +637,6 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     }
 
-    /**
-     * Cluster member is gone
-     *
-     * @see org.apache.catalina.tribes.MembershipListener#memberDisappeared(org.apache.catalina.tribes.Member)
-     */
     @Override
     public void memberDisappeared(Member member) {
         try {
@@ -777,11 +660,9 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
     // messages
 
     /**
-     * notify all listeners from receiving a new message is not ClusterMessage
-     * emit Failure Event to LifecycleListener
+     * notify all listeners from receiving a new message is not ClusterMessage emit Failure Event to LifecycleListener
      *
-     * @param msg
-     *            received Message
+     * @param msg received Message
      */
     @Override
     public boolean accept(Serializable msg, Member sender) {
@@ -791,21 +672,19 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
 
     @Override
     public void messageReceived(Serializable message, Member sender) {
-        ClusterMessage fwd = (ClusterMessage)message;
+        ClusterMessage fwd = (ClusterMessage) message;
         fwd.setAddress(sender);
         messageReceived(fwd);
     }
 
     public void messageReceived(ClusterMessage message) {
 
-        if (log.isDebugEnabled() && message != null) {
-            log.debug("Assuming clocks are synched: Replication for "
-                    + message.getUniqueId() + " took="
-                    + (System.currentTimeMillis() - (message).getTimestamp())
-                    + " ms.");
+        if (log.isTraceEnabled() && message != null) {
+            log.trace("Assuming clocks are synched: Replication for " + message.getUniqueId() + " took=" +
+                    (System.currentTimeMillis() - (message).getTimestamp()) + " ms.");
         }
 
-        //invoke all the listeners
+        // invoke all the listeners
         boolean accepted = false;
         if (message != null) {
             for (ClusterListener listener : clusterListeners) {
@@ -817,12 +696,9 @@ public class SimpleTcpCluster extends LifecycleMBeanBase
             if (!accepted && notifyLifecycleListenerOnFailure) {
                 Member dest = message.getAddress();
                 // Notify our interested LifecycleListeners
-                fireLifecycleEvent(RECEIVE_MESSAGE_FAILURE_EVENT,
-                        new SendMessageData(message, dest, null));
+                fireLifecycleEvent(RECEIVE_MESSAGE_FAILURE_EVENT, new SendMessageData(message, dest, null));
                 if (log.isDebugEnabled()) {
-                    log.debug("Message " + message.toString() + " from type "
-                            + message.getClass().getName()
-                            + " transferred but no listener registered");
+                    log.debug(sm.getString("simpleTcpCluster.noListener", message, message.getClass().getName()));
                 }
             }
         }
