@@ -17,6 +17,7 @@
 package org.apache.catalina.loader;
 
 import java.io.File;
+import java.io.FileNotFoundException;
 import java.io.FilePermission;
 import java.io.IOException;
 import java.io.InputStream;
@@ -73,6 +74,8 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.InstrumentableClassLoader;
 import org.apache.tomcat.util.ExceptionUtils;
 import org.apache.tomcat.util.IntrospectionUtils;
+import org.apache.tomcat.util.buf.ToStringUtil;
+import org.apache.tomcat.util.collections.ConcurrentLruCache;
 import org.apache.tomcat.util.compat.JreCompat;
 import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.security.PermissionCheck;
@@ -382,14 +385,31 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
     /**
      * Repositories managed by this class rather than the super class.
      */
-    private List<URL> localRepositories = new ArrayList<>();
+    private final List<URL> localRepositories = new ArrayList<>();
 
 
     private volatile LifecycleState state = LifecycleState.NEW;
 
+    /*
+     * Class resources are not cached since they are loaded on first use and the resource is then no longer required. It
+     * does help, however, to cache classes that are not found as in some scenarios the same class will be searched for
+     * many times and the greater the number of JARs/classes, the longer that lookup will take.
+     */
+    private final ConcurrentLruCache<String> notFoundClassResources = new ConcurrentLruCache<>(1000);
+
 
     // ------------------------------------------------------------- Properties
 
+    public void setNotFoundClassResourceCacheSize(int notFoundClassResourceCacheSize) {
+        notFoundClassResources.setLimit(notFoundClassResourceCacheSize);
+    }
+
+
+    public int getNotFoundClassResourceCacheSize() {
+        return notFoundClassResources.getLimit();
+    }
+
+
     /**
      * Unused. Always returns {@code null}.
      *
@@ -729,7 +749,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             sb.append(this.parent.toString());
             sb.append("\r\n");
         }
-        if (this.transformers.size() > 0) {
+        if (!this.transformers.isEmpty()) {
             sb.append("----------> Class file transformers:\r\n");
             for (ClassFileTransformer transformer : this.transformers) {
                 sb.append(transformer).append("\r\n");
@@ -764,6 +784,12 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
 
         checkStateForClassLoading(name);
 
+        if (name == null) {
+            throw new ClassNotFoundException("null");
+        }
+
+        String path = binaryNameToPath(name, true);
+
         // (1) Permission to define this class when using a SecurityManager
         if (securityManager != null) {
             int i = name.lastIndexOf('.');
@@ -789,25 +815,14 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             if (log.isTraceEnabled()) {
                 log.trace("      findClassInternal(" + name + ")");
             }
-            try {
-                if (securityManager != null) {
-                    PrivilegedAction<Class<?>> dp = new PrivilegedFindClassByName(name);
-                    clazz = AccessController.doPrivileged(dp);
-                } else {
-                    clazz = findClassInternal(name);
-                }
-            } catch (AccessControlException ace) {
-                log.warn(sm.getString("webappClassLoader.securityException", name, ace.getMessage()), ace);
-                throw new ClassNotFoundException(name, ace);
-            } catch (RuntimeException e) {
-                if (log.isTraceEnabled()) {
-                    log.trace("      -->RuntimeException Rethrown", e);
-                }
-                throw e;
-            }
-            if (clazz == null && hasExternalRepositories) {
+            if (!notFoundClassResources.contains(path)) {
                 try {
-                    clazz = super.findClass(name);
+                    if (securityManager != null) {
+                        PrivilegedAction<Class<?>> dp = new PrivilegedFindClassByName(name);
+                        clazz = AccessController.doPrivileged(dp);
+                    } else {
+                        clazz = findClassInternal(name);
+                    }
                 } catch (AccessControlException ace) {
                     log.warn(sm.getString("webappClassLoader.securityException", name, ace.getMessage()), ace);
                     throw new ClassNotFoundException(name, ace);
@@ -817,19 +832,34 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
                     }
                     throw e;
                 }
-            }
-            if (clazz == null) {
-                if (log.isTraceEnabled()) {
-                    log.trace("    --> Returning ClassNotFoundException");
+                if (clazz == null && hasExternalRepositories) {
+                    try {
+                        clazz = super.findClass(name);
+                    } catch (AccessControlException ace) {
+                        log.warn(sm.getString("webappClassLoader.securityException", name, ace.getMessage()), ace);
+                        throw new ClassNotFoundException(name, ace);
+                    } catch (RuntimeException e) {
+                        if (log.isTraceEnabled()) {
+                            log.trace("      -->RuntimeException Rethrown", e);
+                        }
+                        throw e;
+                    }
                 }
-                throw new ClassNotFoundException(name);
             }
         } catch (ClassNotFoundException e) {
             if (log.isTraceEnabled()) {
                 log.trace("    --> Passing on ClassNotFoundException");
             }
+            notFoundClassResources.add(path);
             throw e;
         }
+        if (clazz == null) {
+            if (log.isTraceEnabled()) {
+                log.trace("    --> Returning ClassNotFoundException");
+            }
+            notFoundClassResources.add(path);
+            throw new ClassNotFoundException(name);
+        }
 
         // Return the class we have located
         if (log.isTraceEnabled()) {
@@ -869,14 +899,21 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
 
         String path = nameToPath(name);
 
-        WebResource resource = resources.getClassLoaderResource(path);
-        if (resource.exists()) {
-            url = resource.getURL();
-            trackLastModified(path, resource);
-        }
+        if (!notFoundClassResources.contains(path)) {
+            WebResource resource = resources.getClassLoaderResource(path);
+            if (resource.exists()) {
+                url = resource.getURL();
+                trackLastModified(path, resource);
+            }
 
-        if (url == null && hasExternalRepositories) {
-            url = super.findResource(name);
+            if (url == null && hasExternalRepositories) {
+                url = super.findResource(name);
+            }
+
+            // Skip caching results for invalid names (it might mask lookups for valid ones)
+            if (url == null && !name.isEmpty() && name.charAt(0) != '/') {
+                notFoundClassResources.add(path);
+            }
         }
 
         if (log.isTraceEnabled()) {
@@ -959,7 +996,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
 
         checkStateForResourceLoading(name);
 
-        URL url = null;
+        URL url;
 
         boolean delegateFirst = delegate || filter(name, false);
 
@@ -1063,26 +1100,32 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             log.trace("  Searching local repositories");
         }
         String path = nameToPath(name);
-        WebResource resource = resources.getClassLoaderResource(path);
-        if (resource.exists()) {
-            stream = resource.getInputStream();
-            trackLastModified(path, resource);
-        }
-        try {
-            if (hasExternalRepositories && stream == null) {
-                URL url = super.findResource(name);
-                if (url != null) {
-                    stream = url.openStream();
+        if (!notFoundClassResources.contains(path)) {
+            WebResource resource = resources.getClassLoaderResource(path);
+            if (resource.exists()) {
+                stream = resource.getInputStream();
+                trackLastModified(path, resource);
+            }
+            try {
+                if (hasExternalRepositories && stream == null) {
+                    URL url = super.findResource(name);
+                    if (url != null) {
+                        stream = url.openStream();
+                    }
                 }
+            } catch (IOException e) {
+                // Ignore
             }
-        } catch (IOException e) {
-            // Ignore
-        }
-        if (stream != null) {
-            if (log.isTraceEnabled()) {
-                log.trace("  --> Returning stream from local");
+            if (stream != null) {
+                if (log.isTraceEnabled()) {
+                    log.trace("  --> Returning stream from local");
+                }
+                return stream;
+            }
+            // Skip caching results for invalid names (it might mask lookups for valid ones)
+            if (!name.isEmpty() && name.charAt(0) != '/') {
+                notFoundClassResources.add(path);
             }
-            return stream;
         }
 
         // (3) Delegate to parent unconditionally
@@ -1147,7 +1190,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             if (log.isTraceEnabled()) {
                 log.trace("loadClass(" + name + ", " + resolve + ")");
             }
-            Class<?> clazz = null;
+            Class<?> clazz;
 
             // Log access to stopped class loader
             checkStateForClassLoading(name);
@@ -1305,6 +1348,9 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             }
         }
 
+        if (log.isDebugEnabled()) {
+            log.debug(ToStringUtil.classPathForCNFE(this));
+        }
         throw new ClassNotFoundException(name);
     }
 
@@ -1465,6 +1511,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
         state = LifecycleState.STOPPING;
 
         resourceEntries.clear();
+        notFoundClassResources.clear();
         jarModificationTimes.clear();
         resources = null;
 
@@ -1578,6 +1625,9 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
         byte[] classBytes = new byte[2048];
         int offset = 0;
         try (InputStream is = getResourceAsStream("org/apache/catalina/loader/JdbcLeakPrevention.class")) {
+            if (is == null) {
+                throw new FileNotFoundException("org/apache/catalina/loader/JdbcLeakPrevention.class");
+            }
             int read = is.read(classBytes, offset, classBytes.length - offset);
             while (read > -1) {
                 offset += read;
@@ -1703,7 +1753,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
         // when the executor was shut down or the thread was interrupted but
         // that depends on the thread correctly handling the interrupt. Check
         // each thread and if any are still running give all threads up to a
-        // total of 2 seconds to shutdown.
+        // total of 2 seconds to shut down.
         int count = 0;
         for (Thread t : threadsToStop) {
             while (t.isAlive() && count < 100) {
@@ -1734,7 +1784,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
 
         StackTraceElement[] elements = thread.getStackTrace();
 
-        if (elements == null || elements.length == 0) {
+        if (elements.length == 0) {
             // Must have stopped already. Too late to ignore it. Assume not a
             // request processing thread.
             return false;
@@ -1979,7 +2029,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
     }
 
     /**
-     * @return the set of current threads as an array.
+     * @return the current threads as an array.
      */
     private Thread[] getThreads() {
         // Get the current thread group
@@ -2163,6 +2213,11 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
         }
         String path = binaryNameToPath(name, true);
 
+        return findClassInternal(name, path);
+    }
+
+
+    private Class<?> findClassInternal(String name, String path) {
         ResourceEntry entry = resourceEntries.get(path);
         WebResource resource = null;
 
@@ -2219,7 +2274,7 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
             URL codeBase = resource.getCodeBase();
             Certificate[] certificates = resource.getCertificates();
 
-            if (transformers.size() > 0) {
+            if (!transformers.isEmpty()) {
                 // If the resource is a class just being loaded, decorate it
                 // with any attached transformers
 
@@ -2484,6 +2539,8 @@ public abstract class WebappClassLoaderBase extends URLClassLoader
     protected void addURL(URL url) {
         super.addURL(url);
         hasExternalRepositories = true;
+        // Clear the not found resources as they may now be available at the added URL.
+        notFoundClassResources.clear();
     }
 
 
