@@ -68,8 +68,8 @@ public class JMXProxyServlet extends HttpServlet {
     @Override
     public void init() throws ServletException {
         // Retrieve the MBean server
-        registry = Registry.getRegistry(null, null);
-        mBeanServer = Registry.getRegistry(null, null).getMBeanServer();
+        registry = Registry.getRegistry(null);
+        mBeanServer = Registry.getRegistry(null).getMBeanServer();
     }
 
 
@@ -167,7 +167,7 @@ public class JMXProxyServlet extends HttpServlet {
 
     public void listBeans(PrintWriter writer, String qry) {
 
-        Set<ObjectName> names = null;
+        Set<ObjectName> names;
         try {
             names = mBeanServer.queryNames(new ObjectName(qry), null);
             writer.println("OK - Number of results: " + names.size());
@@ -258,7 +258,7 @@ public class JMXProxyServlet extends HttpServlet {
         MBeanOperationInfo methodInfo = registry.getMethodInfo(oname, operation, paramCount);
         if (null == methodInfo) {
             // getMethodInfo returns null for both "object not found" and "operation not found"
-            MBeanInfo info = null;
+            MBeanInfo info;
             try {
                 info = registry.getMBeanServer().getMBeanInfo(oname);
             } catch (InstanceNotFoundException infe) {
