@@ -245,7 +245,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
 
         // Retrieve the MBean server
-        mBeanServer = Registry.getRegistry(null, null).getMBeanServer();
+        mBeanServer = Registry.getRegistry(null).getMBeanServer();
 
     }
 
@@ -286,16 +286,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
         String type = request.getParameter("type");
         String tag = request.getParameter("tag");
-        boolean update = false;
-        if (request.getParameter("update") != null && request.getParameter("update").equals("true")) {
-            update = true;
-        }
+        boolean update = request.getParameter("update") != null && request.getParameter("update").equals("true");
         String tlsHostName = request.getParameter("tlsHostName");
 
-        boolean statusLine = false;
-        if ("true".equals(request.getParameter("statusLine"))) {
-            statusLine = true;
-        }
+        boolean statusLine = "true".equals(request.getParameter("statusLine"));
 
         // Prepare our output writer to generate the response message
         response.setContentType("text/plain; charset=" + Constants.CHARSET);
@@ -378,10 +372,8 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
         String config = request.getParameter("config");
         String tag = request.getParameter("tag");
-        boolean update = false;
-        if (request.getParameter("update") != null && request.getParameter("update").equals("true")) {
-            update = true;
-        }
+        boolean update = request.getParameter("update") != null
+            && request.getParameter("update").equals("true");
 
         // Prepare our output writer to generate the response message
         response.setContentType("text/plain;charset=" + Constants.CHARSET);
@@ -416,7 +408,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
         }
 
         // Set our properties from the initialization parameters
-        String value = null;
+        String value;
         try {
             value = getServletConfig().getInitParameter("debug");
             debug = Integer.parseInt(value);
@@ -501,21 +493,21 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
 
     protected void sslReload(PrintWriter writer, String tlsHostName, StringManager smClient) {
-        Connector connectors[] = getConnectors();
+        Connector[] connectors = getConnectors();
         boolean found = false;
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 ProtocolHandler protocol = connector.getProtocolHandler();
                 if (protocol instanceof AbstractHttp11Protocol<?>) {
                     AbstractHttp11Protocol<?> http11Protoocol = (AbstractHttp11Protocol<?>) protocol;
-                    if (tlsHostName == null || tlsHostName.length() == 0) {
+                    if (tlsHostName == null || tlsHostName.isEmpty()) {
                         found = true;
                         http11Protoocol.reloadSslHostConfigs();
                     } else {
                         SSLHostConfig[] sslHostConfigs = http11Protoocol.findSslHostConfigs();
                         for (SSLHostConfig sslHostConfig : sslHostConfigs) {
-                            // tlsHostName is as provided by the user so use a case insensitive
-                            // comparison as host names are case insensitive.
+                            // tlsHostName is as provided by the user so use a case-insensitive
+                            // comparison as host names are case-insensitive.
                             if (sslHostConfig.getHostName().equalsIgnoreCase(tlsHostName)) {
                                 found = true;
                                 http11Protoocol.reloadSslHostConfig(tlsHostName);
@@ -526,7 +518,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             }
         }
         if (found) {
-            if (tlsHostName == null || tlsHostName.length() == 0) {
+            if (tlsHostName == null || tlsHostName.isEmpty()) {
                 writer.println(smClient.getString("managerServlet.sslReloadAll"));
             } else {
                 writer.println(smClient.getString("managerServlet.sslReload", tlsHostName));
@@ -624,7 +616,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             return;
         }
 
-        if (path == null || path.length() == 0 || !path.startsWith("/")) {
+        if (path == null || !path.startsWith("/")) {
             try {
                 mBeanServer.invoke(storeConfigOname, "storeConfig", null, null);
                 writer.println(smClient.getString("managerServlet.saved"));
@@ -672,7 +664,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected void deploy(PrintWriter writer, String config, ContextName cn, String tag, boolean update,
             HttpServletRequest request, StringManager smClient) {
 
-        if (config != null && config.length() == 0) {
+        if (config != null && config.isEmpty()) {
             config = null;
         }
 
@@ -741,8 +733,9 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                             writer.println(smClient.getString("managerServlet.mkdirFail", configBase));
                             return;
                         }
-                        if (ExpandWar.copy(new File(config), new File(configBase, baseName + ".xml")) == false) {
-                            throw new Exception(sm.getString("managerServlet.copyError", config));
+                        if (!ExpandWar.copy(new File(config), new File(configBase, baseName + ".xml"))) {
+                            writer.println(smClient.getString("managerServlet.copyFail", new File(config), new File(configBase, baseName + ".xml")));
+                            return;
                         }
                     }
                     // Upload WAR
@@ -760,7 +753,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                     }
                     if (tag != null) {
                         // Copy WAR to the host's appBase
-                        ExpandWar.copy(uploadedWar, deployedWar);
+                        if (!ExpandWar.copy(uploadedWar, deployedWar)) {
+                            writer.println(smClient.getString("managerServlet.copyFail", uploadedWar, deployedWar));
+                            return;
+                        }
                     }
                 } finally {
                     removeServiced(name);
@@ -814,7 +810,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                         writer.println(smClient.getString("managerServlet.deleteFail", deployedWar));
                         return;
                     }
-                    ExpandWar.copy(localWar, deployedWar);
+                    if (!ExpandWar.copy(localWar, deployedWar)) {
+                        writer.println(smClient.getString("managerServlet.copyFail", localWar, deployedWar));
+                        return;
+                    }
                 } finally {
                     removeServiced(name);
                 }
@@ -846,10 +845,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected void deploy(PrintWriter writer, String config, ContextName cn, String war, boolean update,
             StringManager smClient) {
 
-        if (config != null && config.length() == 0) {
+        if (config != null && config.isEmpty()) {
             config = null;
         }
-        if (war != null && war.length() == 0) {
+        if (war != null && war.isEmpty()) {
             war = null;
         }
 
@@ -908,7 +907,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                                 writer.println(smClient.getString("managerServlet.deleteFail", localConfigFile));
                                 return;
                             }
-                            ExpandWar.copy(configFile, localConfigFile);
+                            if (!ExpandWar.copy(configFile, localConfigFile)) {
+                                writer.println(smClient.getString("managerServlet.copyFail", configFile, localConfigFile));
+                                return;
+                            }
                         }
                     }
                     if (war != null) {
@@ -928,7 +930,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
                                 writer.println(smClient.getString("managerServlet.deleteFail", localWarFile));
                                 return;
                             }
-                            ExpandWar.copy(warFile, localWarFile);
+                            if (!ExpandWar.copy(warFile, localWarFile)) {
+                                writer.println(smClient.getString("managerServlet.copyFail", warFile, localWarFile));
+                                return;
+                            }
                         }
                     }
                 } finally {
@@ -980,10 +985,10 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
             Context context = (Context) container;
             if (context != null) {
                 String displayPath = context.getPath();
-                if (displayPath.equals("")) {
+                if (displayPath.isEmpty()) {
                     displayPath = "/";
                 }
-                List<String> parts = null;
+                List<String> parts;
                 if (context.getState().isAvailable()) {
                     parts = Arrays.asList(displayPath, "running", "" + context.getManager().findSessions().length,
                             context.getDocBase());
@@ -1568,7 +1573,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
 
         // ContextName should be non-null with a path that is empty or starts
         // with /
-        if (cn != null && (cn.getPath().startsWith("/") || cn.getPath().equals(""))) {
+        if (cn != null && (cn.getPath().startsWith("/") || cn.getPath().isEmpty())) {
             return true;
         }
 
@@ -1583,7 +1588,7 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorCiphers(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector connectors[] = getConnectors();
+        Connector[] connectors = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
@@ -1606,37 +1611,29 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorCerts(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector connectors[] = getConnectors();
+        Connector[] connectors = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
                 for (SSLHostConfig sslHostConfig : sslHostConfigs) {
-                    if (sslHostConfig.getOpenSslContext().longValue() == 0) {
-                        // Not set. Must be JSSE based.
-                        Set<SSLHostConfigCertificate> sslHostConfigCerts = sslHostConfig.getCertificates();
-                        for (SSLHostConfigCertificate sslHostConfigCert : sslHostConfigCerts) {
-                            String name = connector.toString() + "-" + sslHostConfig.getHostName() + "-" +
-                                    sslHostConfigCert.getType();
-                            List<String> certList = new ArrayList<>();
-                            SSLContext sslContext = sslHostConfigCert.getSslContext();
-                            String alias = sslHostConfigCert.getCertificateKeyAlias();
-                            if (alias == null) {
-                                alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
-                            }
-                            X509Certificate[] certs = sslContext.getCertificateChain(alias);
-                            if (certs == null) {
-                                certList.add(smClient.getString("managerServlet.certsNotAvailable"));
-                            } else {
-                                for (Certificate cert : certs) {
-                                    certList.add(cert.toString());
-                                }
-                            }
-                            result.put(name, certList);
-                        }
-                    } else {
+                    Set<SSLHostConfigCertificate> sslHostConfigCerts = sslHostConfig.getCertificates();
+                    for (SSLHostConfigCertificate sslHostConfigCert : sslHostConfigCerts) {
+                        String name = connector.toString() + "-" + sslHostConfig.getHostName() + "-" +
+                                sslHostConfigCert.getType();
                         List<String> certList = new ArrayList<>();
-                        certList.add(smClient.getString("managerServlet.certsNotAvailable"));
-                        String name = connector.toString() + "-" + sslHostConfig.getHostName();
+                        SSLContext sslContext = sslHostConfigCert.getSslContext();
+                        String alias = sslHostConfigCert.getCertificateKeyAlias();
+                        if (alias == null) {
+                            alias = SSLUtilBase.DEFAULT_KEY_ALIAS;
+                        }
+                        X509Certificate[] certs = sslContext.getCertificateChain(alias);
+                        if (certs == null) {
+                            certList.add(smClient.getString("managerServlet.certsNotAvailable"));
+                        } else {
+                            for (Certificate cert : certs) {
+                                certList.add(cert.toString());
+                            }
+                        }
                         result.put(name, certList);
                     }
                 }
@@ -1654,28 +1651,23 @@ public class ManagerServlet extends HttpServlet implements ContainerServlet {
     protected Map<String,List<String>> getConnectorTrustedCerts(StringManager smClient) {
         Map<String,List<String>> result = new HashMap<>();
 
-        Connector connectors[] = getConnectors();
+        Connector[] connectors = getConnectors();
         for (Connector connector : connectors) {
             if (Boolean.TRUE.equals(connector.getProperty("SSLEnabled"))) {
                 SSLHostConfig[] sslHostConfigs = connector.getProtocolHandler().findSslHostConfigs();
                 for (SSLHostConfig sslHostConfig : sslHostConfigs) {
                     String name = connector.toString() + "-" + sslHostConfig.getHostName();
                     List<String> certList = new ArrayList<>();
-                    if (sslHostConfig.getOpenSslContext().longValue() == 0) {
-                        // Not set. Must be JSSE based.
-                        SSLContext sslContext = sslHostConfig.getCertificates().iterator().next().getSslContext();
-                        X509Certificate[] certs = sslContext.getAcceptedIssuers();
-                        if (certs == null) {
-                            certList.add(smClient.getString("managerServlet.certsNotAvailable"));
-                        } else if (certs.length == 0) {
-                            certList.add(smClient.getString("managerServlet.trustedCertsNotConfigured"));
-                        } else {
-                            for (Certificate cert : certs) {
-                                certList.add(cert.toString());
-                            }
-                        }
-                    } else {
+                    SSLContext sslContext = sslHostConfig.getCertificates().iterator().next().getSslContext();
+                    X509Certificate[] certs = sslContext.getAcceptedIssuers();
+                    if (certs == null) {
                         certList.add(smClient.getString("managerServlet.certsNotAvailable"));
+                    } else if (certs.length == 0) {
+                        certList.add(smClient.getString("managerServlet.trustedCertsNotConfigured"));
+                    } else {
+                        for (Certificate cert : certs) {
+                            certList.add(cert.toString());
+                        }
                     }
                     result.put(name, certList);
                 }
