@@ -134,8 +134,8 @@ public class LockOutRealm extends CombinedRealm {
     @Override
     public Principal authenticate(GSSContext gssContext, boolean storeCreds) {
         if (gssContext.isEstablished()) {
-            String username = null;
-            GSSName name = null;
+            String username;
+            GSSName name;
             try {
                 name = gssContext.getSrcName();
             } catch (GSSException e) {
@@ -202,10 +202,10 @@ public class LockOutRealm extends CombinedRealm {
 
     /*
      * Checks to see if the current user is locked. If this is associated with a login attempt, then the last access
-     * time will be recorded and any attempt to authenticated a locked user will log a warning.
+     * time will be recorded and any attempt to authenticate a locked user will log a warning.
      */
     public boolean isLocked(String username) {
-        LockRecord lockRecord = null;
+        LockRecord lockRecord;
         synchronized (this) {
             lockRecord = failedUsers.get(username);
         }
@@ -216,13 +216,10 @@ public class LockOutRealm extends CombinedRealm {
         }
 
         // Check to see if user is locked
-        if (lockRecord.getFailures() >= failureCount &&
-                (System.currentTimeMillis() - lockRecord.getLastFailureTime()) / 1000 < lockOutTime) {
-            return true;
-        }
+        // Otherwise, user has not, yet, exceeded lock thresholds
+        return lockRecord.getFailures() >= failureCount &&
+            (System.currentTimeMillis() - lockRecord.getLastFailureTime()) / 1000 < lockOutTime;
 
-        // User has not, yet, exceeded lock thresholds
-        return false;
     }
 
 
@@ -239,7 +236,7 @@ public class LockOutRealm extends CombinedRealm {
      * After a failed authentication, add the record of the failed authentication.
      */
     private void registerAuthFailure(String username) {
-        LockRecord lockRecord = null;
+        LockRecord lockRecord;
         synchronized (this) {
             if (!failedUsers.containsKey(username)) {
                 lockRecord = new LockRecord();
