@@ -47,7 +47,7 @@ import org.apache.tomcat.util.ExceptionUtils;
 /**
  * Standard implementation of the <b>Manager</b> interface that provides simple session persistence across restarts of
  * this component (such as when the entire server is shut down and restarted, or when a particular web application is
- * reloaded.
+ * reloaded).
  * <p>
  * <b>IMPLEMENTATION NOTE</b>: Correct behavior of session storing and reloading depends upon external calls to the
  * <code>start()</code> and <code>stop()</code> methods of this class at the correct times.
@@ -181,9 +181,9 @@ public class StandardManager extends ManagerBase {
         if (log.isTraceEnabled()) {
             log.trace(sm.getString("standardManager.loading", pathname));
         }
-        Loader loader = null;
+        Loader loader;
         ClassLoader classLoader = null;
-        Log logger = null;
+        Log logger;
         try (FileInputStream fis = new FileInputStream(file.getAbsolutePath());
                 BufferedInputStream bis = new BufferedInputStream(fis)) {
             Context c = getContext();
@@ -377,7 +377,7 @@ public class StandardManager extends ManagerBase {
         }
 
         // Expire all active sessions
-        Session sessions[] = findSessions();
+        Session[] sessions = findSessions();
         for (Session session : sessions) {
             try {
                 if (session.isValid()) {
@@ -405,7 +405,7 @@ public class StandardManager extends ManagerBase {
      * @return the file
      */
     protected File file() {
-        if (pathname == null || pathname.length() == 0) {
+        if (pathname == null || pathname.isEmpty()) {
             return null;
         }
         File file = new File(pathname);
