@@ -16,7 +16,6 @@
  */
 package org.apache.catalina.ssi;
 
-
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
@@ -24,6 +23,7 @@ import java.io.PrintWriter;
 
 import org.apache.catalina.util.IOTools;
 import org.apache.tomcat.util.res.StringManager;
+
 /**
  * Implements the Server-side #exec command
  *
@@ -39,34 +39,30 @@ public class SSIExec implements SSICommand {
     protected static final int BUFFER_SIZE = 1024;
 
 
-    /**
-     * @see SSICommand
-     */
     @Override
-    public long process(SSIMediator ssiMediator, String commandName,
-            String[] paramNames, String[] paramValues, PrintWriter writer) {
+    public long process(SSIMediator ssiMediator, String commandName, String[] paramNames, String[] paramValues,
+            PrintWriter writer) {
         long lastModified = 0;
         String configErrMsg = ssiMediator.getConfigErrMsg();
         String paramName = paramNames[0];
         String paramValue = paramValues[0];
         String substitutedValue = ssiMediator.substituteVariables(paramValue);
         if (paramName.equalsIgnoreCase("cgi")) {
-            lastModified = ssiInclude.process(ssiMediator, "include",
-                    new String[]{"virtual"}, new String[]{substitutedValue},
-                    writer);
+            lastModified = ssiInclude.process(ssiMediator, "include", new String[] { "virtual" },
+                    new String[] { substitutedValue }, writer);
         } else if (paramName.equalsIgnoreCase("cmd")) {
             boolean foundProgram = false;
             try {
                 Runtime rt = Runtime.getRuntime();
                 Process proc = rt.exec(substitutedValue);
                 foundProgram = true;
-                BufferedReader stdOutReader = new BufferedReader(
-                        new InputStreamReader(proc.getInputStream()));
-                BufferedReader stdErrReader = new BufferedReader(
-                        new InputStreamReader(proc.getErrorStream()));
                 char[] buf = new char[BUFFER_SIZE];
-                IOTools.flow(stdErrReader, writer, buf);
-                IOTools.flow(stdOutReader, writer, buf);
+                try (BufferedReader stdOutReader = new BufferedReader(new InputStreamReader(proc.getInputStream()));
+                        BufferedReader stdErrReader =
+                                new BufferedReader(new InputStreamReader(proc.getErrorStream()))) {
+                    IOTools.flow(stdErrReader, writer, buf);
+                    IOTools.flow(stdOutReader, writer, buf);
+                }
                 proc.waitFor();
                 lastModified = System.currentTimeMillis();
             } catch (InterruptedException e) {
@@ -82,4 +78,4 @@ public class SSIExec implements SSICommand {
         }
         return lastModified;
     }
-}
\ No newline at end of file
+}
