@@ -171,7 +171,7 @@ public class SSIServlet extends HttpServlet {
         SSIExternalResolver ssiExternalResolver = new SSIServletExternalResolver(getServletContext(), req, res,
                 isVirtualWebappRelative, debug, inputEncoding);
         SSIProcessor ssiProcessor = new SSIProcessor(ssiExternalResolver, debug, allowExec);
-        PrintWriter printWriter = null;
+        PrintWriter printWriter;
         StringWriter stringWriter = null;
         if (buffered) {
             stringWriter = new StringWriter();
@@ -198,9 +198,8 @@ public class SSIServlet extends HttpServlet {
             if (lastModified > 0) {
                 res.setDateHeader("last-modified", lastModified);
             }
-            if (buffered) {
+            if (stringWriter != null) {
                 printWriter.flush();
-                @SuppressWarnings("null")
                 String text = stringWriter.toString();
                 res.getWriter().write(text);
             }
