@@ -69,7 +69,7 @@ public final class ClassLoaderFactory {
      *
      * @exception Exception if an error occurs constructing the class loader
      */
-    public static ClassLoader createClassLoader(File unpacked[], File packed[], final ClassLoader parent)
+    public static ClassLoader createClassLoader(File[] unpacked, File[] packed, final ClassLoader parent)
             throws Exception {
 
         if (log.isDebugEnabled()) {
@@ -100,7 +100,7 @@ public final class ClassLoaderFactory {
                 if (!directory.isDirectory() || !directory.canRead()) {
                     continue;
                 }
-                String filenames[] = directory.list();
+                String[] filenames = directory.list();
                 if (filenames == null) {
                     continue;
                 }
@@ -192,7 +192,7 @@ public final class ClassLoaderFactory {
                     if (log.isDebugEnabled()) {
                         log.debug("  Including directory glob " + directory.getAbsolutePath());
                     }
-                    String filenames[] = directory.list();
+                    String[] filenames = directory.list();
                     if (filenames == null) {
                         continue;
                     }
