@@ -153,7 +153,7 @@ public class HostConfig implements LifecycleListener {
     /**
      * Set of applications which are being serviced, and shouldn't be deployed/undeployed/redeployed at the moment.
      */
-    private Set<String> servicedSet = ConcurrentHashMap.newKeySet();
+    private final Set<String> servicedSet = ConcurrentHashMap.newKeySet();
 
     /**
      * The <code>Digester</code> instance used to parse context descriptors.
@@ -615,7 +615,7 @@ public class HostConfig implements LifecycleListener {
         Context context = null;
         boolean isExternalWar = false;
         boolean isExternal = false;
-        File expandedDocBase = null;
+        File expandedDocBase;
 
         try {
             synchronized (digesterLock) {
@@ -686,7 +686,8 @@ public class HostConfig implements LifecycleListener {
 
             // default to appBase dir + name
             expandedDocBase = new File(host.getAppBaseFile(), cn.getBaseName());
-            if (context.getDocBase() != null && !context.getDocBase().toLowerCase(Locale.ENGLISH).endsWith(".war")) {
+            if (context != null && context.getDocBase() != null &&
+                    !context.getDocBase().toLowerCase(Locale.ENGLISH).endsWith(".war")) {
                 // first assume docBase is absolute
                 expandedDocBase = new File(context.getDocBase());
                 if (!expandedDocBase.isAbsolute()) {
@@ -838,7 +839,7 @@ public class HostConfig implements LifecycleListener {
         // not end with File.separator for a directory
 
         StringBuilder docBase;
-        String canonicalDocBase = null;
+        String canonicalDocBase;
 
         try {
             String canonicalAppBase = appBase.getCanonicalPath();
@@ -864,7 +865,7 @@ public class HostConfig implements LifecycleListener {
 
         // Compare the two. If they are not the same, the contextPath must
         // have /../ like sequences in it
-        return canonicalDocBase.equals(docBase.toString());
+        return canonicalDocBase.contentEquals(docBase);
     }
 
     /**
@@ -894,12 +895,10 @@ public class HostConfig implements LifecycleListener {
         // If there is an expanded directory then any xml in that directory
         // should only be used if the directory is not out of date and
         // unpackWARs is true. Note the code below may apply further limits
-        boolean useXml = false;
-        // If the xml file exists then expandedDir must exists so no need to
+        boolean useXml =
+                xml.exists() && unpackWARs && (!warTracker.exists() || warTracker.lastModified() == war.lastModified());
+        // If the xml file exists then expandedDir must exist so no need to
         // test that here
-        if (xml.exists() && unpackWARs && (!warTracker.exists() || warTracker.lastModified() == war.lastModified())) {
-            useXml = true;
-        }
 
         Context context = null;
         boolean deployThisXML = isDeployThisXML(war, cn);
@@ -1144,7 +1143,7 @@ public class HostConfig implements LifecycleListener {
                     }
                 }
 
-                if (copyThisXml == false && context instanceof StandardContext) {
+                if (!copyThisXml && context instanceof StandardContext) {
                     // Host is using default value. Context may override it.
                     copyThisXml = ((StandardContext) context).getCopyXML();
                 }
@@ -1350,8 +1349,8 @@ public class HostConfig implements LifecycleListener {
                     }
                 }
             } else {
-                // There is a chance the the resource was only missing
-                // temporarily eg renamed during a text editor save
+                // There is a chance the resource was only missing
+                // temporarily e.g. renamed during a text editor save
                 if (resource.exists() || !resource.getName().toLowerCase(Locale.ENGLISH).endsWith(".war")) {
                     try {
                         Thread.sleep(500);
@@ -1535,13 +1534,9 @@ public class HostConfig implements LifecycleListener {
             return false;
         }
 
-        if (canonicalLocation.equals(canonicalConfigBase) && resource.getName().endsWith(".xml")) {
-            // Resource is an xml file in the configBase so it may be deleted
-            return true;
-        }
-
+        // Resource is a xml file in the configBase so it may be deleted
+        return canonicalLocation.equals(canonicalConfigBase) && resource.getName().endsWith(".xml");
         // All other resources should not be deleted
-        return false;
     }
 
 
@@ -1569,7 +1564,7 @@ public class HostConfig implements LifecycleListener {
         try {
             ObjectName hostON = host.getObjectName();
             oname = new ObjectName(hostON.getDomain() + ":type=Deployer,host=" + host.getName());
-            Registry.getRegistry(null, null).registerComponent(this, oname, this.getClass().getName());
+            Registry.getRegistry(null).registerComponent(this, oname, this.getClass().getName());
         } catch (Exception e) {
             log.warn(sm.getString("hostConfig.jmx.register", oname), e);
         }
@@ -1597,7 +1592,7 @@ public class HostConfig implements LifecycleListener {
 
         if (oname != null) {
             try {
-                Registry.getRegistry(null, null).unregisterComponent(oname);
+                Registry.getRegistry(null).unregisterComponent(oname);
             } catch (Exception e) {
                 log.warn(sm.getString("hostConfig.jmx.unregister", oname), e);
             }
@@ -1646,7 +1641,7 @@ public class HostConfig implements LifecycleListener {
      */
     public void check(String name) {
         synchronized (host) {
-            if (!((Lifecycle) host).getState().isAvailable()) {
+            if (!host.getState().isAvailable()) {
                 return;
             }
             if (tryAddServiced(name)) {
@@ -1828,9 +1823,9 @@ public class HostConfig implements LifecycleListener {
 
     private static class DeployDescriptor implements Runnable {
 
-        private HostConfig config;
-        private ContextName cn;
-        private File descriptor;
+        private final HostConfig config;
+        private final ContextName cn;
+        private final File descriptor;
 
         DeployDescriptor(HostConfig config, ContextName cn, File descriptor) {
             this.config = config;
@@ -1850,9 +1845,9 @@ public class HostConfig implements LifecycleListener {
 
     private static class DeployWar implements Runnable {
 
-        private HostConfig config;
-        private ContextName cn;
-        private File war;
+        private final HostConfig config;
+        private final ContextName cn;
+        private final File war;
 
         DeployWar(HostConfig config, ContextName cn, File war) {
             this.config = config;
@@ -1872,9 +1867,9 @@ public class HostConfig implements LifecycleListener {
 
     private static class DeployDirectory implements Runnable {
 
-        private HostConfig config;
-        private ContextName cn;
-        private File dir;
+        private final HostConfig config;
+        private final ContextName cn;
+        private final File dir;
 
         DeployDirectory(HostConfig config, ContextName cn, File dir) {
             this.config = config;
