@@ -27,6 +27,7 @@ import java.net.URL;
 import java.net.URLConnection;
 import java.security.Principal;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -193,7 +194,7 @@ public class Tomcat {
     }
 
     /**
-     * The the hostname of the default host, default is 'localhost'.
+     * The hostname of the default host, default is 'localhost'.
      *
      * @param s The default host name
      */
@@ -463,7 +464,7 @@ public class Tomcat {
     /**
      * Add a user for the in-memory realm. All created apps use this by default, can be replaced using setRealm().
      *
-     * @param user The user name
+     * @param user The username
      * @param pass The password
      */
     public void addUser(String user, String pass) {
@@ -475,7 +476,7 @@ public class Tomcat {
      *
      * @see #addUser(String, String)
      *
-     * @param user The user name
+     * @param user The username
      * @param role The role name
      */
     public void addRole(String user, String role) {
@@ -668,12 +669,12 @@ public class Tomcat {
      * @return the deployed context
      */
     public Context addWebapp(Host host, String contextPath, String docBase) {
-        LifecycleListener listener = null;
+        LifecycleListener listener;
         try {
             Class<?> clazz = Class.forName(getHost().getConfigClass());
             listener = (LifecycleListener) clazz.getConstructor().newInstance();
         } catch (ReflectiveOperationException e) {
-            // Wrap in IAE since we can't easily change the method signature to
+            // Wrap in IAE since we can't easily change the method signature
             // to throw the specific checked exceptions
             throw new IllegalArgumentException(e);
         }
@@ -879,10 +880,10 @@ public class Tomcat {
 
 
     /**
-     * By default, when calling addWebapp() to create a Context, the settings from from the default web.xml are added to
-     * the context. Calling this method with a <code>false</code> value prior to calling addWebapp() allows to opt out
-     * of the default settings. In that event you will need to add the configurations yourself, either programmatically
-     * or by using web.xml deployment descriptors.
+     * By default, when calling addWebapp() to create a Context, the settings from the default web.xml are added to the
+     * context. Calling this method with a <code>false</code> value prior to calling addWebapp() allows to opt out of
+     * the default settings. In that event you will need to add the configurations yourself, either programmatically or
+     * by using web.xml deployment descriptors.
      *
      * @param addDefaultWebXmlToWebapp <code>false</code> will prevent the class from automatically adding the default
      *                                     settings when calling addWebapp(). <code>true</code> will add the default
@@ -912,7 +913,7 @@ public class Tomcat {
         loggerName.append(host.getName());
         loggerName.append("].[");
         // Context name
-        if (contextName == null || contextName.equals("")) {
+        if (contextName == null || contextName.isEmpty()) {
             loggerName.append('/');
         } else if (contextName.startsWith("##")) {
             loggerName.append('/');
@@ -995,7 +996,6 @@ public class Tomcat {
      * <li>MIME mappings (subset of those in conf/web.xml)</li>
      * <li>Welcome files</li>
      * </ul>
-     * TODO: Align the MIME mappings with conf/web.xml - possibly via a common file.
      *
      * @param contextPath The path of the context to set the defaults for
      */
@@ -1037,11 +1037,15 @@ public class Tomcat {
         ctx.addWelcomeFile("index.html");
         ctx.addWelcomeFile("index.htm");
         ctx.addWelcomeFile("index.jsp");
+        // Any application configured welcome files should override the defaults.
+        if (ctx instanceof StandardContext) {
+            ((StandardContext) ctx).setReplaceWelcomeFiles(true);
+        }
     }
 
 
     /**
-     * Add the default MIME type mappings to the provide Context.
+     * Add the default MIME type mappings to the provided Context.
      *
      * @param context The web application to which the default MIME type mappings should be added.
      */
@@ -1086,6 +1090,7 @@ public class Tomcat {
                     }
                 }
             } catch (ClassCastException e) {
+                // Ignore
             }
         }
     }
@@ -1215,7 +1220,7 @@ public class Tomcat {
         // Graal native images don't load any configuration except the VM default
         if (JreCompat.isGraalAvailable()) {
             try (InputStream is = new FileInputStream(
-                    new File(System.getProperty("java.util.logging.config.file", "conf/logging.properties")))) {
+                    System.getProperty("java.util.logging.config.file", "conf/logging.properties"))) {
                 LogManager.getLogManager().readConfiguration(is);
             } catch (SecurityException | IOException e) {
                 // Ignore, the VM default will be used
@@ -1239,10 +1244,7 @@ public class Tomcat {
             } else if (args[i].equals("--catalina")) {
                 // This was already processed before
                 // Skip the rest of the arguments as they are for Catalina
-                ArrayList<String> result = new ArrayList<>();
-                for (int j = i + 1; j < args.length; j++) {
-                    result.add(args[j]);
-                }
+                ArrayList<String> result = new ArrayList<>(Arrays.asList(args).subList(i + 1, args.length));
                 catalinaArguments = result.toArray(new String[0]);
                 break;
             }
@@ -1256,28 +1258,34 @@ public class Tomcat {
         boolean await = false;
         String path = "";
         // Process command line parameters
+        label:
         for (int i = 0; i < args.length; i++) {
-            if (args[i].equals("--war")) {
-                if (++i >= args.length) {
-                    throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i - 1]));
-                }
-                File war = new File(args[i]);
-                tomcat.addWebapp(path, war.getAbsolutePath());
-            } else if (args[i].equals("--path")) {
-                if (++i >= args.length) {
-                    throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i - 1]));
-                }
-                path = args[i];
-            } else if (args[i].equals("--await")) {
-                await = true;
-            } else if (args[i].equals("--no-jmx")) {
-                // This was already processed before
-            } else if (args[i].equals("--catalina")) {
-                // This was already processed before
-                // Skip the rest of the arguments as they are for Catalina
-                break;
-            } else {
-                throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i]));
+            switch (args[i]) {
+                case "--war":
+                    if (++i >= args.length) {
+                        throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i - 1]));
+                    }
+                    File war = new File(args[i]);
+                    tomcat.addWebapp(path, war.getAbsolutePath());
+                    break;
+                case "--path":
+                    if (++i >= args.length) {
+                        throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i - 1]));
+                    }
+                    path = args[i];
+                    break;
+                case "--await":
+                    await = true;
+                    break;
+                case "--no-jmx":
+                    // This was already processed before
+                    break;
+                case "--catalina":
+                    // This was already processed before
+                    // Skip the rest of the arguments as they are for Catalina
+                    break label;
+                default:
+                    throw new IllegalArgumentException(sm.getString("tomcat.invalidCommandLine", args[i]));
             }
         }
         tomcat.start();
