@@ -14,7 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.catalina.tribes.membership.cloud;
 
 import java.io.IOException;
@@ -34,11 +33,9 @@ import org.apache.juli.logging.LogFactory;
 
 /**
  * A {@link org.apache.catalina.tribes.MembershipProvider} that uses DNS to retrieve the members of a cluster.<br>
- *
  * <p>
  * <strong>Configuration example for Kubernetes</strong>
  * </p>
- *
  * {@code server.xml }
  *
  * <pre>
@@ -61,6 +58,7 @@ import org.apache.juli.logging.LogFactory;
  *  }
  *  </pre>
  *
+ * minimal example for the Service my-tomcat-app-membership, note the <strong>selector</strong><br>
  * {@code dns-membership-service.yml }
  *
  * <pre>
@@ -74,16 +72,33 @@ import org.apache.juli.logging.LogFactory;
  *   name: my-tomcat-app-membership
  * spec:
  *   clusterIP: None
- *   ports:
- *   - name: membership
- *     port: 8888
  *   selector:
  *     app: my-tomcat-app
  * }
  * </pre>
  *
- * Environment variable configuration<br>
+ * First Tomcat pod minimal example, note the <strong>labels</strong> that must correspond to the
+ * <strong>selector</strong> in the service.<br>
+ * {@code tomcat1.yml }
  *
+ * <pre>
+ * {@code
+ * apiVersion: v1
+ * kind: Pod
+ * metadata:
+ *   name: tomcat1
+ *   labels:
+ *     app: my-tomcat-app
+ * spec:
+ *   containers:
+ *   - name: tomcat
+ *     image: tomcat
+ *     ports:
+ *     - containerPort: 8080
+ * }
+ * </pre>
+ *
+ * Environment variable configuration<br>
  * {@code DNS_MEMBERSHIP_SERVICE_NAME=my-tomcat-app-membership }
  */
 
@@ -107,7 +122,7 @@ public class DNSMembershipProvider extends CloudMembershipProvider {
         }
 
         if (log.isDebugEnabled()) {
-            log.debug(String.format("Namespace [%s] set; clustering enabled", dnsServiceName));
+            log.debug(sm.getString("cloudMembershipProvider.start", dnsServiceName));
         }
         dnsServiceName = URLEncoder.encode(dnsServiceName, "UTF-8");
 
@@ -139,7 +154,8 @@ public class DNSMembershipProvider extends CloudMembershipProvider {
                 if (ip.equals(localIp)) {
                     // Update the UID on initial lookup
                     Member localMember = service.getLocalMember(false);
-                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID && localMember instanceof MemberImpl) {
+                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID &&
+                            localMember instanceof MemberImpl) {
                         ((MemberImpl) localMember).setUniqueId(id);
                     }
                     continue;
@@ -167,8 +183,7 @@ public class DNSMembershipProvider extends CloudMembershipProvider {
         Member[] members = membership.getMembers();
         if (members != null) {
             for (Member member : members) {
-                if (Arrays.equals(sender.getHost(), member.getHost())
-                        && sender.getPort() == member.getPort()) {
+                if (Arrays.equals(sender.getHost(), member.getHost()) && sender.getPort() == member.getPort()) {
                     found = true;
                     break;
                 }
@@ -183,7 +198,7 @@ public class DNSMembershipProvider extends CloudMembershipProvider {
             StringBuilder buf = new StringBuilder();
             buf.append(host[i++] & 0xff);
             for (; i < host.length; i++) {
-                buf.append(".").append(host[i] & 0xff);
+                buf.append('.').append(host[i] & 0xff);
             }
 
             byte[] id = md5.digest(buf.toString().getBytes());
