@@ -24,6 +24,8 @@ import java.net.URLEncoder;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.FileSystems;
 import java.nio.file.Files;
+import java.nio.file.Path;
+import java.nio.file.attribute.FileTime;
 import java.time.Duration;
 import java.time.Instant;
 import java.util.ArrayList;
@@ -38,13 +40,18 @@ import org.apache.juli.logging.LogFactory;
 import org.apache.tomcat.util.json.JSONParser;
 
 /**
- * A {@link org.apache.catalina.tribes.MembershipProvider} that uses Kubernetes API to retrieve the members of a cluster.<br>
- *
+ * A {@link org.apache.catalina.tribes.MembershipProvider} that uses Kubernetes API to retrieve the members of a
+ * cluster.<br>
  */
 
 public class KubernetesMembershipProvider extends CloudMembershipProvider {
+
     private static final Log log = LogFactory.getLog(KubernetesMembershipProvider.class);
 
+    private Path saTokenPath;
+    private FileTime saTokenLastModifiedTime;
+
+
     @Override
     public void start(int level) throws Exception {
         if ((level & MembershipService.MBR_RX) == 0) {
@@ -57,14 +64,15 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         String namespace = getNamespace();
 
         if (log.isDebugEnabled()) {
-            log.debug(String.format("Namespace [%s] set; clustering enabled", namespace));
+            log.debug(sm.getString("cloudMembershipProvider.start", namespace));
         }
 
         String protocol = getEnv(CUSTOM_ENV_PREFIX + "MASTER_PROTOCOL", "KUBERNETES_MASTER_PROTOCOL");
         String masterHost = getEnv(CUSTOM_ENV_PREFIX + "MASTER_HOST", "KUBERNETES_SERVICE_HOST");
         String masterPort = getEnv(CUSTOM_ENV_PREFIX + "MASTER_PORT", "KUBERNETES_SERVICE_PORT");
 
-        String clientCertificateFile = getEnv(CUSTOM_ENV_PREFIX + "CLIENT_CERT_FILE", "KUBERNETES_CLIENT_CERTIFICATE_FILE");
+        String clientCertificateFile =
+                getEnv(CUSTOM_ENV_PREFIX + "CLIENT_CERT_FILE", "KUBERNETES_CLIENT_CERTIFICATE_FILE");
         String caCertFile = getEnv(CUSTOM_ENV_PREFIX + "CA_CERT_FILE", "KUBERNETES_CA_CERTIFICATE_FILE");
         if (caCertFile == null) {
             caCertFile = "/var/run/secrets/kubernetes.io/serviceaccount/ca.crt";
@@ -79,8 +87,10 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 saTokenFile = "/var/run/secrets/kubernetes.io/serviceaccount/token";
             }
             try {
-                byte[] bytes = Files.readAllBytes(FileSystems.getDefault().getPath(saTokenFile));
+                saTokenPath = FileSystems.getDefault().getPath(saTokenFile);
+                byte[] bytes = Files.readAllBytes(saTokenPath);
                 streamProvider = new TokenStreamProvider(new String(bytes, StandardCharsets.US_ASCII), caCertFile);
+                saTokenLastModifiedTime = Files.getLastModifiedTime(saTokenPath);
             } catch (IOException e) {
                 log.error(sm.getString("kubernetesMembershipProvider.streamError"), e);
             }
@@ -89,12 +99,17 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 protocol = "http";
             }
             String clientKeyFile = getEnv("KUBERNETES_CLIENT_KEY_FILE");
+            if (clientKeyFile == null) {
+                log.error(sm.getString("kubernetesMembershipProvider.noKey"));
+                return;
+            }
             String clientKeyPassword = getEnv("KUBERNETES_CLIENT_KEY_PASSWORD");
             String clientKeyAlgo = getEnv("KUBERNETES_CLIENT_KEY_ALGO");
             if (clientKeyAlgo == null) {
                 clientKeyAlgo = "RSA";
             }
-            streamProvider = new CertificateStreamProvider(clientCertificateFile, clientKeyFile, clientKeyPassword, clientKeyAlgo, caCertFile);
+            streamProvider = new CertificateStreamProvider(clientCertificateFile, clientKeyFile, clientKeyPassword,
+                    clientKeyAlgo, caCertFile);
         }
 
         String ver = getEnv(CUSTOM_ENV_PREFIX + "API_VERSION", "KUBERNETES_API_VERSION");
@@ -108,7 +123,7 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         labels = labels == null ? null : URLEncoder.encode(labels, "UTF-8");
 
         url = String.format("%s://%s:%s/api/%s/namespaces/%s/pods", protocol, masterHost, masterPort, ver, namespace);
-        if (labels != null && labels.length() > 0) {
+        if (labels != null && !labels.isEmpty()) {
             url = url + "?labelSelector=" + labels;
         }
 
@@ -116,6 +131,7 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         heartbeat();
     }
 
+
     @Override
     public boolean stop(int level) throws Exception {
         try {
@@ -125,12 +141,15 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         }
     }
 
+
     @Override
     protected Member[] fetchMembers() {
         if (streamProvider == null) {
             return new Member[0];
         }
 
+        reloadSaTokenIfChanged();
+
         List<MemberImpl> members = new ArrayList<>();
 
         try (InputStream stream = streamProvider.openStream(url, headers, connectionTimeout, readTimeout);
@@ -143,11 +162,36 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
         return members.toArray(new Member[0]);
     }
 
+
+    private void reloadSaTokenIfChanged() {
+        if (saTokenPath == null) {
+            // Service account token not being used.
+            return;
+        }
+        if (!Files.exists(saTokenPath)) {
+            // If the service account token is being used, this path should exist
+            log.warn(sm.getString("kubernetesMembershipProvider.serviceAccountTokenMissing", saTokenPath));
+            return;
+        }
+        try {
+            FileTime oldSaTokenLastModifiedTime = saTokenLastModifiedTime;
+            saTokenLastModifiedTime = Files.getLastModifiedTime(saTokenPath);
+            // Use != to protect against clock issues
+            if (!saTokenLastModifiedTime.equals(oldSaTokenLastModifiedTime)) {
+                byte[] bytes = Files.readAllBytes(saTokenPath);
+                ((TokenStreamProvider)streamProvider).setToken(new String(bytes, StandardCharsets.US_ASCII));
+            }
+        } catch (IOException e) {
+            log.error(sm.getString("kubernetesMembershipProvider.streamError"), e);
+        }
+    }
+
+
     @SuppressWarnings("unchecked")
     protected void parsePods(Reader reader, List<MemberImpl> members) {
         JSONParser parser = new JSONParser(reader);
         try {
-            LinkedHashMap<String, Object> json = parser.object();
+            LinkedHashMap<String,Object> json = parser.object();
             Object itemsObject = json.get("items");
             if (!(itemsObject instanceof List<?>)) {
                 log.error(sm.getString("kubernetesMembershipProvider.invalidPodsList", "no items"));
@@ -155,11 +199,11 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
             }
             List<Object> items = (List<Object>) itemsObject;
             for (Object podObject : items) {
-                if (!(podObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(podObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "item"));
                     continue;
                 }
-                LinkedHashMap<String, Object> pod = (LinkedHashMap<String, Object>) podObject;
+                LinkedHashMap<String,Object> pod = (LinkedHashMap<String,Object>) podObject;
                 // If there is a "kind", check it is "Pod"
                 Object podKindObject = pod.get("kind");
                 if (podKindObject != null && !"Pod".equals(podKindObject)) {
@@ -167,11 +211,11 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 }
                 // "metadata" contains "name", "uid" and "creationTimestamp"
                 Object metadataObject = pod.get("metadata");
-                if (!(metadataObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(metadataObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "metadata"));
                     continue;
                 }
-                LinkedHashMap<String, Object> metadata = (LinkedHashMap<String, Object>) metadataObject;
+                LinkedHashMap<String,Object> metadata = (LinkedHashMap<String,Object>) metadataObject;
                 Object nameObject = metadata.get("name");
                 if (nameObject == null) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "name"));
@@ -183,14 +227,13 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "uid"));
                     continue;
                 }
-                String creationTimestamp = creationTimestampObject.toString();
                 // "status" contains "phase" (which must be "Running") and "podIP"
                 Object statusObject = pod.get("status");
-                if (!(statusObject instanceof LinkedHashMap<?, ?>)) {
+                if (!(statusObject instanceof LinkedHashMap<?,?>)) {
                     log.warn(sm.getString("kubernetesMembershipProvider.invalidPod", "status"));
                     continue;
                 }
-                LinkedHashMap<String, Object> status = (LinkedHashMap<String, Object>) statusObject;
+                LinkedHashMap<String,Object> status = (LinkedHashMap<String,Object>) statusObject;
                 if (!"Running".equals(status.get("phase"))) {
                     continue;
                 }
@@ -206,16 +249,18 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
                 if (podIP.equals(localIp)) {
                     // Update the UID on initial lookup
                     Member localMember = service.getLocalMember(false);
-                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID && localMember instanceof MemberImpl) {
+                    if (localMember.getUniqueId() == CloudMembershipService.INITIAL_ID &&
+                            localMember instanceof MemberImpl) {
                         byte[] id = md5.digest(uid.getBytes(StandardCharsets.US_ASCII));
                         ((MemberImpl) localMember).setUniqueId(id);
                     }
                     continue;
                 }
 
-                long aliveTime = Duration.between(Instant.parse(creationTimestamp), startTime).toMillis();
+                long aliveTime =
+                        Duration.between(Instant.parse(creationTimestampObject.toString()), startTime).toMillis();
 
-                MemberImpl member = null;
+                MemberImpl member;
                 try {
                     member = new MemberImpl(podIP, port, aliveTime);
                 } catch (IOException e) {
@@ -232,5 +277,4 @@ public class KubernetesMembershipProvider extends CloudMembershipProvider {
             log.error(sm.getString("kubernetesMembershipProvider.jsonError"), e);
         }
     }
-
 }
