@@ -21,7 +21,6 @@ import java.io.IOException;
 import org.apache.catalina.tribes.ChannelException;
 import org.apache.catalina.tribes.ChannelMessage;
 import org.apache.catalina.tribes.Member;
-import org.apache.catalina.tribes.transport.AbstractSender;
 import org.apache.catalina.tribes.transport.DataSender;
 import org.apache.catalina.tribes.transport.PooledSender;
 import org.apache.catalina.tribes.util.StringManager;
@@ -34,13 +33,13 @@ public class PooledParallelSender extends PooledSender implements PooledParallel
         if (!isConnected()) {
             throw new ChannelException(sm.getString("pooledParallelSender.sender.disconnected"));
         }
-        ParallelNioSender sender = (ParallelNioSender)getSender();
+        ParallelNioSender sender = (ParallelNioSender) getSender();
         if (sender == null) {
-            ChannelException cx = new ChannelException(sm.getString(
-                    "pooledParallelSender.unable.retrieveSender.timeout",
-                    Long.toString(getMaxWait())));
+            ChannelException cx = new ChannelException(
+                    sm.getString("pooledParallelSender.unable.retrieveSender.timeout", Long.toString(getMaxWait())));
             for (Member member : destination) {
-                cx.addFaultyMember(member, new NullPointerException(sm.getString("pooledParallelSender.unable.retrieveSender")));
+                cx.addFaultyMember(member,
+                        new NullPointerException(sm.getString("pooledParallelSender.unable.retrieveSender")));
             }
             throw cx;
         } else {
@@ -63,10 +62,10 @@ public class PooledParallelSender extends PooledSender implements PooledParallel
     public DataSender getNewDataSender() {
         try {
             ParallelNioSender sender = new ParallelNioSender();
-            AbstractSender.transferProperties(this,sender);
+            transferProperties(this, sender);
             return sender;
-        } catch ( IOException x ) {
-            throw new RuntimeException(sm.getString("pooledParallelSender.unable.open"),x);
+        } catch (IOException x) {
+            throw new RuntimeException(sm.getString("pooledParallelSender.unable.open"), x);
         }
     }
 }
\ No newline at end of file
