@@ -27,32 +27,27 @@ import java.util.ResourceBundle;
 
 
 /**
- * An internationalization / localization helper class which reduces
- * the bother of handling ResourceBundles and takes care of the
- * common cases of message formatting which otherwise require the
- * creation of Object arrays and such.
- *
- * <p>The StringManager operates on a package basis. One StringManager
- * per package can be created and accessed via the getManager method
- * call.
- *
- * <p>The StringManager will look for a ResourceBundle named by
- * the package name given plus the suffix of "LocalStrings". In
- * practice, this means that the localized information will be contained
- * in a LocalStrings.properties file located in the package
- * directory of the classpath.
- *
- * <p>Please see the documentation for java.util.ResourceBundle for
- * more information.
+ * An internationalization / localization helper class which reduces the bother of handling ResourceBundles and takes
+ * care of the common cases of message formatting which otherwise require the creation of Object arrays and such.
+ * <p>
+ * The StringManager operates on a package basis. One StringManager per package can be created and accessed via the
+ * getManager method call.
+ * <p>
+ * The StringManager will look for a ResourceBundle named by the package name given plus the suffix of "LocalStrings".
+ * In practice, this means that the localized information will be contained in a LocalStrings.properties file located in
+ * the package directory of the classpath.
+ * <p>
+ * Please see the documentation for java.util.ResourceBundle for more information.
  *
  * @author James Duncan Davidson [duncan@eng.sun.com]
  * @author James Todd [gonzo@eng.sun.com]
  * @author Mel Martinez [mmartinez@g1440.com]
+ *
  * @see java.util.ResourceBundle
  */
 public class StringManager {
 
-    private static int LOCALE_CACHE_SIZE = 10;
+    private static final int LOCALE_CACHE_SIZE = 10;
 
     /**
      * The ResourceBundle for this StringManager.
@@ -62,10 +57,8 @@ public class StringManager {
 
 
     /**
-     * Creates a new StringManager for a given package. This is a
-     * private method and all access to it is arbitrated by the
-     * static getManager method call so that only one StringManager
-     * per package will be created.
+     * Creates a new StringManager for a given package. This is a private method and all access to it is arbitrated by
+     * the static getManager method call so that only one StringManager per package will be created.
      *
      * @param packageName Name of package to create StringManager for.
      */
@@ -103,18 +96,16 @@ public class StringManager {
 
 
     /**
-     * Get a string from the underlying resource bundle or return null if the
-     * String is not found.
+     * Get a string from the underlying resource bundle or return null if the String is not found.
      *
      * @param key to desired resource String
      *
-     * @return resource String matching <i>key</i> from underlying bundle or
-     *         null if not found.
+     * @return resource String matching <i>key</i> from underlying bundle or null if not found.
      *
      * @throws IllegalArgumentException if <i>key</i> is null
      */
     public String getString(String key) {
-        if (key == null){
+        if (key == null) {
             String msg = "key may not have a null value";
             throw new IllegalArgumentException(msg);
         }
@@ -127,18 +118,17 @@ public class StringManager {
                 str = bundle.getString(key);
             }
         } catch (MissingResourceException mre) {
-            //bad: shouldn't mask an exception the following way:
-            //   str = "[cannot find message associated with key '" + key +
-            //         "' due to " + mre + "]";
-            //     because it hides the fact that the String was missing
-            //     from the calling code.
-            //good: could just throw the exception (or wrap it in another)
-            //      but that would probably cause much havoc on existing
-            //      code.
-            //better: consistent with container pattern to
-            //      simply return null.  Calling code can then do
-            //      a null check.
-            str = null;
+            // bad: shouldn't mask an exception the following way:
+            // str = "[cannot find message associated with key '" + key +
+            // "' due to " + mre + "]";
+            // because it hides the fact that the String was missing
+            // from the calling code.
+            // good: could just throw the exception (or wrap it in another)
+            // but that would probably cause much havoc on existing
+            // code.
+            // better: consistent with container pattern to
+            // simply return null. Calling code can then do
+            // a null check.
         }
 
         return str;
@@ -146,8 +136,7 @@ public class StringManager {
 
 
     /**
-     * Get a string from the underlying resource bundle and format
-     * it with the given set of arguments.
+     * Get a string from the underlying resource bundle and format it with the given set of arguments.
      *
      * @param key  The key for the required message
      * @param args The values to insert into the message
@@ -180,67 +169,59 @@ public class StringManager {
     // STATIC SUPPORT METHODS
     // --------------------------------------------------------------
 
-    private static final Map<String, Map<Locale,StringManager>> managers = new HashMap<>();
+    private static final Map<String,Map<Locale,StringManager>> managers = new HashMap<>();
 
 
     /**
-     * The StringManager will be returned for the package in which the class is
-     * located. If a manager for that package already exists, it will be reused,
-     * else a new StringManager will be created and returned.
+     * The StringManager will be returned for the package in which the class is located. If a manager for that package
+     * already exists, it will be reused, else a new StringManager will be created and returned.
      *
      * @param clazz The class for which to retrieve the StringManager
      *
      * @return The StringManager for the given class.
      */
-    public static final StringManager getManager(Class<?> clazz) {
+    public static StringManager getManager(Class<?> clazz) {
         return getManager(clazz.getPackage().getName());
     }
 
 
     /**
-     * If a manager for a package already exists, it will be reused, else a new
-     * StringManager will be created and returned.
+     * If a manager for a package already exists, it will be reused, else a new StringManager will be created and
+     * returned.
      *
      * @param packageName The package name
      *
      * @return The StringManager for the given package.
      */
-    public static final StringManager getManager(String packageName) {
+    public static StringManager getManager(String packageName) {
         return getManager(packageName, Locale.getDefault());
     }
 
 
     /**
-     * If a manager for a package/Locale combination already exists, it will be
-     * reused, else a new StringManager will be created and returned.
+     * If a manager for a package/Locale combination already exists, it will be reused, else a new StringManager will be
+     * created and returned.
      *
      * @param packageName The package name
      * @param locale      The Locale
      *
      * @return The StringManager for a particular package and Locale
      */
-    public static final synchronized StringManager getManager(
-            String packageName, Locale locale) {
+    public static synchronized StringManager getManager(String packageName, Locale locale) {
 
         Map<Locale,StringManager> map = managers.get(packageName);
         if (map == null) {
             /*
-             * Don't want the HashMap to be expanded beyond LOCALE_CACHE_SIZE.
-             * Expansion occurs when size() exceeds capacity. Therefore keep
-             * size at or below capacity.
-             * removeEldestEntry() executes after insertion therefore the test
-             * for removal needs to use one less than the maximum desired size
-             *
+             * Don't want the HashMap size to exceed LOCALE_CACHE_SIZE. Expansion occurs when size() exceeds capacity.
+             * Therefore keep size at or below capacity. removeEldestEntry() executes after insertion therefore the test
+             * for removal needs to use one less than the maximum desired size. Note this is an LRU cache.
              */
-            map = new LinkedHashMap<Locale,StringManager>(LOCALE_CACHE_SIZE, 1, true) {
+            map = new LinkedHashMap<Locale,StringManager>(LOCALE_CACHE_SIZE, 0.75f, true) {
                 private static final long serialVersionUID = 1L;
+
                 @Override
-                protected boolean removeEldestEntry(
-                        Map.Entry<Locale,StringManager> eldest) {
-                    if (size() > (LOCALE_CACHE_SIZE - 1)) {
-                        return true;
-                    }
-                    return false;
+                protected boolean removeEldestEntry(Map.Entry<Locale,StringManager> eldest) {
+                    return size() > (LOCALE_CACHE_SIZE - 1);
                 }
             };
             managers.put(packageName, map);
@@ -256,16 +237,14 @@ public class StringManager {
 
 
     /**
-     * Retrieve the StringManager for a list of Locales. The first StringManager
-     * found will be returned.
+     * Retrieve the StringManager for a list of Locales. The first StringManager found will be returned.
      *
-     * @param packageName The package for which the StringManager is required
+     * @param packageName      The package for which the StringManager is required
      * @param requestedLocales the list of Locales
      *
      * @return the found StringManager or the default StringManager
      */
-    public static StringManager getManager(String packageName,
-            Enumeration<Locale> requestedLocales) {
+    public static StringManager getManager(String packageName, Enumeration<Locale> requestedLocales) {
         while (requestedLocales.hasMoreElements()) {
             Locale locale = requestedLocales.nextElement();
             StringManager result = getManager(packageName, locale);
