@@ -247,11 +247,11 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
             /* Helper object to be able to call SimpleDateFormat.format(). */
             private final Date currentDate = new Date();
 
-            protected final String cache[];
-            private SimpleDateFormat formatter;
+            protected final String[] cache;
+            private final SimpleDateFormat formatter;
             private boolean isCLF = false;
 
-            private Cache parent = null;
+            private final Cache parent;
 
             private Cache(Cache parent) {
                 this(null, parent);
@@ -341,11 +341,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                     currentDate.setTime(time);
                     previousFormat = formatter.format(currentDate);
                     if (isCLF) {
-                        StringBuilder current = new StringBuilder(32);
-                        current.append('[');
-                        current.append(previousFormat);
-                        current.append(']');
-                        previousFormat = current.toString();
+                        previousFormat = "[" + previousFormat + "]";
                     }
                 }
                 cache[index] = previousFormat;
@@ -361,10 +357,10 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
         protected final Cache cLFCache;
         private final Map<String,Cache> formatCache = new HashMap<>();
 
-        protected DateFormatCache(int size, Locale loc, DateFormatCache parent) {
+        protected DateFormatCache(int size, Locale loc, DateFormatCache parentFC) {
             cacheSize = size;
             cacheDefaultLocale = loc;
-            this.parent = parent;
+            parent = parentFC;
             Cache parentCache = null;
             if (parent != null) {
                 synchronized (parent) {
@@ -422,12 +418,12 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
     private static final ThreadLocal<Date> localDate = ThreadLocal.withInitial(Date::new);
 
     /**
-     * Are we doing conditional logging. default null. It is the value of <code>conditionUnless</code> property.
+     * Are we doing conditional logging ? default null. It is the value of <code>conditionUnless</code> property.
      */
     protected String condition = null;
 
     /**
-     * Are we doing conditional logging. default null. It is the value of <code>conditionIf</code> property.
+     * Are we doing conditional logging ? default null. It is the value of <code>conditionIf</code> property.
      */
     protected String conditionIf = null;
 
@@ -463,7 +459,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
     /**
      * Buffer pool used for log message generation. Pool used to reduce garbage generation.
      */
-    private SynchronizedStack<CharArrayWriter> charArrayWriters = new SynchronizedStack<>();
+    private final SynchronizedStack<CharArrayWriter> charArrayWriters = new SynchronizedStack<>();
 
     /**
      * Log message buffers are usually recycled and re-used. To prevent excessive memory usage, if a buffer grows beyond
@@ -707,7 +703,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
 
     /**
      * This method returns a Date object that is accurate to within one second. If a thread calls this method to get a
-     * Date and it's been less than 1 second since a new Date was created, this method simply gives out the same Date
+     * Date, and it's been less than 1 second since a new Date was created, this method simply gives out the same Date
      * again so that the system doesn't spend time creating Date objects unnecessarily.
      *
      * @param systime The time
@@ -752,7 +748,7 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
     }
 
     /**
-     * Marks an AccessLogElement as needing to be have the value cached at the start of the request rather than just
+     * Marks an AccessLogElement as needing to have the value cached at the start of the request rather than just
      * recorded at the end as the source data for the element may not be available at the end of the request. This
      * typically occurs for remote network information, such as ports, IP addresses etc. when the connection is closed
      * unexpectedly. These elements take advantage of these values being cached elsewhere on first request and do not
@@ -1121,11 +1117,9 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                     frac = timestamp % 1000;
                     StringBuilder tripleMsec = new StringBuilder(4);
                     if (frac < 100) {
+                        tripleMsec.append('0');
                         if (frac < 10) {
                             tripleMsec.append('0');
-                            tripleMsec.append('0');
-                        } else {
-                            tripleMsec.append('0');
                         }
                     }
                     tripleMsec.append(frac);
@@ -1816,6 +1810,10 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
      * encoding which may not be true for Tomcat so Tomcat uses the Java \\uXXXX encoding.
      */
     protected static void escapeAndAppend(String input, CharArrayWriter dest) {
+        escapeAndAppend(input, dest, false);
+    }
+
+    protected static void escapeAndAppend(String input, CharArrayWriter dest, boolean escapeQuoteAsDouble) {
         if (input == null || input.isEmpty()) {
             dest.append('-');
             return;
@@ -1851,7 +1849,11 @@ public abstract class AbstractAccessLogValve extends ValveBase implements Access
                             dest.write(input, next, current - next);
                         }
                         next = current + 1;
-                        dest.append("\\\"");
+                        if (escapeQuoteAsDouble) {
+                            dest.append("\"\"");
+                        } else {
+                            dest.append("\\\"");
+                        }
                         break;
                     // Don't output individual unchanged chars,
                     // write the sub string only when the first char to encode
