@@ -42,12 +42,15 @@ import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.security.Escape;
 
 /**
- * <p>Implementation of a Valve that outputs HTML error pages.</p>
- *
- * <p>This Valve should be attached at the Host level, although it will work
- * if attached to a Context.</p>
- *
- * <p>HTML code from the Cocoon 2 project.</p>
+ * <p>
+ * Implementation of a Valve that outputs HTML error pages.
+ * </p>
+ * <p>
+ * This Valve should be attached at the Host level, although it will work if attached to a Context.
+ * </p>
+ * <p>
+ * HTML code from the Cocoon 2 project.
+ * </p>
  *
  * @author Remy Maucherat
  * @author Craig R. McClanahan
@@ -64,7 +67,7 @@ public class ErrorReportValve extends ValveBase {
     private final ErrorPageSupport errorPageSupport = new ErrorPageSupport();
 
 
-    //------------------------------------------------------ Constructor
+    // ------------------------------------------------------ Constructor
 
     public ErrorReportValve() {
         super(true);
@@ -74,15 +77,13 @@ public class ErrorReportValve extends ValveBase {
     // --------------------------------------------------------- Public Methods
 
     /**
-     * Invoke the next Valve in the sequence. When the invoke returns, check
-     * the response state. If the status code is greater than or equal to 400
-     * or an uncaught exception was thrown then the error handling will be
-     * triggered.
+     * Invoke the next Valve in the sequence. When the invoke returns, check the response state. If the status code is
+     * greater than or equal to 400 or an uncaught exception was thrown then the error handling will be triggered.
      *
-     * @param request The servlet request to be processed
+     * @param request  The servlet request to be processed
      * @param response The servlet response to be created
      *
-     * @exception IOException if an input/output error occurs
+     * @exception IOException      if an input/output error occurs
      * @exception ServletException if a servlet error occurs
      */
     @Override
@@ -93,7 +94,7 @@ public class ErrorReportValve extends ValveBase {
 
         if (response.isCommitted()) {
             if (response.setErrorReported()) {
-                // Error wasn't previously reported but we can't write an error
+                // Error wasn't previously reported, but we can't write an error
                 // page because the response has already been committed.
 
                 // See if IO is allowed
@@ -151,13 +152,36 @@ public class ErrorReportValve extends ValveBase {
     // ------------------------------------------------------ Protected Methods
 
 
+    /**
+     * Return the error page associated with the specified status and exception.
+     *
+     * @param statusCode the status code
+     * @param throwable  the exception
+     *
+     * @return the associated error page
+     */
+    protected ErrorPage findErrorPage(int statusCode, Throwable throwable) {
+        ErrorPage errorPage = null;
+        if (throwable != null) {
+            errorPage = errorPageSupport.find(throwable);
+        }
+        if (errorPage == null) {
+            errorPage = errorPageSupport.find(statusCode);
+        }
+        if (errorPage == null) {
+            // Default error page
+            errorPage = errorPageSupport.find(0);
+        }
+        return errorPage;
+    }
+
+
     /**
      * Prints out an error report.
      *
-     * @param request The request being processed
-     * @param response The response being generated
-     * @param throwable The exception that occurred (which possibly wraps
-     *  a root cause exception
+     * @param request   The request being processed
+     * @param response  The response being generated
+     * @param throwable The exception that occurred (which possibly wraps a root cause exception
      */
     protected void report(Request request, Response response, Throwable throwable) {
 
@@ -166,7 +190,7 @@ public class ErrorReportValve extends ValveBase {
         // Do nothing on a 1xx, 2xx and 3xx status
         // Do nothing if anything has been written already
         // Do nothing if the response hasn't been explicitly marked as in error
-        //    and that error has not been reported.
+        // and that error has not been reported.
         if (statusCode < 400 || response.getContentWritten() > 0 || !response.setErrorReported()) {
             return;
         }
@@ -179,18 +203,7 @@ public class ErrorReportValve extends ValveBase {
             return;
         }
 
-        ErrorPage errorPage = null;
-        if (throwable != null) {
-            errorPage = errorPageSupport.find(throwable);
-        }
-        if (errorPage == null) {
-            errorPage = errorPageSupport.find(statusCode);
-        }
-        if (errorPage == null) {
-            // Default error page
-            errorPage = errorPageSupport.find(0);
-        }
-
+        ErrorPage errorPage = findErrorPage(statusCode, throwable);
 
         if (errorPage != null) {
             if (sendErrorPage(errorPage.getLocation(), response)) {
@@ -204,7 +217,7 @@ public class ErrorReportValve extends ValveBase {
         if (message == null) {
             if (throwable != null) {
                 String exceptionMessage = throwable.getMessage();
-                if (exceptionMessage != null && exceptionMessage.length() > 0) {
+                if (exceptionMessage != null && !exceptionMessage.isEmpty()) {
                     try (Scanner scanner = new Scanner(exceptionMessage)) {
                         message = Escape.htmlElementContent(scanner.nextLine());
                     }
@@ -219,8 +232,7 @@ public class ErrorReportValve extends ValveBase {
         // no error message provided
         String reason = null;
         String description = null;
-        StringManager smClient = StringManager.getManager(
-                Constants.Package, request.getLocales());
+        StringManager smClient = StringManager.getManager(Constants.Package, request.getLocales());
         response.setLocale(smClient.getLocale());
         try {
             reason = smClient.getString("http." + statusCode + ".reason");
@@ -243,16 +255,15 @@ public class ErrorReportValve extends ValveBase {
         sb.append(smClient.getLocale().getLanguage()).append("\">");
         sb.append("<head>");
         sb.append("<title>");
-        sb.append(smClient.getString("errorReportValve.statusHeader",
-                String.valueOf(statusCode), reason));
+        sb.append(smClient.getString("errorReportValve.statusHeader", String.valueOf(statusCode), reason));
         sb.append("</title>");
         sb.append("<style type=\"text/css\">");
         sb.append(TomcatCSS.TOMCAT_CSS);
         sb.append("</style>");
         sb.append("</head><body>");
         sb.append("<h1>");
-        sb.append(smClient.getString("errorReportValve.statusHeader",
-                String.valueOf(statusCode), reason)).append("</h1>");
+        sb.append(smClient.getString("errorReportValve.statusHeader", String.valueOf(statusCode), reason))
+                .append("</h1>");
         if (isShowReport()) {
             sb.append("<hr class=\"line\" />");
             sb.append("<p><b>");
@@ -318,7 +329,7 @@ public class ErrorReportValve extends ValveBase {
             } catch (Throwable t) {
                 ExceptionUtils.handleThrowable(t);
                 if (container.getLogger().isDebugEnabled()) {
-                    container.getLogger().debug("Failure to set the content-type of response", t);
+                    container.getLogger().debug(sm.getString("errorReportValve.contentTypeFail"), t);
                 }
             }
             Writer writer = response.getReporter();
@@ -336,9 +347,10 @@ public class ErrorReportValve extends ValveBase {
 
 
     /**
-     * Print out a partial servlet stack trace (truncating at the last
-     * occurrence of javax.servlet.).
+     * Print out a partial servlet stack trace (truncating at the last occurrence of javax.servlet.).
+     *
      * @param t The stack trace to process
+     *
      * @return the stack trace relative to the application layer
      */
     protected String getPartialServletStackTrace(Throwable t) {
@@ -347,16 +359,14 @@ public class ErrorReportValve extends ValveBase {
         StackTraceElement[] elements = t.getStackTrace();
         int pos = elements.length;
         for (int i = elements.length - 1; i >= 0; i--) {
-            if ((elements[i].getClassName().startsWith
-                 ("org.apache.catalina.core.ApplicationFilterChain"))
-                && (elements[i].getMethodName().equals("internalDoFilter"))) {
+            if ((elements[i].getClassName().startsWith("org.apache.catalina.core.ApplicationFilterChain")) &&
+                    (elements[i].getMethodName().equals("internalDoFilter"))) {
                 pos = i;
                 break;
             }
         }
         for (int i = 0; i < pos; i++) {
-            if (!(elements[i].getClassName().startsWith
-                  ("org.apache.catalina.core."))) {
+            if (!(elements[i].getClassName().startsWith("org.apache.catalina.core."))) {
                 trace.append('\t').append(elements[i].toString()).append(System.lineSeparator());
             }
         }
@@ -370,8 +380,7 @@ public class ErrorReportValve extends ValveBase {
             file = new File(getContainer().getCatalinaBase(), location);
         }
         if (!file.isFile() || !file.canRead()) {
-            getContainer().getLogger().warn(
-                    sm.getString("errorReportValve.errorPageNotFound", location));
+            getContainer().getLogger().warn(sm.getString("errorReportValve.errorPageNotFound", location));
             return false;
         }
 
@@ -381,11 +390,10 @@ public class ErrorReportValve extends ValveBase {
         response.setCharacterEncoding("UTF-8");
 
         try (OutputStream os = response.getOutputStream();
-                InputStream is = new FileInputStream(file);){
+             InputStream is = new FileInputStream(file)) {
             IOTools.flow(is, os);
         } catch (IOException e) {
-            getContainer().getLogger().warn(
-                    sm.getString("errorReportValve.errorPageIOException", location), e);
+            getContainer().getLogger().warn(sm.getString("errorReportValve.errorPageIOException", location), e);
             return false;
         }
 
