@@ -68,11 +68,11 @@ import org.apache.tomcat.util.ExceptionUtils;
  * remoteHost CHAR(15) NOT NULL,
  * userName CHAR(15),
  * timestamp TIMESTAMP NOT NULL,
- * virtualHost VARCHAR(64) NOT NULL,
- * method VARCHAR(8) NOT NULL,
  * query VARCHAR(255) NOT NULL,
  * status SMALLINT UNSIGNED NOT NULL,
  * bytes INT UNSIGNED NOT NULL,
+ * virtualHost VARCHAR(64) NOT NULL,
+ * method VARCHAR(8) NOT NULL,
  * referer VARCHAR(128),
  * userAgent VARCHAR(128),
  * PRIMARY KEY (id),
@@ -95,15 +95,15 @@ import org.apache.tomcat.util.ExceptionUtils;
  * If the request method is "common", only these fields are used:
  * <code>remoteHost, user, timeStamp, query, status, bytes</code>
  * </p>
- * <p>
- * <i>TO DO: provide option for excluding logging of certain MIME types.</i>
- * </p>
  *
  * @author Andre de Jesus
  * @author Peter Rossbach
+ *
+ * @deprecated Non scalable design, and not documented. Will be removed in Tomcat 12.
  */
+@Deprecated
+public class JDBCAccessLogValve extends ValveBase implements AccessLog {
 
-public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
 
     // ----------------------------------------------------------- Constructors
 
@@ -159,47 +159,47 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *
      * @since 6.0.15
      */
-    boolean useLongContentLength = false;
+    protected boolean useLongContentLength = false;
 
     /**
      * The connection username to use when trying to connect to the database.
      */
-    String connectionName = null;
+    protected String connectionName = null;
 
 
     /**
      * The connection URL to use when trying to connect to the database.
      */
-    String connectionPassword = null;
+    protected String connectionPassword = null;
 
     /**
      * Instance of the JDBC Driver class we use as a connection factory.
      */
-    Driver driver = null;
+    protected Driver driver = null;
 
 
-    private String driverName;
-    private String connectionURL;
-    private String tableName;
-    private String remoteHostField;
-    private String userField;
-    private String timestampField;
-    private String virtualHostField;
-    private String methodField;
-    private String queryField;
-    private String statusField;
-    private String bytesField;
-    private String refererField;
-    private String userAgentField;
-    private String pattern;
-    private boolean resolveHosts;
+    protected String driverName;
+    protected String connectionURL;
+    protected String tableName;
+    protected String remoteHostField;
+    protected String userField;
+    protected String timestampField;
+    protected String virtualHostField;
+    protected String methodField;
+    protected String queryField;
+    protected String statusField;
+    protected String bytesField;
+    protected String refererField;
+    protected String userAgentField;
+    protected String pattern;
+    protected boolean resolveHosts;
 
 
-    private Connection conn;
-    private PreparedStatement ps;
+    protected Connection conn;
+    protected PreparedStatement ps;
 
 
-    private long currentTimeMillis;
+    protected long currentTimeMillis;
 
     /**
      * Should this valve set request attributes for IP address, hostname, protocol and port used for the request.
@@ -207,7 +207,7 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
      *
      * @see #setRequestAttributesEnabled(boolean)
      */
-    boolean requestAttributesEnabled = true;
+    protected boolean requestAttributesEnabled = true;
 
 
     // ------------------------------------------------------------- Properties
@@ -561,6 +561,7 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
         }
         conn = driver.connect(connectionURL, props);
         conn.setAutoCommit(true);
+        prepare();
         String logPattern = pattern;
         if (logPattern.equals("common")) {
             ps = conn.prepareStatement(
@@ -574,6 +575,16 @@ public final class JDBCAccessLogValve extends ValveBase implements AccessLog {
         }
     }
 
+
+    /**
+     * Prepare tables for processing. Used by subclasses for testing.
+     *
+     * @throws SQLException if an exception occurs
+     */
+    protected void prepare() throws SQLException {
+    }
+
+
     /**
      * Close the specified database connection.
      */
