@@ -68,10 +68,10 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         String webAppMount = getWebAppMount();
 
         ArrayList<String> result = new ArrayList<>();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path
-            if (pathInJar.length() > 0 && pathInJar.charAt(0) == '/') {
+            if (!pathInJar.isEmpty() && pathInJar.charAt(0) == '/') {
                 pathInJar = pathInJar.substring(1);
             }
             for (String name : getArchiveEntries(false).keySet()) {
@@ -81,13 +81,13 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
                     } else {
                         name = name.substring(pathInJar.length());
                     }
-                    if (name.length() == 0) {
+                    if (name.isEmpty()) {
                         continue;
                     }
                     if (name.charAt(0) == '/') {
                         name = name.substring(1);
                     }
-                    if (name.length() > 0 && name.lastIndexOf('/') == -1) {
+                    if (!name.isEmpty() && name.lastIndexOf('/') == -1) {
                         result.add(name);
                     }
                 }
@@ -108,17 +108,18 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         return result.toArray(new String[0]);
     }
 
+
     @Override
     public final Set<String> listWebAppPaths(String path) {
         checkPath(path);
         String webAppMount = getWebAppMount();
 
         ResourceSet<String> result = new ResourceSet<>();
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path and make
             // sure it ends in '/'
-            if (pathInJar.length() > 0) {
+            if (!pathInJar.isEmpty()) {
                 if (pathInJar.charAt(pathInJar.length() - 1) != '/') {
                     pathInJar = pathInJar.substring(1) + '/';
                 }
@@ -225,13 +226,13 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         // If the JAR has been mounted below the web application root, return
         // an empty resource for requests outside of the mount point.
 
-        if (path.startsWith(webAppMount)) {
+        if (isPathMounted(path, webAppMount)) {
             String pathInJar = getInternalPath() + path.substring(webAppMount.length());
             // Always strip off the leading '/' to get the JAR path
-            if (pathInJar.length() > 0 && pathInJar.charAt(0) == '/') {
+            if (!pathInJar.isEmpty() && pathInJar.charAt(0) == '/') {
                 pathInJar = pathInJar.substring(1);
             }
-            if (pathInJar.equals("")) {
+            if (pathInJar.isEmpty()) {
                 // Special case
                 // This is a directory resource so the path must end with /
                 if (!path.endsWith("/")) {
@@ -293,6 +294,25 @@ public abstract class AbstractArchiveResourceSet extends AbstractResourceSet {
         throw new IllegalArgumentException(sm.getString("abstractArchiveResourceSet.setReadOnlyFalse"));
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * Calls to this method will be ignored as archives do not allow linking.
+     */
+    @Override
+    public void setAllowLinking(boolean allowLinking) {
+    }
+
+    /**
+     * {@inheritDoc}
+     * <p>
+     * Calls to this method always return {@code false} as archives do not allow linking.
+     */
+    @Override
+    public boolean getAllowLinking() {
+        return false;
+    }
+
     @SuppressWarnings("deprecation")
     protected JarFile openJarFile() throws IOException {
         synchronized (archiveLock) {
