@@ -100,7 +100,7 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
     /**
      * Underlying input buffer.
      */
-    private InputBuffer inputStreamInputBuffer;
+    private final InputBuffer inputStreamInputBuffer;
 
 
     /**
@@ -122,15 +122,15 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
 
 
     /**
-     * Parsing state - used for non blocking parsing so that when more data arrives, we can pick up where we left off.
+     * Parsing state - used for non-blocking parsing so that when more data arrives, we can pick up where we left off.
      */
     private byte prevChr = 0;
     private byte chr = 0;
     private volatile boolean parsingRequestLine;
-    private int parsingRequestLinePhase = 0;
-    private boolean parsingRequestLineEol = false;
-    private int parsingRequestLineStart = 0;
-    private int parsingRequestLineQPos = -1;
+    private int parsingRequestLinePhase;
+    private boolean parsingRequestLineEol;
+    private int parsingRequestLineStart;
+    private int parsingRequestLineQPos;
     private HeaderParsePosition headerParsePos;
     private final HeaderParseData headerData = new HeaderParseData();
     private final HttpParser httpParser;
@@ -140,12 +140,6 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
      */
     private final int headerBufferSize;
 
-    /**
-     * Known size of the NioChannel read buffer.
-     */
-    private int socketReadBufferSize;
-
-
     // ----------------------------------------------------------- Constructors
 
     public Http11InputBuffer(Request request, int headerBufferSize, boolean rejectIllegalHeader,
@@ -259,7 +253,10 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
             activeFilters[i].recycle();
         }
 
-        byteBuffer.limit(0).position(0);
+        // Avoid rare NPE reported on users@ list
+        if (byteBuffer != null) {
+            byteBuffer.limit(0).position(0);
+        }
         lastActiveFilter = -1;
         swallowInput = true;
 
@@ -587,20 +584,12 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
             throw new IllegalStateException(sm.getString("iib.parseheaders.ise.error"));
         }
 
-        HeaderParseStatus status = HeaderParseStatus.HAVE_MORE_HEADERS;
+        HeaderParseStatus status;
 
         do {
             status = parseHeader();
-            // Checking that
-            // (1) Headers plus request line size does not exceed its limit
-            // (2) There are enough bytes to avoid expanding the buffer when
-            // reading body
-            // Technically, (2) is technical limitation, (1) is logical
-            // limitation to enforce the meaning of headerBufferSize
-            // From the way how buf is allocated and how blank lines are being
-            // read, it should be enough to check (1) only.
-            if (byteBuffer.position() > headerBufferSize ||
-                    byteBuffer.capacity() - byteBuffer.position() < socketReadBufferSize) {
+            // Checking that headers plus request line size does not exceed its limit
+            if (byteBuffer.position() > headerBufferSize) {
                 throw new IllegalArgumentException(sm.getString("iib.requestheadertoolarge.error"));
             }
         } while (status == HeaderParseStatus.HAVE_MORE_HEADERS);
@@ -781,7 +770,7 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
             byteBuffer.limit(end).position(end);
         }
 
-        int nRead = -1;
+        int nRead;
         int mark = byteBuffer.position();
         try {
             if (byteBuffer.position() < byteBuffer.limit()) {
@@ -1240,6 +1229,5 @@ public class Http11InputBuffer implements InputBuffer, ApplicationBufferHandler
         temp.put(byteBuffer);
         byteBuffer = temp;
         byteBuffer.mark();
-        temp = null;
     }
 }
