@@ -113,7 +113,7 @@ public class Http2Protocol implements UpgradeProtocol {
     // Reference to HTTP/1.1 protocol that this instance is configured under
     private AbstractHttp11Protocol<?> http11Protocol = null;
 
-    private RequestGroupInfo global = new RequestGroupInfo();
+    private final RequestGroupInfo global = new RequestGroupInfo();
 
     /*
      * Setting discardRequestsAndResponses can have a significant performance impact. The magnitude of the impact is
@@ -148,11 +148,9 @@ public class Http2Protocol implements UpgradeProtocol {
 
     @Override
     public Processor getProcessor(SocketWrapperBase<?> socketWrapper, Adapter adapter) {
-        String upgradeProtocol = getUpgradeProtocolName();
-        UpgradeProcessorInternal processor = new UpgradeProcessorInternal(socketWrapper,
-                new UpgradeToken(getInternalUpgradeHandler(socketWrapper, adapter, null), null, null, upgradeProtocol),
-                null);
-        return processor;
+        return new UpgradeProcessorInternal(socketWrapper,
+                new UpgradeToken(getInternalUpgradeHandler(socketWrapper, adapter, null), null,
+                    null, getUpgradeProtocolName()),null);
     }
 
 
@@ -366,11 +364,7 @@ public class Http2Protocol implements UpgradeProtocol {
 
 
     public void setOverheadResetFactor(int overheadResetFactor) {
-        if (overheadResetFactor < 0) {
-            this.overheadResetFactor = 0;
-        } else {
-            this.overheadResetFactor = overheadResetFactor;
-        }
+        this.overheadResetFactor = Math.max(overheadResetFactor, 0);
     }
 
 
@@ -497,7 +491,7 @@ public class Http2Protocol implements UpgradeProtocol {
             ObjectName oname = this.http11Protocol.getONameForUpgrade(getUpgradeProtocolName());
             // This can be null when running the testsuite
             if (oname != null) {
-                Registry.getRegistry(null, null).registerComponent(global, oname, null);
+                Registry.getRegistry(null).registerComponent(global, oname, null);
             }
         } catch (Exception e) {
             log.warn(sm.getString("http2Protocol.jmxRegistration.fail"), e);
@@ -544,7 +538,6 @@ public class Http2Protocol implements UpgradeProtocol {
 
 
     void pushRequestAndResponse(Request requestAndResponse) {
-        requestAndResponse.recycle();
         if (!discardRequestsAndResponses) {
             recycledRequestsAndResponses.push(requestAndResponse);
         }
