@@ -32,27 +32,25 @@ import org.apache.jasper.JasperException;
 import org.apache.tomcat.util.security.PrivilegedGetTccl;
 
 /**
- * This class generates functions mappers for the EL expressions in the page.
- * Instead of a global mapper, a mapper is used for each call to EL
- * evaluator, thus avoiding the prefix overlapping and redefinition
- * issues.
+ * This class generates functions mappers for the EL expressions in the page. Instead of a global mapper, a mapper is
+ * used for each call to EL evaluator, thus avoiding the prefix overlapping and redefinition issues.
  *
  * @author Kin-man Chung
  */
 
 public class ELFunctionMapper {
     private int currFunc = 0;
-    private StringBuilder ds;  // Contains codes to initialize the functions mappers.
-    private StringBuilder ss;  // Contains declarations of the functions mappers.
+    private StringBuilder ds; // Contains codes to initialize the functions mappers.
+    private StringBuilder ss; // Contains declarations of the functions mappers.
 
     /**
      * Creates the functions mappers for all EL expressions in the JSP page.
      *
      * @param page The current compilation unit.
+     *
      * @throws JasperException EL error
      */
-    public static void map(Node.Nodes page)
-                throws JasperException {
+    public static void map(Node.Nodes page) throws JasperException {
 
         ELFunctionMapper map = new ELFunctionMapper();
         map.ds = new StringBuilder();
@@ -62,26 +60,24 @@ public class ELFunctionMapper {
 
         // Append the declarations to the root node
         String ds = map.ds.toString();
-        if (ds.length() > 0) {
+        if (!ds.isEmpty()) {
             Node root = page.getRoot();
             @SuppressWarnings("unused")
             Node unused = new Node.Declaration(map.ss.toString(), null, root);
-            unused = new Node.Declaration(
-                    "static {\n" + ds + "}\n", null, root);
+            unused = new Node.Declaration("static {\n" + ds + "}\n", null, root);
         }
     }
 
     /**
-     * A visitor for the page.  The places where EL is allowed are scanned
-     * for functions, and if found functions mappers are created.
+     * A visitor for the page. The places where EL is allowed are scanned for functions, and if found functions mappers
+     * are created.
      */
     private class ELFunctionVisitor extends Node.Visitor {
 
         /**
-         * Use a global name map to facilitate reuse of function maps.
-         * The key used is prefix:function:uri.
+         * Use a global name map to facilitate reuse of function maps. The key used is prefix:function:uri.
          */
-        private final Map<String, String> gMap = new HashMap<>();
+        private final Map<String,String> gMap = new HashMap<>();
 
         @Override
         public void visit(Node.ParamAction n) throws JasperException {
@@ -155,8 +151,7 @@ public class ELFunctionMapper {
             doMap(n.getEL());
         }
 
-        private void doMap(Node.JspAttribute attr)
-                throws JasperException {
+        private void doMap(Node.JspAttribute attr) throws JasperException {
             if (attr != null) {
                 doMap(attr.getEL());
             }
@@ -165,13 +160,13 @@ public class ELFunctionMapper {
         /**
          * Creates function mappers, if needed, from ELNodes
          */
-        private void doMap(ELNode.Nodes el)
-                throws JasperException {
+        private void doMap(ELNode.Nodes el) throws JasperException {
 
             // Only care about functions in ELNode's
             class Fvisitor extends ELNode.Visitor {
                 private final List<ELNode.Function> funcs = new ArrayList<>();
                 private final Set<String> keySet = new HashSet<>();
+
                 @Override
                 public void visit(ELNode.Function n) throws JasperException {
                     String key = n.getPrefix() + ":" + n.getName();
@@ -190,7 +185,7 @@ public class ELFunctionMapper {
             el.visit(fv);
             List<ELNode.Function> functions = fv.funcs;
 
-            if (functions.size() == 0) {
+            if (functions.isEmpty()) {
                 return;
             }
 
@@ -203,13 +198,13 @@ public class ELFunctionMapper {
 
             // Generate declaration for the map statically
             decName = getMapName();
-            ss.append("private static org.apache.jasper.runtime.ProtectedFunctionMapper " + decName + ";\n");
+            ss.append("private static org.apache.jasper.runtime.ProtectedFunctionMapper ").append(decName).append(";\n");
 
-            ds.append("  " + decName + "= ");
+            ds.append("  ").append(decName).append("= ");
             ds.append("org.apache.jasper.runtime.ProtectedFunctionMapper");
 
             // Special case if there is only one function in the map
-            String funcMethod = null;
+            String funcMethod;
             if (functions.size() == 1) {
                 funcMethod = ".getMapForFunction";
             } else {
@@ -224,20 +219,19 @@ public class ELFunctionMapper {
                 if (funcInfo == null) {
                     // Added via Lambda or ImportHandler. EL will expect a
                     // function mapper even if one isn't used so just pass null
-                    ds.append(funcMethod + "(null, null, null, null);\n");
+                    ds.append(funcMethod).append("(null, null, null, null);\n");
                 } else {
-                    ds.append(funcMethod + "(\"" + fnQName + "\", " +
-                            getCanonicalName(funcInfo.getFunctionClass()) +
-                            ".class, " + '\"' + f.getMethodName() + "\", " +
-                            "new Class[] {");
-                    String params[] = f.getParameters();
+                    ds.append(funcMethod).append("(\"").append(fnQName).append("\", ");
+                    ds.append(getCanonicalName(funcInfo.getFunctionClass())).append(".class, ").append('\"');
+                    ds.append(f.getMethodName()).append("\", ").append("new Class[] {");
+                    String[] params = f.getParameters();
                     for (int k = 0; k < params.length; k++) {
                         if (k != 0) {
                             ds.append(", ");
                         }
                         int iArray = params[k].indexOf('[');
                         if (iArray < 0) {
-                            ds.append(params[k] + ".class");
+                            ds.append(params[k]).append(".class");
                         } else {
                             String baseType = params[k].substring(0, iArray);
                             ds.append("java.lang.reflect.Array.newInstance(");
@@ -246,7 +240,7 @@ public class ELFunctionMapper {
 
                             // Count the number of array dimension
                             int aCount = 0;
-                            for (int jj = iArray; jj < params[k].length(); jj++ ) {
+                            for (int jj = iArray; jj < params[k].length(); jj++) {
                                 if (params[k].charAt(jj) == '[') {
                                     aCount++;
                                 }
@@ -254,7 +248,7 @@ public class ELFunctionMapper {
                             if (aCount == 1) {
                                 ds.append("0).getClass()");
                             } else {
-                                ds.append("new int[" + aCount + "]).getClass()");
+                                ds.append("new int[").append(aCount).append("]).getClass()");
                             }
                         }
                     }
@@ -267,19 +261,17 @@ public class ELFunctionMapper {
         }
 
         /**
-         * Find the name of the function mapper for an EL.  Reuse a
-         * previously generated one if possible.
-         * @param functions A List of ELNode.Function instances that
-         *                  represents the functions in an EL
-         * @return A previous generated function mapper name that can be used
-         *         by this EL; null if none found.
+         * Find the name of the function mapper for an EL. Reuse a previously generated one if possible.
+         *
+         * @param functions A List of ELNode.Function instances that represents the functions in an EL
+         *
+         * @return A previous generated function mapper name that can be used by this EL; null if none found.
          */
         private String matchMap(List<ELNode.Function> functions) {
 
             String mapName = null;
             for (ELNode.Function f : functions) {
-                String temName = gMap.get(f.getPrefix() + ':' + f.getName() +
-                        ':' + f.getUri());
+                String temName = gMap.get(f.getPrefix() + ':' + f.getName() + ':' + f.getUri());
                 if (temName == null) {
                     return null;
                 }
@@ -301,21 +293,22 @@ public class ELFunctionMapper {
         }
 
         /**
-         * Convert a binary class name into a canonical one that can be used
-         * when generating Java source code.
+         * Convert a binary class name into a canonical one that can be used when generating Java source code.
          *
          * @param className Binary class name
-         * @return          Canonical equivalent
+         *
+         * @return Canonical equivalent
          */
         private String getCanonicalName(String className) throws JasperException {
             Class<?> clazz;
 
             ClassLoader tccl;
+            Thread currentThread = Thread.currentThread();
             if (Constants.IS_SECURITY_ENABLED) {
-                PrivilegedAction<ClassLoader> pa = new PrivilegedGetTccl();
+                PrivilegedAction<ClassLoader> pa = new PrivilegedGetTccl(currentThread);
                 tccl = AccessController.doPrivileged(pa);
             } else {
-                tccl = Thread.currentThread().getContextClassLoader();
+                tccl = currentThread.getContextClassLoader();
             }
 
             try {
