@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.jasper.compiler;
 
 import java.io.IOException;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
-import java.util.Vector;
 
 import javax.el.MethodExpression;
 import javax.el.ValueExpression;
@@ -41,66 +41,50 @@ import org.apache.tomcat.Jar;
 import org.apache.tomcat.util.descriptor.tld.TldResourcePath;
 
 /**
- * 1. Processes and extracts the directive info in a tag file. 2. Compiles and
- * loads tag files used in a JSP file.
+ * 1. Processes and extracts the directive info in a tag file. 2. Compiles and loads tag files used in a JSP file.
  *
  * @author Kin-man Chung
  */
 
-class TagFileProcessor {
+public class TagFileProcessor {
 
-    private Vector<Compiler> tempVector;
+    private List<Compiler> tempVector;
 
     /**
      * A visitor the tag file
      */
     private static class TagFileDirectiveVisitor extends Node.Visitor {
 
-        private static final JspUtil.ValidAttribute[] tagDirectiveAttrs = {
-                new JspUtil.ValidAttribute("display-name"),
-                new JspUtil.ValidAttribute("body-content"),
-                new JspUtil.ValidAttribute("dynamic-attributes"),
-                new JspUtil.ValidAttribute("small-icon"),
-                new JspUtil.ValidAttribute("large-icon"),
-                new JspUtil.ValidAttribute("description"),
-                new JspUtil.ValidAttribute("example"),
-                new JspUtil.ValidAttribute("pageEncoding"),
-                new JspUtil.ValidAttribute("language"),
-                new JspUtil.ValidAttribute("import"),
-                new JspUtil.ValidAttribute("deferredSyntaxAllowedAsLiteral"), // JSP 2.1
-                new JspUtil.ValidAttribute("trimDirectiveWhitespaces"), // JSP 2.1
-                new JspUtil.ValidAttribute("isELIgnored") };
+        private static final JspUtil.ValidAttribute[] tagDirectiveAttrs = { new JspUtil.ValidAttribute("display-name"),
+                new JspUtil.ValidAttribute("body-content"), new JspUtil.ValidAttribute("dynamic-attributes"),
+                new JspUtil.ValidAttribute("small-icon"), new JspUtil.ValidAttribute("large-icon"),
+                new JspUtil.ValidAttribute("description"), new JspUtil.ValidAttribute("example"),
+                new JspUtil.ValidAttribute("pageEncoding"), new JspUtil.ValidAttribute("language"),
+                new JspUtil.ValidAttribute("import"), new JspUtil.ValidAttribute("deferredSyntaxAllowedAsLiteral"),
+                new JspUtil.ValidAttribute("trimDirectiveWhitespaces"), new JspUtil.ValidAttribute("isELIgnored") };
 
         private static final JspUtil.ValidAttribute[] attributeDirectiveAttrs = {
-                new JspUtil.ValidAttribute("name", true),
-                new JspUtil.ValidAttribute("required"),
-                new JspUtil.ValidAttribute("fragment"),
-                new JspUtil.ValidAttribute("rtexprvalue"),
-                new JspUtil.ValidAttribute("type"),
-                new JspUtil.ValidAttribute("deferredValue"),            // JSP 2.1
-                new JspUtil.ValidAttribute("deferredValueType"),        // JSP 2.1
-                new JspUtil.ValidAttribute("deferredMethod"),           // JSP 2
-                new JspUtil.ValidAttribute("deferredMethodSignature"),  // JSP 21
-                new JspUtil.ValidAttribute("description") };
+                new JspUtil.ValidAttribute("name", true), new JspUtil.ValidAttribute("required"),
+                new JspUtil.ValidAttribute("fragment"), new JspUtil.ValidAttribute("rtexprvalue"),
+                new JspUtil.ValidAttribute("type"), new JspUtil.ValidAttribute("deferredValue"),
+                new JspUtil.ValidAttribute("deferredValueType"), new JspUtil.ValidAttribute("deferredMethod"),
+                new JspUtil.ValidAttribute("deferredMethodSignature"), new JspUtil.ValidAttribute("description") };
 
-        private static final JspUtil.ValidAttribute[] variableDirectiveAttrs = {
-                new JspUtil.ValidAttribute("name-given"),
-                new JspUtil.ValidAttribute("name-from-attribute"),
-                new JspUtil.ValidAttribute("alias"),
-                new JspUtil.ValidAttribute("variable-class"),
-                new JspUtil.ValidAttribute("scope"),
-                new JspUtil.ValidAttribute("declare"),
-                new JspUtil.ValidAttribute("description") };
+        private static final JspUtil.ValidAttribute[] variableDirectiveAttrs =
+                { new JspUtil.ValidAttribute("name-given"), new JspUtil.ValidAttribute("name-from-attribute"),
+                        new JspUtil.ValidAttribute("alias"), new JspUtil.ValidAttribute("variable-class"),
+                        new JspUtil.ValidAttribute("scope"), new JspUtil.ValidAttribute("declare"),
+                        new JspUtil.ValidAttribute("description") };
 
-        private ErrorDispatcher err;
+        private final ErrorDispatcher err;
 
-        private TagLibraryInfo tagLibInfo;
+        private final TagLibraryInfo tagLibInfo;
 
-        private String name = null;
+        private final String name;
 
-        private String path = null;
+        private final String path;
 
-        private String bodycontent = null;
+        private String bodyContent = null;
 
         private String description = null;
 
@@ -114,9 +98,9 @@ class TagFileProcessor {
 
         private String example = null;
 
-        private Vector<TagAttributeInfo> attributeVector;
+        private final List<TagAttributeInfo> attributeList;
 
-        private Vector<TagVariableInfo> variableVector;
+        private final List<TagVariableInfo> variableList;
 
         private static final String ATTR_NAME = "the name attribute of the attribute directive";
 
@@ -128,18 +112,17 @@ class TagFileProcessor {
 
         private static final String TAG_DYNAMIC = "the dynamic-attributes attribute of the tag directive";
 
-        private Map<String,NameEntry> nameTable = new HashMap<>();
+        private final Map<String,NameEntry> nameTable = new HashMap<>();
 
-        private Map<String,NameEntry> nameFromTable = new HashMap<>();
+        private final Map<String,NameEntry> nameFromTable = new HashMap<>();
 
-        public TagFileDirectiveVisitor(Compiler compiler,
-                TagLibraryInfo tagLibInfo, String name, String path) {
+        TagFileDirectiveVisitor(Compiler compiler, TagLibraryInfo tagLibInfo, String name, String path) {
             err = compiler.getErrorDispatcher();
             this.tagLibInfo = tagLibInfo;
             this.name = name;
             this.path = path;
-            attributeVector = new Vector<>();
-            variableVector = new Vector<>();
+            attributeList = new ArrayList<>();
+            variableList = new ArrayList<>();
         }
 
         @Override
@@ -147,19 +130,13 @@ class TagFileProcessor {
 
             JspUtil.checkAttributes("Tag directive", n, tagDirectiveAttrs, err);
 
-            bodycontent = checkConflict(n, bodycontent, "body-content");
-            if (bodycontent != null
-                    && !bodycontent
-                            .equalsIgnoreCase(TagInfo.BODY_CONTENT_EMPTY)
-                    && !bodycontent
-                            .equalsIgnoreCase(TagInfo.BODY_CONTENT_TAG_DEPENDENT)
-                    && !bodycontent
-                            .equalsIgnoreCase(TagInfo.BODY_CONTENT_SCRIPTLESS)) {
-                err.jspError(n, "jsp.error.tagdirective.badbodycontent",
-                        bodycontent);
+            bodyContent = checkConflict(n, bodyContent, "body-content");
+            if (bodyContent != null && !bodyContent.equalsIgnoreCase(TagInfo.BODY_CONTENT_EMPTY) &&
+                    !bodyContent.equalsIgnoreCase(TagInfo.BODY_CONTENT_TAG_DEPENDENT) &&
+                    !bodyContent.equalsIgnoreCase(TagInfo.BODY_CONTENT_SCRIPTLESS)) {
+                err.jspError(n, "jsp.error.tagdirective.badbodycontent", bodyContent);
             }
-            dynamicAttrsMapName = checkConflict(n, dynamicAttrsMapName,
-                    "dynamic-attributes");
+            dynamicAttrsMapName = checkConflict(n, dynamicAttrsMapName, "dynamic-attributes");
             if (dynamicAttrsMapName != null) {
                 checkUniqueName(dynamicAttrsMapName, TAG_DYNAMIC, n);
             }
@@ -170,15 +147,13 @@ class TagFileProcessor {
             example = checkConflict(n, example, "example");
         }
 
-        private String checkConflict(Node n, String oldAttrValue, String attr)
-                throws JasperException {
+        private String checkConflict(Node n, String oldAttrValue, String attr) throws JasperException {
 
             String result = oldAttrValue;
             String attrValue = n.getAttributeValue(attr);
             if (attrValue != null) {
                 if (oldAttrValue != null && !oldAttrValue.equals(attrValue)) {
-                    err.jspError(n, "jsp.error.tag.conflict.attr", attr,
-                            oldAttrValue, attrValue);
+                    err.jspError(n, "jsp.error.tag.conflict.attr", attr, oldAttrValue, attrValue);
                 }
                 result = attrValue;
             }
@@ -188,8 +163,7 @@ class TagFileProcessor {
         @Override
         public void visit(Node.AttributeDirective n) throws JasperException {
 
-            JspUtil.checkAttributes("Attribute directive", n,
-                    attributeDirectiveAttrs, err);
+            JspUtil.checkAttributes("Attribute directive", n, attributeDirectiveAttrs, err);
 
             // JSP 2.1 Table JSP.8-3
             // handle deferredValue and deferredValueType
@@ -222,8 +196,7 @@ class TagFileProcessor {
                 deferredMethodSpecified = true;
                 deferredMethod = JspUtil.booleanValue(deferredMethodString);
             }
-            String deferredMethodSignature = n
-                    .getAttributeValue("deferredMethodSignature");
+            String deferredMethodSignature = n.getAttributeValue("deferredMethodSignature");
             if (deferredMethodSignature != null) {
                 if (deferredMethodSpecified && !deferredMethod) {
                     err.jspError(n, "jsp.error.deferredmethodsignaturewithoutdeferredmethod");
@@ -239,15 +212,13 @@ class TagFileProcessor {
             }
 
             String attrName = n.getAttributeValue("name");
-            boolean required = JspUtil.booleanValue(n
-                    .getAttributeValue("required"));
+            boolean required = JspUtil.booleanValue(n.getAttributeValue("required"));
             boolean rtexprvalue = true;
             String rtexprvalueString = n.getAttributeValue("rtexprvalue");
             if (rtexprvalueString != null) {
                 rtexprvalue = JspUtil.booleanValue(rtexprvalueString);
             }
-            boolean fragment = JspUtil.booleanValue(n
-                    .getAttributeValue("fragment"));
+            boolean fragment = JspUtil.booleanValue(n.getAttributeValue("fragment"));
             String type = n.getAttributeValue("type");
             if (fragment) {
                 // type is fixed to "JspFragment" and a translation error
@@ -262,8 +233,9 @@ class TagFileProcessor {
                     err.jspError(n, "jsp.error.frgmentwithrtexprvalue");
                 }
             } else {
-                if (type == null)
+                if (type == null) {
                     type = "java.lang.String";
+                }
 
                 if (deferredValue) {
                     type = ValueExpression.class.getName();
@@ -272,28 +244,24 @@ class TagFileProcessor {
                 }
             }
 
-            if (("2.0".equals(tagLibInfo.getRequiredVersion()) || ("1.2".equals(tagLibInfo.getRequiredVersion())))
-                    && (deferredMethodSpecified || deferredMethod
-                            || deferredValueSpecified || deferredValue)) {
+            if (("2.0".equals(tagLibInfo.getRequiredVersion()) || ("1.2".equals(tagLibInfo.getRequiredVersion()))) &&
+                    (deferredMethodSpecified || deferredMethod || deferredValueSpecified || deferredValue)) {
                 err.jspError("jsp.error.invalid.version", path);
             }
 
-            TagAttributeInfo tagAttributeInfo = new TagAttributeInfo(attrName,
-                    required, type, rtexprvalue, fragment, null, deferredValue,
-                    deferredMethod, deferredValueType, deferredMethodSignature);
-            attributeVector.addElement(tagAttributeInfo);
+            TagAttributeInfo tagAttributeInfo = new TagAttributeInfo(attrName, required, type, rtexprvalue, fragment,
+                    null, deferredValue, deferredMethod, deferredValueType, deferredMethodSignature);
+            attributeList.add(tagAttributeInfo);
             checkUniqueName(attrName, ATTR_NAME, n, tagAttributeInfo);
         }
 
         @Override
         public void visit(Node.VariableDirective n) throws JasperException {
 
-            JspUtil.checkAttributes("Variable directive", n,
-                    variableDirectiveAttrs, err);
+            JspUtil.checkAttributes("Variable directive", n, variableDirectiveAttrs, err);
 
             String nameGiven = n.getAttributeValue("name-given");
-            String nameFromAttribute = n
-                    .getAttributeValue("name-from-attribute");
+            String nameFromAttribute = n.getAttributeValue("name-from-attribute");
             if (nameGiven == null && nameFromAttribute == null) {
                 err.jspError("jsp.error.variable.either.name");
             }
@@ -303,19 +271,20 @@ class TagFileProcessor {
             }
 
             String alias = n.getAttributeValue("alias");
-            if (nameFromAttribute != null && alias == null
-                    || nameFromAttribute == null && alias != null) {
+            if (nameFromAttribute != null && alias == null || nameFromAttribute == null && alias != null) {
                 err.jspError("jsp.error.variable.alias");
             }
 
             String className = n.getAttributeValue("variable-class");
-            if (className == null)
+            if (className == null) {
                 className = "java.lang.String";
+            }
 
             String declareStr = n.getAttributeValue("declare");
             boolean declare = true;
-            if (declareStr != null)
+            if (declareStr != null) {
                 declare = JspUtil.booleanValue(declareStr);
+            }
 
             int scope = VariableInfo.NESTED;
             String scopeStr = n.getAttributeValue("scope");
@@ -331,9 +300,8 @@ class TagFileProcessor {
 
             if (nameFromAttribute != null) {
                 /*
-                 * An alias has been specified. We use 'nameGiven' to hold the
-                 * value of the alias, and 'nameFromAttribute' to hold the name
-                 * of the attribute whose value (at invocation-time) denotes the
+                 * An alias has been specified. We use 'nameGiven' to hold the value of the alias, and
+                 * 'nameFromAttribute' to hold the name of the attribute whose value (at invocation-time) denotes the
                  * name of the variable that is being aliased
                  */
                 nameGiven = alias;
@@ -344,8 +312,7 @@ class TagFileProcessor {
                 checkUniqueName(nameGiven, VAR_NAME_GIVEN, n);
             }
 
-            variableVector.addElement(new TagVariableInfo(nameGiven,
-                    nameFromAttribute, className, declare, scope));
+            variableList.add(new TagVariableInfo(nameGiven, nameFromAttribute, className, declare, scope));
         }
 
         public TagInfo getTagInfo() throws JasperException {
@@ -354,33 +321,25 @@ class TagFileProcessor {
                 // XXX Get it from tag file name
             }
 
-            if (bodycontent == null) {
-                bodycontent = TagInfo.BODY_CONTENT_SCRIPTLESS;
+            if (bodyContent == null) {
+                bodyContent = TagInfo.BODY_CONTENT_SCRIPTLESS;
             }
 
-            String tagClassName = JspUtil.getTagHandlerClassName(
-                    path, tagLibInfo.getReliableURN(), err);
+            String tagClassName = JspUtil.getTagHandlerClassName(path, tagLibInfo.getReliableURN(), err);
 
-            TagVariableInfo[] tagVariableInfos = new TagVariableInfo[variableVector
-                    .size()];
-            variableVector.copyInto(tagVariableInfos);
+            TagVariableInfo[] tagVariableInfos = variableList.toArray(new TagVariableInfo[0]);
+            TagAttributeInfo[] tagAttributeInfo = attributeList.toArray(new TagAttributeInfo[0]);
 
-            TagAttributeInfo[] tagAttributeInfo = new TagAttributeInfo[attributeVector
-                    .size()];
-            attributeVector.copyInto(tagAttributeInfo);
-
-            return new JasperTagInfo(name, tagClassName, bodycontent,
-                    description, tagLibInfo, null, tagAttributeInfo,
-                    displayName, smallIcon, largeIcon, tagVariableInfos,
-                    dynamicAttrsMapName);
+            return new JasperTagInfo(name, tagClassName, bodyContent, description, tagLibInfo, null, tagAttributeInfo,
+                    displayName, smallIcon, largeIcon, tagVariableInfos, dynamicAttrsMapName);
         }
 
         static class NameEntry {
-            private String type;
+            private final String type;
 
-            private Node node;
+            private final Node node;
 
-            private TagAttributeInfo attr;
+            private final TagAttributeInfo attr;
 
             NameEntry(String type, Node node, TagAttributeInfo attr) {
                 this.type = type;
@@ -401,36 +360,31 @@ class TagFileProcessor {
             }
         }
 
-        /**
-         * Reports a translation error if names specified in attributes of
-         * directives are not unique in this translation unit.
+        /*
+         * Reports a translation error if names specified in attributes of directives are not unique in this translation
+         * unit.
          *
-         * The value of the following attributes must be unique. 1. 'name'
-         * attribute of an attribute directive 2. 'name-given' attribute of a
-         * variable directive 3. 'alias' attribute of variable directive 4.
-         * 'dynamic-attributes' of a tag directive except that
-         * 'dynamic-attributes' can (and must) have the same value when it
-         * appears in multiple tag directives.
+         * The value of the following attributes must be unique. 1. 'name' attribute of an attribute directive 2.
+         * 'name-given' attribute of a variable directive 3. 'alias' attribute of variable directive 4.
+         * 'dynamic-attributes' of a tag directive except that 'dynamic-attributes' can (and must) have the same value
+         * when it appears in multiple tag directives.
          *
-         * Also, 'name-from' attribute of a variable directive cannot have the
-         * same value as that from another variable directive.
+         * Also, 'name-from' attribute of a variable directive cannot have the same value as that from another variable
+         * directive.
          */
-        private void checkUniqueName(String name, String type, Node n)
-                throws JasperException {
+        private void checkUniqueName(String name, String type, Node n) throws JasperException {
             checkUniqueName(name, type, n, null);
         }
 
-        private void checkUniqueName(String name, String type, Node n,
-                TagAttributeInfo attr) throws JasperException {
+        private void checkUniqueName(String name, String type, Node n, TagAttributeInfo attr) throws JasperException {
 
-            Map<String, NameEntry> table = (VAR_NAME_FROM.equals(type)) ? nameFromTable : nameTable;
+            Map<String,NameEntry> table = (VAR_NAME_FROM.equals(type)) ? nameFromTable : nameTable;
             NameEntry nameEntry = table.get(name);
             if (nameEntry != null) {
-                if (!TAG_DYNAMIC.equals(type) ||
-                        !TAG_DYNAMIC.equals(nameEntry.getType())) {
+                if (!TAG_DYNAMIC.equals(type) || !TAG_DYNAMIC.equals(nameEntry.getType())) {
                     int line = nameEntry.getNode().getStart().getLineNumber();
-                    err.jspError(n, "jsp.error.tagfile.nameNotUnique", type,
-                            nameEntry.getType(), Integer.toString(line));
+                    err.jspError(n, "jsp.error.tagfile.nameNotUnique", type, nameEntry.getType(),
+                            Integer.toString(line));
                 }
             } else {
                 table.put(name, new NameEntry(type, n, attr));
@@ -442,24 +396,20 @@ class TagFileProcessor {
          */
         void postCheck() throws JasperException {
             // Check that var.name-from-attributes has valid values.
-            for (Entry<String, NameEntry> entry : nameFromTable.entrySet()) {
+            for (Entry<String,NameEntry> entry : nameFromTable.entrySet()) {
                 String key = entry.getKey();
                 NameEntry nameEntry = nameTable.get(key);
                 NameEntry nameFromEntry = entry.getValue();
                 Node nameFromNode = nameFromEntry.getNode();
                 if (nameEntry == null) {
-                    err.jspError(nameFromNode,
-                            "jsp.error.tagfile.nameFrom.noAttribute", key);
+                    err.jspError(nameFromNode, "jsp.error.tagfile.nameFrom.noAttribute", key);
                 } else {
                     Node node = nameEntry.getNode();
                     TagAttributeInfo tagAttr = nameEntry.getTagAttributeInfo();
-                    if (!"java.lang.String".equals(tagAttr.getTypeName())
-                            || !tagAttr.isRequired()
-                            || tagAttr.canBeRequestTime()) {
-                        err.jspError(nameFromNode,
-                                "jsp.error.tagfile.nameFrom.badAttribute",
-                                key, Integer.toString(node.getStart()
-                                        .getLineNumber()));
+                    if (!"java.lang.String".equals(tagAttr.getTypeName()) || !tagAttr.isRequired() ||
+                            tagAttr.canBeRequestTime()) {
+                        err.jspError(nameFromNode, "jsp.error.tagfile.nameFrom.badAttribute", key,
+                                Integer.toString(node.getStart().getLineNumber()));
                     }
                 }
             }
@@ -467,29 +417,22 @@ class TagFileProcessor {
     }
 
     /**
-     * Parses the tag file, and collects information on the directives included
-     * in it. The method is used to obtain the info on the tag file, when the
-     * handler that it represents is referenced. The tag file is not compiled
-     * here.
+     * Parses the tag file, and collects information on the directives included in it. The method is used to obtain the
+     * info on the tag file, when the handler that it represents is referenced. The tag file is not compiled here.
+     *
+     * @param pc         the current ParserController used in this compilation
+     * @param name       the tag name as specified in the TLD
+     * @param path       the path for the tagfile
+     * @param jar        the Jar resource containing the tag file
+     * @param tagLibInfo the TagLibraryInfo object associated with this TagInfo
      *
-     * @param pc
-     *            the current ParserController used in this compilation
-     * @param name
-     *            the tag name as specified in the TLD
-     * @param path
-     *            the path for the tagfile
-     * @param jar
-     *            the Jar resource containing the tag file
-     * @param tagLibInfo
-     *            the TagLibraryInfo object associated with this TagInfo
      * @return a TagInfo object assembled from the directives in the tag file.
      *
      * @throws JasperException If an error occurs during parsing
      */
     @SuppressWarnings("null") // page can't be null
-    public static TagInfo parseTagFileDirectives(ParserController pc,
-            String name, String path, Jar jar, TagLibraryInfo tagLibInfo)
-            throws JasperException {
+    public static TagInfo parseTagFileDirectives(ParserController pc, String name, String path, Jar jar,
+            TagLibraryInfo tagLibInfo) throws JasperException {
 
 
         ErrorDispatcher err = pc.getCompiler().getErrorDispatcher();
@@ -501,8 +444,7 @@ class TagFileProcessor {
             err.jspError("jsp.error.file.not.found", path);
         }
 
-        TagFileDirectiveVisitor tagFileVisitor = new TagFileDirectiveVisitor(pc
-                .getCompiler(), tagLibInfo, name, path);
+        TagFileDirectiveVisitor tagFileVisitor = new TagFileDirectiveVisitor(pc.getCompiler(), tagLibInfo, name, path);
         page.visit(tagFileVisitor);
         tagFileVisitor.postCheck();
 
@@ -512,16 +454,16 @@ class TagFileProcessor {
     /**
      * Compiles and loads a tagfile.
      */
-    private Class<?> loadTagFile(Compiler compiler, String tagFilePath,
-            TagInfo tagInfo, PageInfo parentPageInfo) throws JasperException {
+    private Class<?> loadTagFile(Compiler compiler, String tagFilePath, TagInfo tagInfo, PageInfo parentPageInfo)
+            throws JasperException {
 
         Jar tagJar = null;
         Jar tagJarOriginal = null;
         try {
             if (tagFilePath.startsWith("/META-INF/")) {
                 try {
-                    tagJar = compiler.getCompilationContext().getTldResourcePath(
-                                tagInfo.getTagLibrary().getURI()).openJar();
+                    tagJar = compiler.getCompilationContext().getTldResourcePath(tagInfo.getTagLibrary().getURI())
+                            .openJar();
                 } catch (IOException ioe) {
                     throw new JasperException(ioe);
                 }
@@ -541,12 +483,10 @@ class TagFileProcessor {
                 try {
                     wrapper = rctxt.getWrapper(wrapperUri);
                     if (wrapper == null) {
-                        wrapper = new JspServletWrapper(ctxt.getServletContext(), ctxt
-                                .getOptions(), tagFilePath, tagInfo, ctxt
-                                .getRuntimeContext(), tagJar);
+                        wrapper = new JspServletWrapper(ctxt.getServletContext(), ctxt.getOptions(), tagFilePath,
+                                tagInfo, ctxt.getRuntimeContext(), tagJar);
                         // Use same classloader and classpath for compiling tag files
-                        wrapper.getJspEngineContext().setClassLoader(
-                                ctxt.getClassLoader());
+                        wrapper.getJspEngineContext().setClassLoader(ctxt.getClassLoader());
                         wrapper.getJspEngineContext().setClassPath(ctxt.getClassPath());
                         rctxt.addWrapper(wrapperUri, wrapper);
                     } else {
@@ -571,17 +511,13 @@ class TagFileProcessor {
                             // file is compiled in prototype mode, to avoid infinite
                             // recursion.
 
-                            JspServletWrapper tempWrapper = new JspServletWrapper(ctxt
-                                    .getServletContext(), ctxt.getOptions(),
-                                    tagFilePath, tagInfo, ctxt.getRuntimeContext(),
-                                    tagJar);
+                            JspServletWrapper tempWrapper = new JspServletWrapper(ctxt.getServletContext(),
+                                    ctxt.getOptions(), tagFilePath, tagInfo, ctxt.getRuntimeContext(), tagJar);
                             // Use same classloader and classpath for compiling tag files
-                            tempWrapper.getJspEngineContext().setClassLoader(
-                                    ctxt.getClassLoader());
+                            tempWrapper.getJspEngineContext().setClassLoader(ctxt.getClassLoader());
                             tempWrapper.getJspEngineContext().setClassPath(ctxt.getClassPath());
                             tagClazz = tempWrapper.loadTagFilePrototype();
-                            tempVector.add(tempWrapper.getJspEngineContext()
-                                    .getCompiler());
+                            tempVector.add(tempWrapper.getJspEngineContext().getCompiler());
                         } else {
                             tagClazz = wrapper.loadTagFile();
                         }
@@ -595,10 +531,8 @@ class TagFileProcessor {
                     try {
                         Object tagIns = tagClazz.getConstructor().newInstance();
                         if (tagIns instanceof JspSourceDependent) {
-                            for (Entry<String, Long> entry : ((JspSourceDependent)
-                                    tagIns).getDependants().entrySet()) {
-                                parentPageInfo.addDependant(entry.getKey(),
-                                        entry.getValue());
+                            for (Entry<String,Long> entry : ((JspSourceDependent) tagIns).getDependants().entrySet()) {
+                                parentPageInfo.addDependant(entry.getKey(), entry.getValue());
                             }
                         }
                     } catch (RuntimeException | ReflectiveOperationException e) {
@@ -620,14 +554,14 @@ class TagFileProcessor {
     }
 
     /*
-     * Visitor which scans the page and looks for tag handlers that are tag
-     * files, compiling (if necessary) and loading them.
+     * Visitor which scans the page and looks for tag handlers that are tag files, compiling (if necessary) and loading
+     * them.
      */
     private class TagFileLoaderVisitor extends Node.Visitor {
 
-        private Compiler compiler;
+        private final Compiler compiler;
 
-        private PageInfo pageInfo;
+        private final PageInfo pageInfo;
 
         TagFileLoaderVisitor(Compiler compiler) {
 
@@ -642,32 +576,29 @@ class TagFileProcessor {
                 String tagFilePath = tagFileInfo.getPath();
                 if (tagFilePath.startsWith("/META-INF/")) {
                     // For tags in JARs, add the TLD and the tag as a dependency
-                    TldResourcePath tldResourcePath =
-                        compiler.getCompilationContext().getTldResourcePath(
-                            tagFileInfo.getTagInfo().getTagLibrary().getURI());
+                    TldResourcePath tldResourcePath = compiler.getCompilationContext()
+                            .getTldResourcePath(tagFileInfo.getTagInfo().getTagLibrary().getURI());
 
                     try (Jar jar = tldResourcePath.openJar()) {
 
                         if (jar != null) {
                             // Add TLD
                             pageInfo.addDependant(jar.getURL(tldResourcePath.getEntryName()),
-                                                  Long.valueOf(jar.getLastModified(tldResourcePath.getEntryName())));
+                                    Long.valueOf(jar.getLastModified(tldResourcePath.getEntryName())));
                             // Add Tag
                             pageInfo.addDependant(jar.getURL(tagFilePath.substring(1)),
-                                                  Long.valueOf(jar.getLastModified(tagFilePath.substring(1))));
+                                    Long.valueOf(jar.getLastModified(tagFilePath.substring(1))));
                         } else {
                             pageInfo.addDependant(tagFilePath,
-                                                  compiler.getCompilationContext().getLastModified(tagFilePath));
+                                    compiler.getCompilationContext().getLastModified(tagFilePath));
                         }
                     } catch (IOException ioe) {
                         throw new JasperException(ioe);
                     }
                 } else {
-                    pageInfo.addDependant(tagFilePath,
-                            compiler.getCompilationContext().getLastModified(tagFilePath));
+                    pageInfo.addDependant(tagFilePath, compiler.getCompilationContext().getLastModified(tagFilePath));
                 }
-                Class<?> c = loadTagFile(compiler, tagFilePath, n.getTagInfo(),
-                        pageInfo);
+                Class<?> c = loadTagFile(compiler, tagFilePath, n.getTagInfo(), pageInfo);
                 n.setTagHandlerClass(c);
             }
             visitBody(n);
@@ -675,36 +606,31 @@ class TagFileProcessor {
     }
 
     /**
-     * Implements a phase of the translation that compiles (if necessary) the
-     * tag files used in a JSP files. The directives in the tag files are
-     * assumed to have been processed and encapsulated as TagFileInfo in the
-     * CustomTag nodes.
+     * Implements a phase of the translation that compiles (if necessary) the tag files used in a JSP files. The
+     * directives in the tag files are assumed to have been processed and encapsulated as TagFileInfo in the CustomTag
+     * nodes.
      *
      * @param compiler Compiler to use to compile tag files
      * @param page     The page from to scan for tag files to compile
      *
      * @throws JasperException If an error occurs during the scan or compilation
      */
-    public void loadTagFiles(Compiler compiler, Node.Nodes page)
-            throws JasperException {
+    public void loadTagFiles(Compiler compiler, Node.Nodes page) throws JasperException {
 
-        tempVector = new Vector<>();
+        tempVector = new ArrayList<>();
         page.visit(new TagFileLoaderVisitor(compiler));
     }
 
     /**
-     * Removed the java and class files for the tag prototype generated from the
-     * current compilation.
+     * Removed the java and class files for the tag prototype generated from the current compilation.
      *
-     * @param classFileName
-     *            If non-null, remove only the class file with with this name.
+     * @param classFileName If non-null, remove only the class file with this name.
      */
     public void removeProtoTypeFiles(String classFileName) {
         for (Compiler c : tempVector) {
             if (classFileName == null) {
                 c.removeGeneratedClassFiles();
-            } else if (classFileName.equals(c.getCompilationContext()
-                    .getClassFileName())) {
+            } else if (classFileName.equals(c.getCompilationContext().getClassFileName())) {
                 c.removeGeneratedClassFiles();
                 tempVector.remove(c);
                 return;
