@@ -32,8 +32,7 @@ import javax.el.ValueExpression;
  *
  * @author Jacob Hookom
  */
-public final class JspValueExpression extends ValueExpression implements
-        Externalizable {
+public final class JspValueExpression extends ValueExpression implements Externalizable {
 
     private ValueExpression target;
 
@@ -54,72 +53,86 @@ public final class JspValueExpression extends ValueExpression implements
     }
 
     @Override
-    public Class<?> getType(ELContext context) throws NullPointerException,
-            PropertyNotFoundException, ELException {
+    public Class<?> getType(ELContext context) throws NullPointerException, PropertyNotFoundException, ELException {
         context.notifyBeforeEvaluation(getExpressionString());
         try {
             Class<?> result = this.target.getType(context);
             context.notifyAfterEvaluation(getExpressionString());
             return result;
         } catch (PropertyNotFoundException e) {
-            if (e instanceof JspPropertyNotFoundException) throw e;
+            if (e instanceof JspPropertyNotFoundException) {
+                throw e;
+            }
             throw new JspPropertyNotFoundException(this.mark, e);
         } catch (ELException e) {
-            if (e instanceof JspELException) throw e;
+            if (e instanceof JspELException) {
+                throw e;
+            }
             throw new JspELException(this.mark, e);
         }
     }
 
     @Override
-    public boolean isReadOnly(ELContext context) throws NullPointerException,
-            PropertyNotFoundException, ELException {
+    public boolean isReadOnly(ELContext context) throws NullPointerException, PropertyNotFoundException, ELException {
         context.notifyBeforeEvaluation(getExpressionString());
         try {
             boolean result = this.target.isReadOnly(context);
             context.notifyAfterEvaluation(getExpressionString());
             return result;
         } catch (PropertyNotFoundException e) {
-            if (e instanceof JspPropertyNotFoundException) throw e;
+            if (e instanceof JspPropertyNotFoundException) {
+                throw e;
+            }
             throw new JspPropertyNotFoundException(this.mark, e);
         } catch (ELException e) {
-            if (e instanceof JspELException) throw e;
+            if (e instanceof JspELException) {
+                throw e;
+            }
             throw new JspELException(this.mark, e);
         }
     }
 
     @Override
     public void setValue(ELContext context, Object value)
-            throws NullPointerException, PropertyNotFoundException,
-            PropertyNotWritableException, ELException {
+            throws NullPointerException, PropertyNotFoundException, PropertyNotWritableException, ELException {
         context.notifyBeforeEvaluation(getExpressionString());
         try {
             this.target.setValue(context, value);
             context.notifyAfterEvaluation(getExpressionString());
         } catch (PropertyNotWritableException e) {
-            if (e instanceof JspPropertyNotWritableException) throw e;
+            if (e instanceof JspPropertyNotWritableException) {
+                throw e;
+            }
             throw new JspPropertyNotWritableException(this.mark, e);
         } catch (PropertyNotFoundException e) {
-            if (e instanceof JspPropertyNotFoundException) throw e;
+            if (e instanceof JspPropertyNotFoundException) {
+                throw e;
+            }
             throw new JspPropertyNotFoundException(this.mark, e);
         } catch (ELException e) {
-            if (e instanceof JspELException) throw e;
+            if (e instanceof JspELException) {
+                throw e;
+            }
             throw new JspELException(this.mark, e);
         }
     }
 
     @Override
-    public Object getValue(ELContext context) throws NullPointerException,
-            PropertyNotFoundException, ELException {
+    public Object getValue(ELContext context) throws NullPointerException, PropertyNotFoundException, ELException {
         context.notifyBeforeEvaluation(getExpressionString());
         try {
             Object result = this.target.getValue(context);
             context.notifyAfterEvaluation(getExpressionString());
             return result;
         } catch (PropertyNotFoundException e) {
-            if (e instanceof JspPropertyNotFoundException) throw e;
+            if (e instanceof JspPropertyNotFoundException) {
+                throw e;
+            }
             throw new JspPropertyNotFoundException(this.mark, e);
         } catch (ELException e) {
-            if (e instanceof JspELException) throw e;
+            if (e instanceof JspELException) {
+                throw e;
+            }
             throw new JspELException(this.mark, e);
         }
     }
@@ -151,8 +164,7 @@ public final class JspValueExpression extends ValueExpression implements
     }
 
     @Override
-    public void readExternal(ObjectInput in) throws IOException,
-            ClassNotFoundException {
+    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
         this.mark = in.readUTF();
         this.target = (ValueExpression) in.readObject();
     }
