@@ -22,13 +22,11 @@ import javax.servlet.jsp.tagext.JspFragment;
 import javax.servlet.jsp.tagext.JspTag;
 
 /**
- * Helper class from which all Jsp Fragment helper classes extend.
- * This class allows for the emulation of numerous fragments within
- * a single class, which in turn reduces the load on the class loader
- * since there are potentially many JspFragments in a single page.
+ * Helper class from which all Jsp Fragment helper classes extend. This class allows for the emulation of numerous
+ * fragments within a single class, which in turn reduces the load on the class loader since there are potentially many
+ * JspFragments in a single page.
  * <p>
- * The class also provides various utility methods for JspFragment
- * implementations.
+ * The class also provides various utility methods for JspFragment implementations.
  *
  * @author Mark Roth
  */
@@ -39,13 +37,11 @@ public abstract class JspFragmentHelper extends JspFragment {
     protected final PageContext _jspx_page_context;
     protected final JspTag parentTag;
 
-    public JspFragmentHelper( int discriminator, JspContext jspContext,
-        JspTag parentTag )
-    {
+    public JspFragmentHelper(int discriminator, JspContext jspContext, JspTag parentTag) {
         this.discriminator = discriminator;
         this.jspContext = jspContext;
-        if(jspContext instanceof PageContext) {
-            _jspx_page_context = (PageContext)jspContext;
+        if (jspContext instanceof PageContext) {
+            _jspx_page_context = (PageContext) jspContext;
         } else {
             _jspx_page_context = null;
         }
