@@ -51,8 +51,7 @@ import org.apache.jasper.el.ELContextImpl;
 import org.apache.jasper.runtime.JspContextWrapper.ELContextWrapper;
 
 /**
- * Implementation of the PageContext class from the JSP spec. Also doubles as a
- * VariableResolver for the EL.
+ * Implementation of the PageContext class from the JSP spec. Also doubles as a VariableResolver for the EL.
  *
  * @author Anil K. Vijendran
  * @author Larry Cable
@@ -66,6 +65,8 @@ public class PageContextImpl extends PageContext {
 
     private static final JspFactory jspf = JspFactory.getDefaultFactory();
 
+    private static final BodyContentImpl[] EMPTY_BODY_CONTENT_IMPL_ARRAY = new BodyContentImpl[0];
+
     private BodyContentImpl[] outs;
 
     private int depth;
@@ -82,7 +83,7 @@ public class PageContextImpl extends PageContext {
     private String errorPageURL;
 
     // page-scope attributes
-    private final transient HashMap<String, Object> attributes;
+    private final transient HashMap<String,Object> attributes;
 
     // per-request state
     private transient ServletRequest request;
@@ -99,20 +100,15 @@ public class PageContextImpl extends PageContext {
 
     private transient JspWriterImpl baseOut;
 
-    /*
-     * Constructor.
-     */
     PageContextImpl() {
-        this.outs = new BodyContentImpl[0];
+        this.outs = EMPTY_BODY_CONTENT_IMPL_ARRAY;
         this.attributes = new HashMap<>(16);
         this.depth = -1;
     }
 
     @Override
-    public void initialize(Servlet servlet, ServletRequest request,
-            ServletResponse response, String errorPageURL,
-            boolean needsSession, int bufferSize, boolean autoFlush)
-            throws IOException {
+    public void initialize(Servlet servlet, ServletRequest request, ServletResponse response, String errorPageURL,
+            boolean needsSession, int bufferSize, boolean autoFlush) throws IOException {
 
         // initialize state
         this.servlet = servlet;
@@ -166,8 +162,7 @@ public class PageContextImpl extends PageContext {
         try {
             ((JspWriterImpl) out).flushBuffer();
         } catch (IOException ex) {
-            IllegalStateException ise = new IllegalStateException(Localizer.getMessage("jsp.error.flush"), ex);
-            throw ise;
+            throw new IllegalStateException(Localizer.getMessage("jsp.error.flush"), ex);
         } finally {
             servlet = null;
             config = null;
@@ -181,7 +176,7 @@ public class PageContextImpl extends PageContext {
             baseOut.recycle();
             session = null;
             attributes.clear();
-            for (BodyContentImpl body: outs) {
+            for (BodyContentImpl body : outs) {
                 body.recycle();
             }
         }
@@ -200,23 +195,23 @@ public class PageContextImpl extends PageContext {
         }
 
         switch (scope) {
-        case PAGE_SCOPE:
-            return attributes.get(name);
+            case PAGE_SCOPE:
+                return attributes.get(name);
 
-        case REQUEST_SCOPE:
-            return request.getAttribute(name);
+            case REQUEST_SCOPE:
+                return request.getAttribute(name);
 
-        case SESSION_SCOPE:
-            if (session == null) {
-                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-            }
-            return session.getAttribute(name);
+            case SESSION_SCOPE:
+                if (session == null) {
+                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+                }
+                return session.getAttribute(name);
 
-        case APPLICATION_SCOPE:
-            return context.getAttribute(name);
+            case APPLICATION_SCOPE:
+                return context.getAttribute(name);
 
-        default:
-            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+            default:
+                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -236,28 +231,27 @@ public class PageContextImpl extends PageContext {
             removeAttribute(name, scope);
         } else {
             switch (scope) {
-            case PAGE_SCOPE:
-                attributes.put(name, o);
-                break;
+                case PAGE_SCOPE:
+                    attributes.put(name, o);
+                    break;
 
-            case REQUEST_SCOPE:
-                request.setAttribute(name, o);
-                break;
+                case REQUEST_SCOPE:
+                    request.setAttribute(name, o);
+                    break;
 
-            case SESSION_SCOPE:
-                if (session == null) {
-                    throw new IllegalStateException(Localizer
-                            .getMessage("jsp.error.page.noSession"));
-                }
-                session.setAttribute(name, o);
-                break;
+                case SESSION_SCOPE:
+                    if (session == null) {
+                        throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+                    }
+                    session.setAttribute(name, o);
+                    break;
 
-            case APPLICATION_SCOPE:
-                context.setAttribute(name, o);
-                break;
+                case APPLICATION_SCOPE:
+                    context.setAttribute(name, o);
+                    break;
 
-            default:
-                throw new IllegalArgumentException("Invalid scope");
+                default:
+                    throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
             }
         }
     }
@@ -270,27 +264,27 @@ public class PageContextImpl extends PageContext {
         }
 
         switch (scope) {
-        case PAGE_SCOPE:
-            attributes.remove(name);
-            break;
+            case PAGE_SCOPE:
+                attributes.remove(name);
+                break;
 
-        case REQUEST_SCOPE:
-            request.removeAttribute(name);
-            break;
+            case REQUEST_SCOPE:
+                request.removeAttribute(name);
+                break;
 
-        case SESSION_SCOPE:
-            if (session == null) {
-                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-            }
-            session.removeAttribute(name);
-            break;
+            case SESSION_SCOPE:
+                if (session == null) {
+                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+                }
+                session.removeAttribute(name);
+                break;
 
-        case APPLICATION_SCOPE:
-            context.removeAttribute(name);
-            break;
+            case APPLICATION_SCOPE:
+                context.removeAttribute(name);
+                break;
 
-        default:
-            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+            default:
+                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -314,7 +308,7 @@ public class PageContextImpl extends PageContext {
                 if (session.getAttribute(name) != null) {
                     return SESSION_SCOPE;
                 }
-            } catch(IllegalStateException ise) {
+            } catch (IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall through to application scope.
             }
@@ -346,7 +340,7 @@ public class PageContextImpl extends PageContext {
         if (session != null) {
             try {
                 o = session.getAttribute(name);
-            } catch(IllegalStateException ise) {
+            } catch (IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall through to application scope.
             }
@@ -361,23 +355,23 @@ public class PageContextImpl extends PageContext {
     @Override
     public Enumeration<String> getAttributeNamesInScope(final int scope) {
         switch (scope) {
-        case PAGE_SCOPE:
-            return Collections.enumeration(attributes.keySet());
+            case PAGE_SCOPE:
+                return Collections.enumeration(attributes.keySet());
 
-        case REQUEST_SCOPE:
-            return request.getAttributeNames();
+            case REQUEST_SCOPE:
+                return request.getAttributeNames();
 
-        case SESSION_SCOPE:
-            if (session == null) {
-                throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
-            }
-            return session.getAttributeNames();
+            case SESSION_SCOPE:
+                if (session == null) {
+                    throw new IllegalStateException(Localizer.getMessage("jsp.error.page.noSession"));
+                }
+                return session.getAttributeNames();
 
-        case APPLICATION_SCOPE:
-            return context.getAttributeNames();
+            case APPLICATION_SCOPE:
+                return context.getAttributeNames();
 
-        default:
-            throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
+            default:
+                throw new IllegalArgumentException(Localizer.getMessage("jsp.error.page.invalid.scope"));
         }
     }
 
@@ -390,10 +384,10 @@ public class PageContextImpl extends PageContext {
 
         removeAttribute(name, PAGE_SCOPE);
         removeAttribute(name, REQUEST_SCOPE);
-        if( session != null ) {
+        if (session != null) {
             try {
                 removeAttribute(name, SESSION_SCOPE);
-            } catch(IllegalStateException ise) {
+            } catch (IllegalStateException ise) {
                 // Session has been invalidated.
                 // Ignore and fall throw to application scope.
             }
@@ -434,8 +428,7 @@ public class PageContextImpl extends PageContext {
     /**
      * Returns the exception associated with this page context, if any.
      * <p>
-     * Added wrapping for Throwables to avoid ClassCastException: see Bugzilla
-     * 31171 for details.
+     * Added wrapping for Throwables to avoid ClassCastException: see Bugzilla 31171 for details.
      *
      * @return The Exception associated with this page context, if any.
      */
@@ -456,12 +449,11 @@ public class PageContextImpl extends PageContext {
         return servlet;
     }
 
-    private final String getAbsolutePathRelativeToContext(String relativeUrlPath) {
+    private String getAbsolutePathRelativeToContext(String relativeUrlPath) {
         String path = relativeUrlPath;
 
         if (!path.startsWith("/")) {
-            String uri = (String) request.getAttribute(
-                    RequestDispatcher.INCLUDE_SERVLET_PATH);
+            String uri = (String) request.getAttribute(RequestDispatcher.INCLUDE_SERVLET_PATH);
             if (uri == null) {
                 uri = ((HttpServletRequest) request).getServletPath();
             }
@@ -473,23 +465,19 @@ public class PageContextImpl extends PageContext {
     }
 
     @Override
-    public void include(String relativeUrlPath) throws ServletException,
-            IOException {
-        JspRuntimeLibrary
-                .include(request, response, relativeUrlPath, out, true);
+    public void include(String relativeUrlPath) throws ServletException, IOException {
+        JspRuntimeLibrary.include(request, response, relativeUrlPath, out, true);
     }
 
     @Override
-    public void include(final String relativeUrlPath, final boolean flush)
-            throws ServletException, IOException {
+    public void include(final String relativeUrlPath, final boolean flush) throws ServletException, IOException {
         JspRuntimeLibrary.include(request, response, relativeUrlPath, out, flush);
     }
 
     @Override
     @Deprecated
     public javax.servlet.jsp.el.VariableResolver getVariableResolver() {
-        return new org.apache.jasper.el.VariableResolverImpl(
-                this.getELContext());
+        return new org.apache.jasper.el.VariableResolverImpl(this.getELContext());
     }
 
     @Override
@@ -499,8 +487,7 @@ public class PageContextImpl extends PageContext {
             out.clear();
             baseOut.clear();
         } catch (IOException ex) {
-            throw new IllegalStateException(Localizer.getMessage(
-                    "jsp.error.attempt_to_clear_flushed_buffer"), ex);
+            throw new IllegalStateException(Localizer.getMessage("jsp.error.attempt_to_clear_flushed_buffer"), ex);
         }
 
         // Make sure that the response object is not the wrapper for include
@@ -564,20 +551,17 @@ public class PageContextImpl extends PageContext {
     }
 
     /**
-     * Provides programmatic access to the ExpressionEvaluator. The JSP
-     * Container must return a valid instance of an ExpressionEvaluator that can
-     * parse EL expressions.
+     * Provides programmatic access to the ExpressionEvaluator. The JSP Container must return a valid instance of an
+     * ExpressionEvaluator that can parse EL expressions.
      */
     @Override
     @Deprecated
     public javax.servlet.jsp.el.ExpressionEvaluator getExpressionEvaluator() {
-        return new org.apache.jasper.el.ExpressionEvaluatorImpl(
-                this.applicationContext.getExpressionFactory());
+        return new org.apache.jasper.el.ExpressionEvaluatorImpl(this.applicationContext.getExpressionFactory());
     }
 
     @Override
-    public void handlePageException(Exception ex) throws IOException,
-            ServletException {
+    public void handlePageException(Exception ex) throws IOException, ServletException {
         // Should never be called since handleException() called with a
         // Throwable in the generated servlet.
         handlePageException((Throwable) ex);
@@ -590,24 +574,19 @@ public class PageContextImpl extends PageContext {
             throw new NullPointerException(Localizer.getMessage("jsp.error.page.nullThrowable"));
         }
 
-        if (errorPageURL != null && !errorPageURL.equals("")) {
+        if (errorPageURL != null && !errorPageURL.isEmpty()) {
 
             /*
-             * Set request attributes. Do not set the
-             * javax.servlet.error.exception attribute here (instead, set in the
-             * generated servlet code for the error page) in order to prevent
-             * the ErrorReportValve, which is invoked as part of forwarding the
-             * request to the error page, from throwing it if the response has
-             * not been committed (the response will have been committed if the
-             * error page is a JSP page).
+             * Set request attributes. Do not set the javax.servlet.error.exception attribute here (instead, set in the
+             * generated servlet code for the error page) in order to prevent the ErrorReportValve, which is invoked as
+             * part of forwarding the request to the error page, from throwing it if the response has not been committed
+             * (the response will have been committed if the error page is a JSP page).
              */
-            request.setAttribute(PageContext.EXCEPTION, t);
+            request.setAttribute(EXCEPTION, t);
             request.setAttribute(RequestDispatcher.ERROR_STATUS_CODE,
                     Integer.valueOf(HttpServletResponse.SC_INTERNAL_SERVER_ERROR));
-            request.setAttribute(RequestDispatcher.ERROR_REQUEST_URI,
-                    ((HttpServletRequest) request).getRequestURI());
-            request.setAttribute(RequestDispatcher.ERROR_SERVLET_NAME,
-                    config.getServletName());
+            request.setAttribute(RequestDispatcher.ERROR_REQUEST_URI, ((HttpServletRequest) request).getRequestURI());
+            request.setAttribute(RequestDispatcher.ERROR_SERVLET_NAME, config.getServletName());
             try {
                 forward(errorPageURL);
             } catch (IllegalStateException ise) {
@@ -627,7 +606,7 @@ public class PageContextImpl extends PageContext {
             request.removeAttribute(RequestDispatcher.ERROR_STATUS_CODE);
             request.removeAttribute(RequestDispatcher.ERROR_REQUEST_URI);
             request.removeAttribute(RequestDispatcher.ERROR_SERVLET_NAME);
-            request.removeAttribute(PageContext.EXCEPTION);
+            request.removeAttribute(EXCEPTION);
 
         } else {
             // Otherwise throw the exception wrapped inside a ServletException.
@@ -639,47 +618,39 @@ public class PageContextImpl extends PageContext {
             if (t instanceof ServletException) {
                 throw (ServletException) t;
             }
-            if (t instanceof RuntimeException) {
-                throw (RuntimeException) t;
-            }
-
             Throwable rootCause = null;
             if (t instanceof JspException || t instanceof ELException ||
                     t instanceof javax.servlet.jsp.el.ELException) {
                 rootCause = t.getCause();
             }
-
             if (rootCause != null) {
-                throw new ServletException(
-                        t.getClass().getName() + ": " + t.getMessage(), rootCause);
+                throw new ServletException(t.getClass().getName() + ": " + t.getMessage(), rootCause);
+            }
+            // ELException is a runtime exception
+            if (t instanceof RuntimeException) {
+                throw (RuntimeException) t;
             }
-
             throw new ServletException(t);
         }
     }
 
     /**
-     * Proprietary method to evaluate EL expressions. XXX - This method should
-     * go away once the EL interpreter moves out of JSTL and into its own
-     * project. For now, this is necessary because the standard machinery is too
-     * slow.
+     * Proprietary method to evaluate EL expressions. XXX - This method should go away once the EL interpreter moves out
+     * of JSTL and into its own project. For now, this is necessary because the standard machinery is too slow.
+     *
+     * @param expression   The expression to be evaluated
+     * @param expectedType The expected resulting type
+     * @param pageContext  The page context
+     * @param functionMap  Maps prefix and name to Method
      *
-     * @param expression
-     *            The expression to be evaluated
-     * @param expectedType
-     *            The expected resulting type
-     * @param pageContext
-     *            The page context
-     * @param functionMap
-     *            Maps prefix and name to Method
      * @return The result of the evaluation
+     *
      * @throws ELException If an error occurs during the evaluation
      */
-    public static Object proprietaryEvaluate(final String expression,
-            final Class<?> expectedType, final PageContext pageContext,
-            final ProtectedFunctionMapper functionMap)
-            throws ELException {
-        final ExpressionFactory exprFactory = jspf.getJspApplicationContext(pageContext.getServletContext()).getExpressionFactory();
+    public static Object proprietaryEvaluate(final String expression, final Class<?> expectedType,
+            final PageContext pageContext, final ProtectedFunctionMapper functionMap) throws ELException {
+        final ExpressionFactory exprFactory =
+                jspf.getJspApplicationContext(pageContext.getServletContext()).getExpressionFactory();
         ELContext ctx = pageContext.getELContext();
         ELContextImpl ctxImpl;
         if (ctx instanceof ELContextWrapper) {
@@ -707,7 +678,16 @@ public class PageContextImpl extends PageContext {
                 Set<String> classImports = ((JspSourceImports) servlet).getClassImports();
                 if (classImports != null) {
                     for (String classImport : classImports) {
-                        ih.importClass(classImport);
+                        if (classImport.startsWith("static ")) {
+                            classImport = classImport.substring(7);
+                            try {
+                                ih.importStatic(classImport);
+                            } catch (ELException e) {
+                                // Ignore - not all static imports are valid for EL
+                            }
+                        } else {
+                            ih.importClass(classImport);
+                        }
                     }
                 }
             }
