@@ -24,27 +24,22 @@ import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
 /**
- * An internationalization / localization helper class which reduces
- * the bother of handling ResourceBundles and takes care of the
- * common cases of message formatting which otherwise require the
- * creation of Object arrays and such.
- *
- * <p>The StringManager operates on a package basis. One StringManager
- * per package can be created and accessed via the getManager method
- * call.
- *
- * <p>The StringManager will look for a ResourceBundle named by
- * the package name given plus the suffix of "LocalStrings". In
- * practice, this means that the localized information will be contained
- * in a LocalStrings.properties file located in the package
- * directory of the classpath.
- *
- * <p>Please see the documentation for java.util.ResourceBundle for
- * more information.
+ * An internationalization / localization helper class which reduces the bother of handling ResourceBundles and takes
+ * care of the common cases of message formatting which otherwise require the creation of Object arrays and such.
+ * <p>
+ * The StringManager operates on a package basis. One StringManager per package can be created and accessed via the
+ * getManager method call.
+ * <p>
+ * The StringManager will look for a ResourceBundle named by the package name given plus the suffix of "LocalStrings".
+ * In practice, this means that the localized information will be contained in a LocalStrings.properties file located in
+ * the package directory of the classpath.
+ * <p>
+ * Please see the documentation for java.util.ResourceBundle for more information.
  *
  * @author James Duncan Davidson [duncan@eng.sun.com]
  * @author James Todd [gonzo@eng.sun.com]
  * @author Mel Martinez [mmartinez@g1440.com]
+ *
  * @see java.util.ResourceBundle
  */
 public class StringManager {
@@ -56,10 +51,8 @@ public class StringManager {
     private final Locale locale;
 
     /**
-     * Creates a new StringManager for a given package. This is a
-     * private method and all access to it is arbitrated by the
-     * static getManager method call so that only one StringManager
-     * per package will be created.
+     * Creates a new StringManager for a given package. This is a private method and all access to it is arbitrated by
+     * the static getManager method call so that only one StringManager per package will be created.
      *
      * @param packageName Name of package to create StringManager for.
      */
@@ -68,16 +61,15 @@ public class StringManager {
         ResourceBundle tempBundle = null;
         try {
             tempBundle = ResourceBundle.getBundle(bundleName, Locale.getDefault());
-        } catch( MissingResourceException ex ) {
+        } catch (MissingResourceException ex) {
             // Try from the current loader (that's the case for trusted apps)
             // Should only be required if using a TC5 style classloader structure
             // where common != shared != server
             ClassLoader cl = Thread.currentThread().getContextClassLoader();
-            if( cl != null ) {
+            if (cl != null) {
                 try {
-                    tempBundle = ResourceBundle.getBundle(
-                            bundleName, Locale.getDefault(), cl);
-                } catch(MissingResourceException ex2) {
+                    tempBundle = ResourceBundle.getBundle(bundleName, Locale.getDefault(), cl);
+                } catch (MissingResourceException ex2) {
                     // Ignore
                 }
             }
@@ -92,16 +84,16 @@ public class StringManager {
     }
 
     /**
-        Get a string from the underlying resource bundle or return
-        null if the String is not found.
-
-        @param key to desired resource String
-        @return resource String matching <i>key</i> from underlying
-                bundle or null if not found.
-        @throws IllegalArgumentException if <i>key</i> is null.
+     * Get a string from the underlying resource bundle or return null if the String is not found.
+     *
+     * @param key to desired resource String
+     *
+     * @return resource String matching <i>key</i> from underlying bundle or null if not found.
+     *
+     * @throws IllegalArgumentException if <i>key</i> is null.
      */
     public String getString(String key) {
-        if(key == null){
+        if (key == null) {
             String msg = "key may not have a null value";
 
             throw new IllegalArgumentException(msg);
@@ -114,32 +106,30 @@ public class StringManager {
             if (bundle != null) {
                 str = bundle.getString(key);
             }
-        } catch(MissingResourceException mre) {
-            //bad: shouldn't mask an exception the following way:
-            //   str = "[cannot find message associated with key '" + key + "' due to " + mre + "]";
-            //     because it hides the fact that the String was missing
-            //     from the calling code.
-            //good: could just throw the exception (or wrap it in another)
-            //      but that would probably cause much havoc on existing
-            //      code.
-            //better: consistent with container pattern to
-            //      simply return null.  Calling code can then do
-            //      a null check.
-            str = null;
+        } catch (MissingResourceException mre) {
+            // bad: shouldn't mask an exception the following way:
+            // str = "[cannot find message associated with key '" + key + "' due to " + mre + "]";
+            // because it hides the fact that the String was missing
+            // from the calling code.
+            // good: could just throw the exception (or wrap it in another)
+            // but that would probably cause much havoc on existing
+            // code.
+            // better: consistent with container pattern to
+            // simply return null. Calling code can then do
+            // a null check.
+            // str is already set to null
         }
 
         return str;
     }
 
     /**
-     * Get a string from the underlying resource bundle and format
-     * it with the given set of arguments.
+     * Get a string from the underlying resource bundle and format it with the given set of arguments.
      *
      * @param key  The key for the required message
      * @param args The values to insert into the message
      *
-     * @return The request string formatted with the provided arguments or the
-     *         key if the key was not found.
+     * @return The request string formatted with the provided arguments or the key if the key was not found.
      */
     public String getString(final String key, final Object... args) {
         String value = getString(key);
@@ -156,18 +146,17 @@ public class StringManager {
     // STATIC SUPPORT METHODS
     // --------------------------------------------------------------
 
-    private static final Map<String, StringManager> managers = new HashMap<>();
+    private static final Map<String,StringManager> managers = new HashMap<>();
 
     /**
-     * Get the StringManager for a particular package. If a manager for
-     * a package already exists, it will be reused, else a new
-     * StringManager will be created and returned.
+     * Get the StringManager for a particular package. If a manager for a package already exists, it will be reused,
+     * else a new StringManager will be created and returned.
      *
      * @param packageName The package name
      *
      * @return The instance associated with the given package
      */
-    public static final synchronized StringManager getManager(String packageName) {
+    public static synchronized StringManager getManager(String packageName) {
         StringManager mgr = managers.get(packageName);
         if (mgr == null) {
             mgr = new StringManager(packageName);
@@ -177,7 +166,7 @@ public class StringManager {
     }
 
 
-    public static final StringManager getManager(Class<?> clazz) {
+    public static StringManager getManager(Class<?> clazz) {
         return getManager(clazz.getPackage().getName());
     }
 }
