@@ -23,6 +23,7 @@ import javax.naming.Reference;
 import javax.naming.spi.ObjectFactory;
 
 import org.apache.naming.EjbRef;
+import org.apache.naming.StringManager;
 
 /**
  * Object factory for EJBs.
@@ -31,6 +32,8 @@ import org.apache.naming.EjbRef;
  */
 public class EjbFactory extends FactoryBase {
 
+    private static final StringManager sm = StringManager.getManager(EjbFactory.class);
+
     @Override
     protected boolean isReferenceTypeSupported(Object obj) {
         return obj instanceof EjbRef;
@@ -40,12 +43,10 @@ public class EjbFactory extends FactoryBase {
     protected ObjectFactory getDefaultFactory(Reference ref) throws NamingException {
 
         ObjectFactory factory;
-        String javaxEjbFactoryClassName = System.getProperty(
-                "javax.ejb.Factory", Constants.OPENEJB_EJB_FACTORY);
+        String javaxEjbFactoryClassName = System.getProperty("javax.ejb.Factory", Constants.OPENEJB_EJB_FACTORY);
         try {
-            factory = (ObjectFactory)
-                Class.forName(javaxEjbFactoryClassName).getConstructor().newInstance();
-        } catch(Throwable t) {
+            factory = (ObjectFactory) Class.forName(javaxEjbFactoryClassName).getConstructor().newInstance();
+        } catch (Throwable t) {
             if (t instanceof NamingException) {
                 throw (NamingException) t;
             }
@@ -55,8 +56,7 @@ public class EjbFactory extends FactoryBase {
             if (t instanceof VirtualMachineError) {
                 throw (VirtualMachineError) t;
             }
-            NamingException ex = new NamingException
-                ("Could not create resource factory instance");
+            NamingException ex = new NamingException(sm.getString("factoryBase.factoryCreationError"));
             ex.initCause(t);
             throw ex;
         }
@@ -70,8 +70,7 @@ public class EjbFactory extends FactoryBase {
         if (linkRefAddr != null) {
             // Retrieving the EJB link
             String ejbLink = linkRefAddr.getContent().toString();
-            Object beanObj = (new InitialContext()).lookup(ejbLink);
-            return beanObj;
+            return (new InitialContext()).lookup(ejbLink);
         }
         return null;
     }
