@@ -32,12 +32,12 @@ import java.sql.RowId;
 import java.sql.SQLException;
 import java.sql.SQLType;
 import java.sql.SQLXML;
-import java.sql.Statement;
 import java.sql.Time;
 import java.sql.Timestamp;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.List;
+import java.util.Objects;
 
 /**
  * A base delegating implementation of {@link PreparedStatement}.
@@ -712,7 +712,6 @@ public class DelegatingPreparedStatement extends DelegatingStatement implements
      */
     @Override
     public synchronized String toString() {
-        final Statement statement = getDelegate();
-        return statement == null ? "NULL" : statement.toString();
+        return Objects.toString(getDelegate(), "NULL");
     }
 }
