@@ -14,18 +14,21 @@
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
  */
-
 package org.apache.tomcat.jni;
 
-/** Sockaddr
+/**
+ * Sockaddr
  *
  * @author Mladen Turk
- * @version $Id: Sockaddr.java 939351 2010-04-29 15:41:54Z kkolinko $
+ *
+ * @deprecated The scope of the APR/Native Library will be reduced in Tomcat 9.1.x / Tomcat Native 2.x and has been
+ *                 reduced in Tomcat 10.1.x / Tomcat Native 2.x onwards to only include those components required to
+ *                 provide OpenSSL integration with the NIO and NIO2 connectors.
  */
-
+@Deprecated
 public class Sockaddr {
 
-   /** The pool to use... */
+    /** The pool to use... */
     public long pool;
     /** The hostname */
     public String hostname;
@@ -35,8 +38,9 @@ public class Sockaddr {
     public int port;
     /** The family */
     public int family;
-    /** If multiple addresses were found by apr_sockaddr_info_get(), this
-     *  points to a representation of the next address. */
+    /**
+     * If multiple addresses were found by apr_sockaddr_info_get(), this points to a representation of the next address.
+     */
     public long next;
 
 }
