@@ -60,7 +60,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
          *
          * @throws IOException If an I/O occurs while writing the characters
          */
-        void realWriteChars(char buf[], int off, int len) throws IOException;
+        void realWriteChars(char[] buf, int off, int len) throws IOException;
     }
 
     // --------------------
@@ -108,7 +108,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     /**
-     * Sets the buffer to the specified subarray of characters.
+     * Sets the buffer to the specified sub array of characters.
      *
      * @param c   the characters
      * @param off the start offset of the characters
@@ -188,7 +188,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      *
      * @throws IOException Writing overflow data to the output channel failed
      */
-    public void append(char src[], int off, int len) throws IOException {
+    public void append(char[] src, int off, int len) throws IOException {
         // will grow, up to limit
         makeSpace(len);
         int limit = getLimitInternal();
@@ -276,7 +276,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
         int sOff = off;
         int sEnd = off + len;
         while (sOff < sEnd) {
-            int d = min(limit - end, sEnd - sOff);
+            int d = Math.min(limit - end, sEnd - sOff);
             s.getChars(sOff, sOff + d, buff, end);
             sOff += d;
             end += d;
@@ -317,10 +317,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
         if (checkEof()) {
             return -1;
         }
-        int n = len;
-        if (len > getLength()) {
-            n = getLength();
-        }
+        int n = Math.min(len, getLength());
         System.arraycopy(buff, start, dest, off, n);
         start += n;
         return n;
@@ -332,10 +329,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
             if (in == null) {
                 return true;
             }
-            int n = in.realReadChars();
-            if (n < 0) {
-                return true;
-            }
+            return in.realReadChars() < 0;
         }
         return false;
     }
@@ -365,8 +359,6 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      * @param count The size
      */
     public void makeSpace(int count) {
-        char[] tmp = null;
-
         int limit = getLimitInternal();
 
         long newSize;
@@ -399,12 +391,11 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
         if (newSize > limit) {
             newSize = limit;
         }
-        tmp = new char[(int) newSize];
+        char[] tmp = new char[(int) newSize];
 
         // Some calling code assumes buffer will not be compacted
         System.arraycopy(buff, 0, tmp, 0, end);
         buff = tmp;
-        tmp = null;
     }
 
 
@@ -488,8 +479,8 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
     }
 
 
-    public boolean equals(char b2[], int off2, int len2) {
-        char b1[] = buff;
+    public boolean equals(char[] b2, int off2, int len2) {
+        char[] b1 = buff;
         if (b1 == null && b2 == null) {
             return true;
         }
@@ -613,7 +604,7 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
      *
      * @return The position of the first instance of the character or -1 if the character is not found.
      */
-    public static int indexOf(char chars[], int start, int end, char s) {
+    public static int indexOf(char[] chars, int start, int end, char s) {
         int offset = start;
 
         while (offset < end) {
@@ -628,13 +619,6 @@ public final class CharChunk extends AbstractChunk implements CharSequence {
 
 
     // -------------------- utils
-    private int min(int a, int b) {
-        if (a < b) {
-            return a;
-        }
-        return b;
-    }
-
 
     // Char sequence impl
 
