@@ -18,8 +18,7 @@ package org.apache.tomcat.util.descriptor.web;
 
 public class Constants {
 
-    public static final String PACKAGE_NAME =
-            Constants.class.getPackage().getName();
+    public static final String PACKAGE_NAME = Constants.class.getPackage().getName();
 
     public static final String WEB_XML_LOCATION = "/WEB-INF/web.xml";
 
