@@ -21,22 +21,21 @@ import java.io.Serializable;
 import org.apache.tomcat.util.buf.UDecoder;
 
 /**
- * Representation of an error page element for a web application,
- * as represented in a <code>&lt;error-page&gt;</code> element in the
- * deployment descriptor.
+ * Representation of an error page element for a web application, as represented in a <code>&lt;error-page&gt;</code>
+ * element in the deployment descriptor.
  *
  * @author Craig R. McClanahan
  */
-public class ErrorPage implements Serializable {
+public class ErrorPage extends XmlEncodingBase implements Serializable {
+
+    private static final long serialVersionUID = 2L;
 
-    private static final long serialVersionUID = 1L;
 
     // ----------------------------------------------------- Instance Variables
 
-
     /**
-     * The error (status) code for which this error page is active. Note that
-     * status code 0 is used for the default error page.
+     * The error (status) code for which this error page is active. Note that status code 0 is used for the default
+     * error page.
      */
     private int errorCode = 0;
 
@@ -121,12 +120,7 @@ public class ErrorPage implements Serializable {
      * @param location The new location
      */
     public void setLocation(String location) {
-
-        //        if ((location == null) || !location.startsWith("/"))
-        //            throw new IllegalArgumentException
-        //                ("Error Page Location must start with a '/'");
-        this.location = UDecoder.URLDecode(location);
-
+        this.location = UDecoder.URLDecode(location, getCharset());
     }
 
 
@@ -148,7 +142,7 @@ public class ErrorPage implements Serializable {
         }
         sb.append(", location=");
         sb.append(location);
-        sb.append("]");
+        sb.append(']');
         return sb.toString();
     }
 
