@@ -17,7 +17,6 @@
 package org.apache.tomcat.util.http;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
@@ -28,7 +27,6 @@ import java.util.Map;
 
 import org.apache.juli.logging.Log;
 import org.apache.juli.logging.LogFactory;
-import org.apache.tomcat.util.buf.B2CConverter;
 import org.apache.tomcat.util.buf.ByteChunk;
 import org.apache.tomcat.util.buf.MessageBytes;
 import org.apache.tomcat.util.buf.StringUtils;
@@ -36,10 +34,6 @@ import org.apache.tomcat.util.buf.UDecoder;
 import org.apache.tomcat.util.log.UserDataHelper;
 import org.apache.tomcat.util.res.StringManager;
 
-/**
- *
- * @author Costin Manolache
- */
 public final class Parameters {
 
     private static final Log log = LogFactory.getLog(Parameters.class);
@@ -48,12 +42,10 @@ public final class Parameters {
 
     private static final UserDataHelper maxParamCountLog = new UserDataHelper(log);
 
-    private static final StringManager sm =
-        StringManager.getManager("org.apache.tomcat.util.http");
+    private static final StringManager sm = StringManager.getManager("org.apache.tomcat.util.http");
 
-    private final Map<String,ArrayList<String>> paramHashValues =
-            new LinkedHashMap<>();
-    private boolean didQueryParameters=false;
+    private final Map<String,ArrayList<String>> paramHashValues = new LinkedHashMap<>();
+    private boolean didQueryParameters = false;
 
     private MessageBytes queryMB;
 
@@ -67,8 +59,8 @@ public final class Parameters {
     private int parameterCount = 0;
 
     /**
-     * Set to the reason for the failure (the first failure if there is more
-     * than one) if there were failures during parameter parsing.
+     * Set to the reason for the failure (the first failure if there is more than one) if there were failures during
+     * parameter parsing.
      */
     private FailReason parseFailedReason = null;
 
@@ -76,66 +68,36 @@ public final class Parameters {
         // NO-OP
     }
 
-    public void setQuery( MessageBytes queryMB ) {
-        this.queryMB=queryMB;
+    public void setQuery(MessageBytes queryMB) {
+        this.queryMB = queryMB;
     }
 
     public void setLimit(int limit) {
         this.limit = limit;
     }
 
-    /**
-     * @return The current encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public String getEncoding() {
-        return charset.name();
-    }
-
     public Charset getCharset() {
         return charset;
     }
 
-    /**
-     * @param s The new encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public void setEncoding(String s) {
-        setCharset(getCharset(s, DEFAULT_BODY_CHARSET));
-    }
-
     public void setCharset(Charset charset) {
         if (charset == null) {
             charset = DEFAULT_BODY_CHARSET;
         }
         this.charset = charset;
-        if(log.isDebugEnabled()) {
-            log.debug("Set encoding to " + charset.name());
+        if (log.isTraceEnabled()) {
+            log.trace("Set encoding to " + charset.name());
         }
     }
 
-    /**
-     * @param s The new query string encoding
-     *
-     * @deprecated This method will be removed in Tomcat 9
-     */
-    @Deprecated
-    public void setQueryStringEncoding(String s) {
-        setQueryStringCharset(getCharset(s, DEFAULT_URI_CHARSET));
-    }
-
     public void setQueryStringCharset(Charset queryStringCharset) {
         if (queryStringCharset == null) {
             queryStringCharset = DEFAULT_URI_CHARSET;
         }
         this.queryStringCharset = queryStringCharset;
 
-        if(log.isDebugEnabled()) {
-            log.debug("Set query string encoding to " + queryStringCharset.name());
+        if (log.isTraceEnabled()) {
+            log.trace("Set query string encoding to " + queryStringCharset.name());
         }
     }
 
@@ -157,6 +119,11 @@ public final class Parameters {
     }
 
 
+    public int size() {
+        return parameterCount;
+    }
+
+
     public void recycle() {
         parameterCount = 0;
         paramHashValues.clear();
@@ -178,7 +145,7 @@ public final class Parameters {
         if (values == null) {
             return null;
         }
-        return values.toArray(new String[values.size()]);
+        return values.toArray(new String[0]);
     }
 
     public Enumeration<String> getParameterNames() {
@@ -186,11 +153,11 @@ public final class Parameters {
         return Collections.enumeration(paramHashValues.keySet());
     }
 
-    public String getParameter(String name ) {
+    public String getParameter(String name) {
         handleQueryParameters();
         ArrayList<String> values = paramHashValues.get(name);
         if (values != null) {
-            if(values.size() == 0) {
+            if (values.isEmpty()) {
                 return "";
             }
             return values.get(0);
@@ -198,8 +165,10 @@ public final class Parameters {
             return null;
         }
     }
+
     // -------------------- Processing --------------------
-    /** Process the query string into parameters
+    /**
+     * Process the query string into parameters
      */
     public void handleQueryParameters() {
         if (didQueryParameters) {
@@ -212,73 +181,60 @@ public final class Parameters {
             return;
         }
 
-        if(log.isDebugEnabled()) {
-            log.debug("Decoding query " + decodedQuery + " " + queryStringCharset.name());
+        if (log.isTraceEnabled()) {
+            log.trace("Decoding query " + decodedQuery + " " + queryStringCharset.name());
         }
 
         try {
             decodedQuery.duplicate(queryMB);
         } catch (IOException e) {
             // Can't happen, as decodedQuery can't overflow
-            e.printStackTrace();
+            log.error(sm.getString("parameters.copyFail"), e);
         }
         processParameters(decodedQuery, queryStringCharset);
     }
 
 
-    public void addParameter( String key, String value )
-            throws IllegalStateException {
+    public void addParameter(String key, String value) throws IllegalStateException {
 
-        if( key==null ) {
+        if (key == null) {
             return;
         }
 
-        parameterCount ++;
-        if (limit > -1 && parameterCount > limit) {
+        if (limit > -1 && parameterCount >= limit) {
             // Processing this parameter will push us over the limit. ISE is
             // what Request.parseParts() uses for requests that are too big
             setParseFailedReason(FailReason.TOO_MANY_PARAMETERS);
-            throw new IllegalStateException(sm.getString(
-                    "parameters.maxCountFail", Integer.valueOf(limit)));
+            throw new IllegalStateException(sm.getString("parameters.maxCountFail", Integer.valueOf(limit)));
         }
+        parameterCount++;
 
-        ArrayList<String> values = paramHashValues.get(key);
-        if (values == null) {
-            values = new ArrayList<>(1);
-            paramHashValues.put(key, values);
-        }
-        values.add(value);
+        paramHashValues.computeIfAbsent(key, k -> new ArrayList<>(1)).add(value);
     }
 
-    public void setURLDecoder( UDecoder u ) {
-        urlDec=u;
+    public void setURLDecoder(UDecoder u) {
+        urlDec = u;
     }
 
     // -------------------- Parameter parsing --------------------
     // we are called from a single thread - we can do it the hard way
     // if needed
-    private final ByteChunk tmpName=new ByteChunk();
-    private final ByteChunk tmpValue=new ByteChunk();
-    private final ByteChunk origName=new ByteChunk();
-    private final ByteChunk origValue=new ByteChunk();
-    /**
-     * @deprecated This will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public static final String DEFAULT_ENCODING = "ISO-8859-1";
+    private final ByteChunk tmpName = new ByteChunk();
+    private final ByteChunk tmpValue = new ByteChunk();
+    private final ByteChunk origName = new ByteChunk();
+    private final ByteChunk origValue = new ByteChunk();
     private static final Charset DEFAULT_BODY_CHARSET = StandardCharsets.ISO_8859_1;
     private static final Charset DEFAULT_URI_CHARSET = StandardCharsets.UTF_8;
 
 
-    public void processParameters( byte bytes[], int start, int len ) {
+    public void processParameters(byte[] bytes, int start, int len) {
         processParameters(bytes, start, len, charset);
     }
 
-    private void processParameters(byte bytes[], int start, int len, Charset charset) {
+    private void processParameters(byte[] bytes, int start, int len, Charset charset) {
 
-        if(log.isDebugEnabled()) {
-            log.debug(sm.getString("parameters.bytes",
-                    new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
+        if (log.isTraceEnabled()) {
+            log.trace(sm.getString("parameters.bytes", new String(bytes, start, len, DEFAULT_BODY_CHARSET)));
         }
 
         int decodeFailCount = 0;
@@ -286,7 +242,7 @@ public final class Parameters {
         int pos = start;
         int end = start + len;
 
-        while(pos < end) {
+        while (pos < end) {
             int nameStart = pos;
             int nameEnd = -1;
             int valueStart = -1;
@@ -298,7 +254,7 @@ public final class Parameters {
             boolean parameterComplete = false;
 
             do {
-                switch(bytes[pos]) {
+                switch (bytes[pos]) {
                     case '=':
                         if (parsingName) {
                             // Name finished. Value starts from next character
@@ -316,7 +272,7 @@ public final class Parameters {
                             nameEnd = pos;
                         } else {
                             // Value finished
-                            valueEnd  = pos;
+                            valueEnd = pos;
                         }
                         parameterComplete = true;
                         pos++;
@@ -329,10 +285,10 @@ public final class Parameters {
                         } else {
                             decodeValue = true;
                         }
-                        pos ++;
+                        pos++;
                         break;
                     default:
-                        pos ++;
+                        pos++;
                         break;
                 }
             } while (!parameterComplete && pos < end);
@@ -340,18 +296,17 @@ public final class Parameters {
             if (pos == end) {
                 if (nameEnd == -1) {
                     nameEnd = pos;
-                } else if (valueStart > -1 && valueEnd == -1){
+                } else if (valueStart > -1 && valueEnd == -1) {
                     valueEnd = pos;
                 }
             }
 
             if (log.isDebugEnabled() && valueStart == -1) {
-                log.debug(sm.getString("parameters.noequal",
-                        Integer.valueOf(nameStart), Integer.valueOf(nameEnd),
-                        new String(bytes, nameStart, nameEnd-nameStart, DEFAULT_BODY_CHARSET)));
+                log.debug(sm.getString("parameters.noequal", Integer.valueOf(nameStart), Integer.valueOf(nameEnd),
+                        new String(bytes, nameStart, nameEnd - nameStart, DEFAULT_BODY_CHARSET)));
             }
 
-            if (nameEnd <= nameStart ) {
+            if (nameEnd <= nameStart) {
                 if (valueStart == -1) {
                     // &&
                     if (log.isDebugEnabled()) {
@@ -365,13 +320,11 @@ public final class Parameters {
                 if (logMode != null) {
                     String extract;
                     if (valueEnd > nameStart) {
-                        extract = new String(bytes, nameStart, valueEnd - nameStart,
-                                DEFAULT_BODY_CHARSET);
+                        extract = new String(bytes, nameStart, valueEnd - nameStart, DEFAULT_BODY_CHARSET);
                     } else {
                         extract = "";
                     }
-                    String message = sm.getString("parameters.invalidChunk",
-                            Integer.valueOf(nameStart),
+                    String message = sm.getString("parameters.invalidChunk", Integer.valueOf(nameStart),
                             Integer.valueOf(valueEnd), extract);
                     switch (logMode) {
                         case INFO_THEN_DEBUG:
@@ -443,8 +396,7 @@ public final class Parameters {
                         String message = ise.getMessage();
                         switch (logMode) {
                             case INFO_THEN_DEBUG:
-                                message += sm.getString(
-                                        "parameters.maxCountFail.fallToDebug");
+                                message += sm.getString("parameters.maxCountFail.fallToDebug");
                                 //$FALL-THROUGH$
                             case INFO:
                                 log.info(message);
@@ -460,14 +412,14 @@ public final class Parameters {
                 decodeFailCount++;
                 if (decodeFailCount == 1 || log.isDebugEnabled()) {
                     if (log.isDebugEnabled()) {
-                        log.debug(sm.getString("parameters.decodeFail.debug",
-                                origName.toString(), origValue.toString()), e);
+                        log.debug(
+                                sm.getString("parameters.decodeFail.debug", origName.toString(), origValue.toString()),
+                                e);
                     } else if (log.isInfoEnabled()) {
                         UserDataHelper.Mode logMode = userDataLog.getNextMode();
                         if (logMode != null) {
-                            String message = sm.getString(
-                                    "parameters.decodeFail.info",
-                                    tmpName.toString(), tmpValue.toString());
+                            String message =
+                                    sm.getString("parameters.decodeFail.info", tmpName.toString(), tmpValue.toString());
                             switch (logMode) {
                                 case INFO_THEN_DEBUG:
                                     message += sm.getString("parameters.fallToDebug");
@@ -495,9 +447,7 @@ public final class Parameters {
         if (decodeFailCount > 1 && !log.isDebugEnabled()) {
             UserDataHelper.Mode logMode = userDataLog.getNextMode();
             if (logMode != null) {
-                String message = sm.getString(
-                        "parameters.multipleDecodingFail",
-                        Integer.valueOf(decodeFailCount));
+                String message = sm.getString("parameters.multipleDecodingFail", Integer.valueOf(decodeFailCount));
                 switch (logMode) {
                     case INFO_THEN_DEBUG:
                         message += sm.getString("parameters.fallToDebug");
@@ -512,46 +462,23 @@ public final class Parameters {
         }
     }
 
-    private void urlDecode(ByteChunk bc)
-        throws IOException {
-        if( urlDec==null ) {
-            urlDec=new UDecoder();
+    private void urlDecode(ByteChunk bc) throws IOException {
+        if (urlDec == null) {
+            urlDec = new UDecoder();
         }
         urlDec.convert(bc, true);
     }
 
-    /**
-     * @param data      Parameter data
-     * @param encoding  Encoding to use for encoded bytes
-     *
-     * @deprecated This method will be removed in Tomcat 9.0.x
-     */
-    @Deprecated
-    public void processParameters(MessageBytes data, String encoding) {
-        processParameters(data, getCharset(encoding, DEFAULT_BODY_CHARSET));
-    }
-
     public void processParameters(MessageBytes data, Charset charset) {
-        if( data==null || data.isNull() || data.getLength() <= 0 ) {
+        if (data == null || data.isNull() || data.getLength() <= 0) {
             return;
         }
 
-        if( data.getType() != MessageBytes.T_BYTES ) {
+        if (data.getType() != MessageBytes.T_BYTES) {
             data.toBytes();
         }
-        ByteChunk bc=data.getByteChunk();
-        processParameters(bc.getBytes(), bc.getOffset(), bc.getLength(), charset);
-    }
-
-    private Charset getCharset(String encoding, Charset defaultCharset) {
-        if (encoding == null) {
-            return defaultCharset;
-        }
-        try {
-            return B2CConverter.getCharset(encoding);
-        } catch (UnsupportedEncodingException e) {
-            return defaultCharset;
-        }
+        ByteChunk bc = data.getByteChunk();
+        processParameters(bc.getBytes(), bc.getStart(), bc.getLength(), charset);
     }
 
     /**
@@ -560,7 +487,7 @@ public final class Parameters {
     @Override
     public String toString() {
         StringBuilder sb = new StringBuilder();
-        for (Map.Entry<String, ArrayList<String>> e : paramHashValues.entrySet()) {
+        for (Map.Entry<String,ArrayList<String>> e : paramHashValues.entrySet()) {
             sb.append(e.getKey()).append('=');
             StringUtils.join(e.getValue(), ',', sb);
             sb.append('\n');
@@ -576,6 +503,12 @@ public final class Parameters {
         IO_ERROR,
         NO_NAME,
         POST_TOO_LARGE,
+        /**
+         * Same as {@link #CLIENT_DISCONNECT}.
+         *
+         * @deprecated Unused. Will be removed in Tomcat 11.0.x onwards
+         */
+        @Deprecated
         REQUEST_BODY_INCOMPLETE,
         TOO_MANY_PARAMETERS,
         UNKNOWN,
