@@ -23,24 +23,25 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
 import javax.management.MBeanNotificationInfo;
 
 /**
- * <p>Internal configuration information for a <code>Notification</code>
- * descriptor.</p>
+ * <p>
+ * Internal configuration information for a <code>Notification</code> descriptor.
+ * </p>
  *
  * @author Craig R. McClanahan
  */
 public class NotificationInfo extends FeatureInfo {
 
-    static final long serialVersionUID = -6319885418912650856L;
+    private static final long serialVersionUID = -6319885418912650856L;
 
     // ----------------------------------------------------- Instance Variables
 
 
     /**
-     * The <code>ModelMBeanNotificationInfo</code> object that corresponds
-     * to this <code>NotificationInfo</code> instance.
+     * The <code>ModelMBeanNotificationInfo</code> object that corresponds to this <code>NotificationInfo</code>
+     * instance.
      */
     transient MBeanNotificationInfo info = null;
-    protected String notifTypes[] = new String[0];
+    protected String[] notifTypes = new String[0];
     protected final ReadWriteLock notifTypesLock = new ReentrantReadWriteLock();
 
     // ------------------------------------------------------------- Properties
@@ -71,7 +72,7 @@ public class NotificationInfo extends FeatureInfo {
 
 
     /**
-     * @return the set of notification types for this MBean.
+     * @return the array of notification types for this MBean.
      */
     public String[] getNotifTypes() {
         Lock readLock = notifTypesLock.readLock();
@@ -98,7 +99,7 @@ public class NotificationInfo extends FeatureInfo {
         writeLock.lock();
         try {
 
-            String results[] = new String[notifTypes.length + 1];
+            String[] results = new String[notifTypes.length + 1];
             System.arraycopy(notifTypes, 0, results, 0, notifTypes.length);
             results[notifTypes.length] = notifType;
             notifTypes = results;
@@ -110,22 +111,23 @@ public class NotificationInfo extends FeatureInfo {
 
 
     /**
-     * Create and return a <code>ModelMBeanNotificationInfo</code> object that
-     * corresponds to the attribute described by this instance.
+     * Create and return a <code>ModelMBeanNotificationInfo</code> object that corresponds to the attribute described by
+     * this instance.
+     *
      * @return the notification info
      */
     public MBeanNotificationInfo createNotificationInfo() {
 
         // Return our cached information (if any)
-        if (info != null)
+        if (info != null) {
             return info;
+        }
 
         // Create and return a new information object
-        info = new MBeanNotificationInfo
-            (getNotifTypes(), getName(), getDescription());
-        //Descriptor descriptor = info.getDescriptor();
-        //addFields(descriptor);
-        //info.setDescriptor(descriptor);
+        info = new MBeanNotificationInfo(getNotifTypes(), getName(), getDescription());
+        // Descriptor descriptor = info.getDescriptor();
+        // addFields(descriptor);
+        // info.setDescriptor(descriptor);
         return info;
 
     }
@@ -150,7 +152,7 @@ public class NotificationInfo extends FeatureInfo {
         } finally {
             readLock.unlock();
         }
-        sb.append("]");
+        sb.append(']');
         return sb.toString();
     }
 }
