@@ -79,7 +79,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
     private static final Log logHandshake = LogFactory.getLog(NioEndpoint.class.getName() + ".handshake");
 
 
-    public static final int OP_REGISTER = 0x100; //register interest op
+    public static final int OP_REGISTER = 0x100; // register interest op
 
     // ----------------------------------------------------------------- Fields
 
@@ -113,15 +113,25 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      * Use System.inheritableChannel to obtain channel from stdin/stdout.
      */
     private boolean useInheritedChannel = false;
-    public void setUseInheritedChannel(boolean useInheritedChannel) { this.useInheritedChannel = useInheritedChannel; }
-    public boolean getUseInheritedChannel() { return useInheritedChannel; }
+
+    public void setUseInheritedChannel(boolean useInheritedChannel) {
+        this.useInheritedChannel = useInheritedChannel;
+    }
+
+    public boolean getUseInheritedChannel() {
+        return useInheritedChannel;
+    }
 
 
     /**
      * Path for the Unix domain socket, used to create the socket address.
      */
     private String unixDomainSocketPath = null;
-    public String getUnixDomainSocketPath() { return this.unixDomainSocketPath; }
+
+    public String getUnixDomainSocketPath() {
+        return this.unixDomainSocketPath;
+    }
+
     public void setUnixDomainSocketPath(String unixDomainSocketPath) {
         this.unixDomainSocketPath = unixDomainSocketPath;
     }
@@ -131,7 +141,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      * Permissions which will be set on the Unix domain socket if it is created.
      */
     private String unixDomainSocketPathPermissions = null;
-    public String getUnixDomainSocketPathPermissions() { return this.unixDomainSocketPathPermissions; }
+
+    public String getUnixDomainSocketPathPermissions() {
+        return this.unixDomainSocketPathPermissions;
+    }
+
     public void setUnixDomainSocketPathPermissions(String unixDomainSocketPathPermissions) {
         this.unixDomainSocketPathPermissions = unixDomainSocketPathPermissions;
     }
@@ -141,8 +155,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      * Priority of the poller thread.
      */
     private int pollerThreadPriority = Thread.NORM_PRIORITY;
-    public void setPollerThreadPriority(int pollerThreadPriority) { this.pollerThreadPriority = pollerThreadPriority; }
-    public int getPollerThreadPriority() { return pollerThreadPriority; }
+
+    public void setPollerThreadPriority(int pollerThreadPriority) {
+        this.pollerThreadPriority = pollerThreadPriority;
+    }
+
+    public int getPollerThreadPriority() {
+        return pollerThreadPriority;
+    }
 
 
     /**
@@ -153,7 +173,9 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      * @deprecated Will be removed in Tomcat 10.
      */
     @Deprecated
-    public void setPollerThreadCount(int pollerThreadCount) { }
+    public void setPollerThreadCount(int pollerThreadCount) {
+    }
+
     /**
      * Always returns 1.
      *
@@ -162,11 +184,19 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      * @deprecated Will be removed in Tomcat 10.
      */
     @Deprecated
-    public int getPollerThreadCount() { return 1; }
+    public int getPollerThreadCount() {
+        return 1;
+    }
 
     private long selectorTimeout = 1000;
-    public void setSelectorTimeout(long timeout) { this.selectorTimeout = timeout;}
-    public long getSelectorTimeout() { return this.selectorTimeout; }
+
+    public void setSelectorTimeout(long timeout) {
+        this.selectorTimeout = timeout;
+    }
+
+    public long getSelectorTimeout() {
+        return this.selectorTimeout;
+    }
 
     /**
      * The socket poller.
@@ -189,8 +219,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
     /**
      * Number of keep-alive sockets.
      *
-     * @return The number of sockets currently in the keep-alive state waiting
-     *         for the next request to be received on the socket
+     * @return The number of sockets currently in the keep-alive state waiting for the next request to be received on
+     *             the socket
      */
     public int getKeepAliveCount() {
         if (poller == null) {
@@ -267,7 +297,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             InetSocketAddress addr = new InetSocketAddress(getAddress(), getPortWithOffset());
             serverSock.bind(addr, getAcceptCount());
         }
-        serverSock.configureBlocking(true); //mimic APR behavior
+        serverSock.configureBlocking(true); // mimic APR behavior
     }
 
 
@@ -282,16 +312,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             paused = false;
 
             if (socketProperties.getProcessorCache() != 0) {
-                processorCache = new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE,
-                        socketProperties.getProcessorCache());
+                processorCache =
+                        new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE, socketProperties.getProcessorCache());
             }
             if (socketProperties.getEventCache() != 0) {
-                eventCache = new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE,
-                        socketProperties.getEventCache());
+                eventCache = new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE, socketProperties.getEventCache());
             }
             if (socketProperties.getBufferPool() != 0) {
-                nioChannels = new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE,
-                        socketProperties.getBufferPool());
+                nioChannels = new SynchronizedStack<>(SynchronizedStack.DEFAULT_SIZE, socketProperties.getBufferPool());
             }
 
             // Create worker collection
@@ -366,8 +394,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
     @Override
     public void unbind() throws Exception {
         if (log.isTraceEnabled()) {
-            log.trace("Destroy initiated for " +
-                    new InetSocketAddress(getAddress(),getPortWithOffset()));
+            log.trace("Destroy initiated for " + new InetSocketAddress(getAddress(), getPortWithOffset()));
         }
         if (running) {
             stop();
@@ -379,12 +406,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         }
         destroySsl();
         super.unbind();
-        if (getHandler() != null ) {
+        if (getHandler() != null) {
             getHandler().recycle();
         }
         if (log.isTraceEnabled()) {
-            log.trace("Destroy completed for " +
-                    new InetSocketAddress(getAddress(), getPortWithOffset()));
+            log.trace("Destroy completed for " + new InetSocketAddress(getAddress(), getPortWithOffset()));
         }
     }
 
@@ -425,16 +451,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 }
                 // Wait for up to 1000ms acceptor threads to unlock
                 long waitLeft = 1000;
-                while (waitLeft > 0 &&
-                        acceptor.getState() == AcceptorState.RUNNING) {
+                while (waitLeft > 0 && acceptor.getState() == AcceptorState.RUNNING) {
                     Thread.sleep(5);
                     waitLeft -= 5;
                 }
-            } catch(Throwable t) {
+            } catch (Throwable t) {
                 ExceptionUtils.handleThrowable(t);
                 if (getLog().isDebugEnabled()) {
-                    getLog().debug(sm.getString(
-                            "endpoint.debug.unlock.fail", String.valueOf(getPortWithOffset())), t);
+                    getLog().debug(sm.getString("endpoint.debug.unlock.fail", String.valueOf(getPortWithOffset())), t);
                 }
             }
         }
@@ -463,10 +487,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
     /**
      * Process the specified connection.
+     *
      * @param socket The socket channel
-     * @return <code>true</code> if the socket was correctly configured
-     *  and processing may continue, <code>false</code> if the socket needs to be
-     *  close immediately
+     *
+     * @return <code>true</code> if the socket was correctly configured and processing may continue, <code>false</code>
+     *             if the socket needs to be close immediately
      */
     @Override
     protected boolean setSocketOptions(SocketChannel socket) {
@@ -478,10 +503,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 channel = nioChannels.pop();
             }
             if (channel == null) {
-                SocketBufferHandler bufhandler = new SocketBufferHandler(
-                        socketProperties.getAppReadBufSize(),
-                        socketProperties.getAppWriteBufSize(),
-                        socketProperties.getDirectBuffer());
+                SocketBufferHandler bufhandler = new SocketBufferHandler(socketProperties.getAppReadBufSize(),
+                        socketProperties.getAppWriteBufSize(), socketProperties.getDirectBuffer());
                 if (isSSLEnabled()) {
                     channel = new SecureNioChannel(bufhandler, this);
                 } else {
@@ -573,8 +596,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
 
     @Override
-    protected SocketProcessorBase<NioChannel> createSocketProcessor(
-            SocketWrapperBase<NioChannel> socketWrapper, SocketEvent event) {
+    protected SocketProcessorBase<NioChannel> createSocketProcessor(SocketWrapperBase<NioChannel> socketWrapper,
+            SocketEvent event) {
         return new SocketProcessor(socketWrapper, event);
     }
 
@@ -621,15 +644,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
      */
     public class Poller implements Runnable {
 
-        private Selector selector;
-        private final SynchronizedQueue<PollerEvent> events =
-                new SynchronizedQueue<>();
+        private final Selector selector;
+        private final SynchronizedQueue<PollerEvent> events = new SynchronizedQueue<>();
 
         private volatile boolean close = false;
         // Optimize expiration handling
         private long nextExpiration = 0;
 
-        private AtomicLong wakeupCounter = new AtomicLong(0);
+        private final AtomicLong wakeupCounter = new AtomicLong(0);
 
         private volatile int keyCount = 0;
 
@@ -637,9 +659,13 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             this.selector = Selector.open();
         }
 
-        public int getKeyCount() { return keyCount; }
+        public int getKeyCount() {
+            return selector.keys().size();
+        }
 
-        public Selector getSelector() { return selector; }
+        public Selector getSelector() {
+            return selector;
+        }
 
         /**
          * Destroy the poller.
@@ -673,14 +699,12 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         }
 
         /**
-         * Add specified socket and associated pool to the poller. The socket will
-         * be added to a temporary array, and polled first after a maximum amount
-         * of time equal to pollTime (in most cases, latency will be much lower,
+         * Add specified socket and associated pool to the poller. The socket will be added to a temporary array, and
+         * polled first after a maximum amount of time equal to pollTime (in most cases, latency will be much lower,
          * however).
          *
          * @param socketWrapper to add to the poller
-         * @param interestOps Operations for which to register this socket with
-         *                    the Poller
+         * @param interestOps   Operations for which to register this socket with the Poller
          */
         public void add(NioSocketWrapper socketWrapper, int interestOps) {
             PollerEvent pollerEvent = createPollerEvent(socketWrapper, interestOps);
@@ -693,20 +717,21 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         /**
          * Processes events in the event queue of the Poller.
          *
-         * @return <code>true</code> if some events were processed,
-         *   <code>false</code> if queue was empty
+         * @return <code>true</code> if some events were processed, <code>false</code> if queue was empty
          */
         public boolean events() {
             boolean result = false;
 
-            PollerEvent pe = null;
-            for (int i = 0, size = events.size(); i < size && (pe = events.poll()) != null; i++ ) {
+            PollerEvent pe;
+            for (int i = 0, size = events.size(); i < size && (pe = events.poll()) != null; i++) {
                 result = true;
                 NioSocketWrapper socketWrapper = pe.getSocketWrapper();
                 SocketChannel sc = socketWrapper.getSocket().getIOChannel();
                 int interestOps = pe.getInterestOps();
                 if (sc == null) {
-                    log.warn(sm.getString("endpoint.nio.nullSocketChannel"));
+                    if (log.isDebugEnabled()) {
+                        log.debug(sm.getString("endpoint.nio.nullSocketChannel"));
+                    }
                     socketWrapper.close();
                 } else if (interestOps == OP_REGISTER) {
                     try {
@@ -754,7 +779,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
          * @param socketWrapper The socket wrapper
          */
         public void register(final NioSocketWrapper socketWrapper) {
-            socketWrapper.interestOps(SelectionKey.OP_READ);//this is what OP_REGISTER turns into.
+            socketWrapper.interestOps(SelectionKey.OP_READ);// this is what OP_REGISTER turns into.
             PollerEvent pollerEvent = createPollerEvent(socketWrapper, OP_REGISTER);
             addEvent(pollerEvent);
         }
@@ -787,9 +812,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         }
 
         /**
-         * The background thread that adds sockets to the Poller, checks the
-         * poller for triggered events and hands the associated socket off to an
-         * appropriate processor as events occur.
+         * The background thread that adds sockets to the Poller, checks the poller for triggered events and hands the
+         * associated socket off to an appropriate processor as events occur.
          */
         @Override
         public void run() {
@@ -803,7 +827,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         hasEvents = events();
                         if (wakeupCounter.getAndSet(-1) > 0) {
                             // If we are here, means we have other stuff to do
-                            // Do a non blocking select
+                            // Do a non-blocking select
                             keyCount = selector.selectNow();
                         } else {
                             keyCount = selector.select(selectorTimeout);
@@ -830,8 +854,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     continue;
                 }
 
-                Iterator<SelectionKey> iterator =
-                    keyCount > 0 ? selector.selectedKeys().iterator() : null;
+                Iterator<SelectionKey> iterator = keyCount > 0 ? selector.selectedKeys().iterator() : null;
                 // Walk through the collection of ready keys and dispatch
                 // any active event.
                 while (iterator != null && iterator.hasNext()) {
@@ -846,7 +869,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 }
 
                 // Process timeouts
-                timeout(keyCount,hasEvents);
+                timeout(keyCount, hasEvents);
             }
 
             getStopLatch().countDown();
@@ -921,7 +944,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 }
 
                 if (sd.fchannel == null) {
-                    // Setup the file channel
+                    // Set up the file channel
                     File f = new File(sd.fileName);
                     @SuppressWarnings("resource") // Closed when channel is closed
                     FileInputStream fis = new FileInputStream(f);
@@ -952,7 +975,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         }
                     }
                 }
-                if (sd.length <= 0 && sc.getOutboundRemaining()<=0) {
+                if (sd.length <= 0 && sc.getOutboundRemaining() <= 0) {
                     if (log.isTraceEnabled()) {
                         log.trace("Send file complete for: " + sd.fileName);
                     }
@@ -966,29 +989,29 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     // appropriate event(s) if sendfile completes.
                     if (!calledByProcessor) {
                         switch (sd.keepAliveState) {
-                        case NONE: {
-                            if (log.isTraceEnabled()) {
-                                log.trace("Send file connection is being closed");
-                            }
-                            poller.cancelledKey(sk, socketWrapper);
-                            break;
-                        }
-                        case PIPELINED: {
-                            if (log.isTraceEnabled()) {
-                                log.trace("Connection is keep alive, processing pipe-lined data");
-                            }
-                            if (!processSocket(socketWrapper, SocketEvent.OPEN_READ, true)) {
+                            case NONE: {
+                                if (log.isTraceEnabled()) {
+                                    log.trace("Send file connection is being closed");
+                                }
                                 poller.cancelledKey(sk, socketWrapper);
+                                break;
                             }
-                            break;
-                        }
-                        case OPEN: {
-                            if (log.isTraceEnabled()) {
-                                log.trace("Connection is keep alive, registering back for OP_READ");
+                            case PIPELINED: {
+                                if (log.isTraceEnabled()) {
+                                    log.trace("Connection is keep alive, processing pipe-lined data");
+                                }
+                                if (!processSocket(socketWrapper, SocketEvent.OPEN_READ, true)) {
+                                    poller.cancelledKey(sk, socketWrapper);
+                                }
+                                break;
+                            }
+                            case OPEN: {
+                                if (log.isTraceEnabled()) {
+                                    log.trace("Connection is keep alive, registering back for OP_READ");
+                                }
+                                reg(sk, socketWrapper, SelectionKey.OP_READ);
+                                break;
                             }
-                            reg(sk, socketWrapper, SelectionKey.OP_READ);
-                            break;
-                        }
                         }
                     }
                     return SendfileState.DONE;
@@ -1057,7 +1080,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                             socketWrapper.interestOps(0);
                             cancelledKey(key, socketWrapper);
                         } else if (socketWrapper.interestOpsHas(SelectionKey.OP_READ) ||
-                                  socketWrapper.interestOpsHas(SelectionKey.OP_WRITE)) {
+                                socketWrapper.interestOpsHas(SelectionKey.OP_WRITE)) {
                             boolean readTimeout = false;
                             boolean writeTimeout = false;
                             // Check for read timeout
@@ -1104,13 +1127,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             }
             // For logging purposes only
             long prevExp = nextExpiration;
-            nextExpiration = System.currentTimeMillis() +
-                    socketProperties.getTimeoutInterval();
+            nextExpiration = System.currentTimeMillis() + socketProperties.getTimeoutInterval();
             if (log.isTraceEnabled()) {
-                log.trace("timeout completed: keys processed=" + keycount +
-                        "; now=" + now + "; nextExpiration=" + prevExp +
-                        "; keyCount=" + keyCount + "; hasEvents=" + hasEvents +
-                        "; eval=" + ((now < prevExp) && (keyCount>0 || hasEvents) && (!close) ));
+                log.trace("timeout completed: keys processed=" + keycount + "; now=" + now + "; nextExpiration=" +
+                        prevExp + "; keyCount=" + keyCount + "; hasEvents=" + hasEvents + "; eval=" +
+                        ((now < prevExp) && (keyCount > 0 || hasEvents) && (!close)));
             }
 
         }
@@ -1151,20 +1172,46 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             writeLock = (writePending == null) ? new Object() : writePending;
         }
 
-        public Poller getPoller() { return poller; }
-        public int interestOps() { return interestOps; }
-        public int interestOps(int ops) { this.interestOps  = ops; return ops; }
+        public Poller getPoller() {
+            return poller;
+        }
+
+        public int interestOps() {
+            return interestOps;
+        }
+
+        public int interestOps(int ops) {
+            this.interestOps = ops;
+            return ops;
+        }
+
         public boolean interestOpsHas(int targetOp) {
             return (this.interestOps() & targetOp) == targetOp;
         }
 
-        public void setSendfileData(SendfileData sf) { this.sendfileData = sf;}
-        public SendfileData getSendfileData() { return this.sendfileData; }
+        public void setSendfileData(SendfileData sf) {
+            this.sendfileData = sf;
+        }
 
-        public void updateLastWrite() { lastWrite = System.currentTimeMillis(); }
-        public long getLastWrite() { return lastWrite; }
-        public void updateLastRead() { lastRead = System.currentTimeMillis(); }
-        public long getLastRead() { return lastRead; }
+        public SendfileData getSendfileData() {
+            return this.sendfileData;
+        }
+
+        public void updateLastWrite() {
+            lastWrite = System.currentTimeMillis();
+        }
+
+        public long getLastWrite() {
+            return lastWrite;
+        }
+
+        public void updateLastRead() {
+            lastRead = System.currentTimeMillis();
+        }
+
+        public long getLastRead() {
+            return lastRead;
+        }
 
         @Override
         public boolean isReadyForRead() throws IOException {
@@ -1176,8 +1223,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
             fillReadBuffer(false);
 
-            boolean isReady = socketBufferHandler.getReadBuffer().position() > 0;
-            return isReady;
+            return socketBufferHandler.getReadBuffer().position() > 0;
         }
 
 
@@ -1187,11 +1233,9 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             if (nRead > 0) {
                 return nRead;
                 /*
-                 * Since more bytes may have arrived since the buffer was last
-                 * filled, it is an option at this point to perform a
-                 * non-blocking read. However correctly handling the case if
-                 * that read returns end of stream adds complexity. Therefore,
-                 * at the moment, the preference is for simplicity.
+                 * Since more bytes may have arrived since the buffer was last filled, it is an option at this point to
+                 * perform a non-blocking read. However, correctly handling the case if that read returns end of stream
+                 * adds complexity. Therefore, at the moment, the preference is for simplicity.
                  */
             }
 
@@ -1216,11 +1260,9 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             if (nRead > 0) {
                 return nRead;
                 /*
-                 * Since more bytes may have arrived since the buffer was last
-                 * filled, it is an option at this point to perform a
-                 * non-blocking read. However correctly handling the case if
-                 * that read returns end of stream adds complexity. Therefore,
-                 * at the moment, the preference is for simplicity.
+                 * Since more bytes may have arrived since the buffer was last filled, it is an option at this point to
+                 * perform a non-blocking read. However, correctly handling the case if that read returns end of stream
+                 * adds complexity. Therefore, at the moment, the preference is for simplicity.
                  */
             }
 
@@ -1296,7 +1338,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
 
         private int fillReadBuffer(boolean block, ByteBuffer buffer) throws IOException {
-            int n = 0;
+            int n;
             if (getSocket() == NioChannel.CLOSED_NIO_CHANNEL) {
                 throw new ClosedChannelException();
             }
@@ -1373,13 +1415,11 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         /*
          * https://bz.apache.org/bugzilla/show_bug.cgi?id=66076
          *
-         * When using TLS an additional buffer is used for the encrypted data
-         * before it is written to the network. It is possible for this network
-         * output buffer to contain data while the socket write buffer is empty.
+         * When using TLS an additional buffer is used for the encrypted data before it is written to the network. It is
+         * possible for this network output buffer to contain data while the socket write buffer is empty.
          *
-         * For NIO with non-blocking I/O, this case is handling by ensuring that
-         * flush only returns false (i.e. no data left to flush) if all buffers
-         * are empty.
+         * For NIO with non-blocking I/O, this case is handling by ensuring that flush only returns false (i.e. no data
+         * left to flush) if all buffers are empty.
          */
         private boolean socketOrNetworkBufferHasDataLeft() {
             return !socketBufferHandler.isWriteBufferEmpty() || getSocket().getOutboundRemaining() > 0;
@@ -1388,7 +1428,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
 
         @Override
         protected void doWrite(boolean block, ByteBuffer buffer) throws IOException {
-            int n = 0;
+            int n;
             if (getSocket() == NioChannel.CLOSED_NIO_CHANNEL) {
                 throw new ClosedChannelException();
             }
@@ -1397,16 +1437,13 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     /*
                      * Socket has previously timed out.
                      *
-                     * Blocking writes assume that buffer is always fully
-                     * written so there is no code checking for incomplete
-                     * writes, retaining the unwritten data and attempting to
-                     * write it as part of a subsequent write call.
+                     * Blocking writes assume that buffer is always fully written so there is no code checking for
+                     * incomplete writes, retaining the unwritten data and attempting to write it as part of a
+                     * subsequent write call.
                      *
-                     * Because of the above, when a timeout is triggered we need
-                     * to skip subsequent attempts to write as otherwise it will
-                     * appear to the client as if some data was dropped just
-                     * before the connection is lost. It is better if the client
-                     * just sees the dropped connection.
+                     * Because of the above, when a timeout is triggered we need to skip subsequent attempts to write as
+                     * otherwise it will appear to the client as if some data was dropped just before the connection is
+                     * lost. It is better if the client just sees the dropped connection.
                      */
                     throw new IOException(previousIOException);
                 }
@@ -1426,7 +1463,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     }
                     synchronized (writeLock) {
                         n = getSocket().write(buffer);
-                        // n == 0 could be an incomplete write but it could also
+                        // n == 0 could be an incomplete write, but it could also
                         // indicate that a previous incomplete write of the
                         // outbound buffer (for TLS) has now completed. Only
                         // block if there is still data to write.
@@ -1601,23 +1638,23 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         }
 
         @Override
-        protected <A> OperationState<A> newOperationState(boolean read,
-                ByteBuffer[] buffers, int offset, int length,
-                BlockingMode block, long timeout, TimeUnit unit, A attachment,
-                CompletionCheck check, CompletionHandler<Long, ? super A> handler,
-                Semaphore semaphore, VectoredIOCompletionHandler<A> completion) {
-            return new NioOperationState<>(read, buffers, offset, length, block,
-                    timeout, unit, attachment, check, handler, semaphore, completion);
+        protected <A> OperationState<A> newOperationState(boolean read, ByteBuffer[] buffers, int offset, int length,
+                BlockingMode block, long timeout, TimeUnit unit, A attachment, CompletionCheck check,
+                CompletionHandler<Long,? super A> handler, Semaphore semaphore,
+                VectoredIOCompletionHandler<A> completion) {
+            return new NioOperationState<>(read, buffers, offset, length, block, timeout, unit, attachment, check,
+                    handler, semaphore, completion);
         }
 
         private class NioOperationState<A> extends OperationState<A> {
             private volatile boolean inline = true;
-            private NioOperationState(boolean read, ByteBuffer[] buffers, int offset, int length,
-                    BlockingMode block, long timeout, TimeUnit unit, A attachment, CompletionCheck check,
-                    CompletionHandler<Long, ? super A> handler, Semaphore semaphore,
+
+            private NioOperationState(boolean read, ByteBuffer[] buffers, int offset, int length, BlockingMode block,
+                    long timeout, TimeUnit unit, A attachment, CompletionCheck check,
+                    CompletionHandler<Long,? super A> handler, Semaphore semaphore,
                     VectoredIOCompletionHandler<A> completion) {
-                super(read, buffers, offset, length, block,
-                        timeout, unit, attachment, check, handler, semaphore, completion);
+                super(read, buffers, offset, length, block, timeout, unit, attachment, check, handler, semaphore,
+                        completion);
             }
 
             @Override
@@ -1677,7 +1714,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                                     }
                                 }
                                 if (doWrite) {
-                                    long n = 0;
+                                    long n;
                                     do {
                                         n = getSocket().write(buffers, offset, length);
                                         if (n == -1) {
@@ -1725,8 +1762,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
     // ---------------------------------------------- SocketProcessor Inner Class
 
     /**
-     * This class is the equivalent of the Worker, but will simply use in an
-     * external Executor thread pool.
+     * This class is the equivalent of the Worker, but will simply use in an external Executor thread pool.
      */
     protected class SocketProcessor extends SocketProcessorBase<NioChannel> {
 
@@ -1737,12 +1773,10 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
         @Override
         protected void doRun() {
             /*
-             * Do not cache and re-use the value of socketWrapper.getSocket() in
-             * this method. If the socket closes the value will be updated to
-             * CLOSED_NIO_CHANNEL and the previous value potentially re-used for
-             * a new connection. That can result in a stale cached value which
-             * in turn can result in unintentionally closing currently active
-             * connections.
+             * Do not cache and re-use the value of socketWrapper.getSocket() in this method. If the socket closes the
+             * value will be updated to CLOSED_NIO_CHANNEL and the previous value potentially re-used for a new
+             * connection. That can result in a stale cached value which in turn can result in unintentionally closing
+             * currently active connections.
              */
             Poller poller = NioEndpoint.this.poller;
             if (poller == null) {
@@ -1751,7 +1785,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             }
 
             try {
-                int handshake = -1;
+                int handshake;
                 try {
                     if (socketWrapper.getSocket().isHandshakeComplete()) {
                         // No TLS handshaking required. Let the handler
@@ -1763,7 +1797,8 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                         // if the handshake failed.
                         handshake = -1;
                     } else {
-                        handshake = socketWrapper.getSocket().handshake(event == SocketEvent.OPEN_READ, event == SocketEvent.OPEN_WRITE);
+                        handshake = socketWrapper.getSocket().handshake(event == SocketEvent.OPEN_READ,
+                                event == SocketEvent.OPEN_WRITE);
                         // The handshake process reads/writes from/to the
                         // socket. status may therefore be OPEN_WRITE once
                         // the handshake completes. However, the handshake
@@ -1776,14 +1811,14 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                 } catch (IOException x) {
                     handshake = -1;
                     if (logHandshake.isDebugEnabled()) {
-                        logHandshake.debug(sm.getString("endpoint.err.handshake",
-                                socketWrapper.getRemoteAddr(), Integer.toString(socketWrapper.getRemotePort())), x);
+                        logHandshake.debug(sm.getString("endpoint.err.handshake", socketWrapper.getRemoteAddr(),
+                                Integer.toString(socketWrapper.getRemotePort())), x);
                     }
                 } catch (CancelledKeyException ckx) {
                     handshake = -1;
                 }
                 if (handshake == 0) {
-                    SocketState state = SocketState.OPEN;
+                    SocketState state;
                     // Process the request from this socket
                     if (event == null) {
                         state = getHandler().process(socketWrapper, SocketEvent.OPEN_READ);
@@ -1793,12 +1828,12 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
                     if (state == SocketState.CLOSED) {
                         poller.cancelledKey(getSelectionKey(), socketWrapper);
                     }
-                } else if (handshake == -1 ) {
+                } else if (handshake == -1) {
                     getHandler().process(socketWrapper, SocketEvent.CONNECT_FAIL);
                     poller.cancelledKey(getSelectionKey(), socketWrapper);
-                } else if (handshake == SelectionKey.OP_READ){
+                } else if (handshake == SelectionKey.OP_READ) {
                     socketWrapper.registerReadInterest();
-                } else if (handshake == SelectionKey.OP_WRITE){
+                } else if (handshake == SelectionKey.OP_WRITE) {
                     socketWrapper.registerWriteInterest();
                 }
             } catch (CancelledKeyException cx) {
@@ -1811,7 +1846,7 @@ public class NioEndpoint extends AbstractJsseEndpoint<NioChannel,SocketChannel>
             } finally {
                 socketWrapper = null;
                 event = null;
-                //return to cache
+                // return to cache
                 if (running && processorCache != null) {
                     processorCache.push(this);
                 }
