@@ -36,14 +36,10 @@ import org.apache.tomcat.util.net.openssl.ciphers.Cipher;
 import org.apache.tomcat.util.res.StringManager;
 
 /**
- * JSSESupport.
- *
- * Concrete implementation class for JSSE Support classes.
+ * JSSESupport. Concrete implementation class for JSSE Support classes.
  *
  * @author EKR
- * @author Craig R. McClanahan
- * Parts cribbed from JSSECertCompat
- * Parts cribbed from CertificatesValve
+ * @author Craig R. McClanahan Parts cribbed from JSSECertCompat Parts cribbed from CertificatesValve
  */
 public class JSSESupport implements SSLSupport, SSLSessionManager {
 
@@ -62,22 +58,20 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
     /*
-     * NO-OP method provided to make it easy for other classes in this package
-     * to trigger the loading of this class and the population of the
-     * keySizeCache.
+     * NO-OP method provided to make it easy for other classes in this package to trigger the loading of this class and
+     * the population of the keySizeCache.
      */
     static void init() {
         // NO-OP
     }
 
     private SSLSession session;
-    private Map<String,List<String>> additionalAttributes;
+    private final Map<String,List<String>> additionalAttributes;
 
     /**
      * @param session SSLSession from which information is to be extracted
      *
-     * @deprecated This will be removed in Tomcat 10.1.x onwards
-     *             Use {@link JSSESupport#JSSESupport(SSLSession, Map)}
+     * @deprecated This will be removed in Tomcat 10.1.x onwards Use {@link JSSESupport#JSSESupport(SSLSession, Map)}
      */
     @Deprecated
     public JSSESupport(SSLSession session) {
@@ -113,10 +107,10 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
             return null;
         }
 
-        Certificate [] certs=null;
+        Certificate[] certs;
         try {
             certs = session.getPeerCertificates();
-        } catch( Throwable t ) {
+        } catch (Throwable t) {
             log.debug(sm.getString("jsseSupport.clientCertError"), t);
             return null;
         }
@@ -126,31 +120,31 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
 
 
     private static X509Certificate[] convertCertificates(Certificate[] certs) {
-        if( certs==null ) {
+        if (certs == null) {
             return null;
         }
 
-        X509Certificate [] x509Certs = new X509Certificate[certs.length];
-        for(int i=0; i < certs.length; i++) {
-            if (certs[i] instanceof X509Certificate ) {
+        X509Certificate[] x509Certs = new X509Certificate[certs.length];
+        for (int i = 0; i < certs.length; i++) {
+            if (certs[i] instanceof X509Certificate) {
                 // always currently true with the JSSE 1.1.x
                 x509Certs[i] = (X509Certificate) certs[i];
             } else {
                 try {
-                    byte [] buffer = certs[i].getEncoded();
+                    byte[] buffer = certs[i].getEncoded();
                     CertificateFactory cf = CertificateFactory.getInstance("X.509");
                     ByteArrayInputStream stream = new ByteArrayInputStream(buffer);
                     x509Certs[i] = (X509Certificate) cf.generateCertificate(stream);
-                } catch(Exception ex) {
+                } catch (Exception ex) {
                     log.info(sm.getString("jsseSupport.certTranslationError", certs[i]), ex);
                     return null;
                 }
             }
-            if(log.isTraceEnabled()) {
+            if (log.isTraceEnabled()) {
                 log.trace("Cert #" + i + " = " + x509Certs[i]);
             }
         }
-        if(x509Certs.length < 1) {
+        if (x509Certs.length < 1) {
             return null;
         }
         return x509Certs;
@@ -173,18 +167,17 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     }
 
     @Override
-    public String getSessionId()
-        throws IOException {
+    public String getSessionId() throws IOException {
         // Look up the current SSLSession
         if (session == null) {
             return null;
         }
         // Expose ssl_session (getId)
-        byte [] ssl_session = session.getId();
-        if ( ssl_session == null) {
+        byte[] ssl_session = session.getId();
+        if (ssl_session == null || ssl_session.length == 0) {
             return null;
         }
-        StringBuilder buf=new StringBuilder();
+        StringBuilder buf = new StringBuilder();
         for (byte b : ssl_session) {
             String digit = Integer.toHexString(b);
             if (digit.length() < 2) {
@@ -215,9 +208,9 @@ public class JSSESupport implements SSLSupport, SSLSessionManager {
     @Override
     public String getProtocol() throws IOException {
         if (session == null) {
-           return null;
+            return null;
         }
-       return session.getProtocol();
+        return session.getProtocol();
     }
 
     @Override
