@@ -72,7 +72,7 @@ public class WsSession implements Session {
 
     private static final boolean SEC_CONFIGURATOR_USES_IMPL_DEFAULT;
 
-    private static AtomicLong ids = new AtomicLong(0);
+    private static final AtomicLong ids = new AtomicLong(0);
 
     static {
         // Use fake end point and path. They are never used, they just need to
@@ -107,14 +107,14 @@ public class WsSession implements Session {
     // Expected to handle message types of <ByteBuffer> only
     private volatile MessageHandler binaryMessageHandler = null;
     private volatile MessageHandler.Whole<PongMessage> pongMessageHandler = null;
-    private AtomicReference<State> state = new AtomicReference<>(State.OPEN);
+    private final AtomicReference<State> state = new AtomicReference<>(State.OPEN);
     private final Map<String, Object> userProperties = new ConcurrentHashMap<>();
     private volatile int maxBinaryMessageBufferSize = Constants.DEFAULT_BUFFER_SIZE;
     private volatile int maxTextMessageBufferSize = Constants.DEFAULT_BUFFER_SIZE;
     private volatile long maxIdleTimeout = 0;
     private volatile long lastActiveRead = System.currentTimeMillis();
     private volatile long lastActiveWrite = System.currentTimeMillis();
-    private Map<FutureToSendHandler, FutureToSendHandler> futures = new ConcurrentHashMap<>();
+    private final Map<FutureToSendHandler, FutureToSendHandler> futures = new ConcurrentHashMap<>();
     private volatile Long sessionCloseTimeoutExpiry;
 
 
@@ -279,11 +279,8 @@ public class WsSession implements Session {
         if (configurator.getClass().equals(DefaultServerEndpointConfigurator.class)) {
             return true;
         }
-        if (SEC_CONFIGURATOR_USES_IMPL_DEFAULT &&
-                configurator.getClass().equals(ServerEndpointConfig.Configurator.class)) {
-            return true;
-        }
-        return false;
+        return SEC_CONFIGURATOR_USES_IMPL_DEFAULT &&
+            configurator.getClass().equals(Configurator.class);
     }
 
 
@@ -730,8 +727,8 @@ public class WsSession implements Session {
             closeConnection();
         } else if (state.compareAndSet(State.OUTPUT_CLOSING, State.CLOSING)) {
             /*
-             * The local endpoint sent a close message the the same time as the remote endpoint. The local close is
-             * still being processed. Update the state so the the local close process will also close the network
+             * The local endpoint sent a close message at the same time as the remote endpoint. The local close is
+             * still being processed. Update the state so the local close process will also close the network
              * connection once it has finished sending a close message.
              */
         } else if (state.compareAndSet(State.OUTPUT_CLOSED, State.CLOSED)) {
@@ -864,7 +861,7 @@ public class WsSession implements Session {
         }
 
         String reason = closeReason.getReasonPhrase();
-        if (reason != null && reason.length() > 0) {
+        if (reason != null && !reason.isEmpty()) {
             appendCloseReasonWithTruncation(msg, reason);
         }
         msg.flip();
@@ -884,7 +881,7 @@ public class WsSession implements Session {
             closeConnection();
             // Failure to send a close message is not unexpected in the case of
             // an abnormal closure (usually triggered by a failure to read/write
-            // from/to the client. In this case do not trigger the endpoint's
+            // from/to the client). In this case do not trigger the endpoint's
             // error handling
             if (closeCode != CloseCodes.CLOSED_ABNORMALLY) {
                 localEndpoint.onError(this, e);
@@ -913,7 +910,7 @@ public class WsSession implements Session {
         // Once the close code has been added there are a maximum of 123 bytes
         // left for the reason phrase. If it is truncated then care needs to be
         // taken to ensure the bytes are not truncated in the middle of a
-        // multi-byte UTF-8 character.
+        // multibyte UTF-8 character.
         byte[] reasonBytes = reason.getBytes(StandardCharsets.UTF_8);
 
         if (reasonBytes.length <= 123) {
@@ -941,11 +938,11 @@ public class WsSession implements Session {
      *
      * @param f2sh The handler
      */
-    protected void registerFuture(FutureToSendHandler f2sh) {
+    void registerFuture(FutureToSendHandler f2sh) {
         // Ideally, this code should sync on stateLock so that the correct
         // action is taken based on the current state of the connection.
         // However, a sync on stateLock can't be used here as it will create the
-        // possibility of a dead-lock. See BZ 61183.
+        // possibility of a deadlock. See BZ 61183.
         // Therefore, a slightly less efficient approach is used.
 
         // Always register the future.
@@ -992,7 +989,7 @@ public class WsSession implements Session {
      *
      * @param f2sh The handler
      */
-    protected void unregisterFuture(FutureToSendHandler f2sh) {
+    void unregisterFuture(FutureToSendHandler f2sh) {
         futures.remove(f2sh);
     }
 
