@@ -155,11 +155,9 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
         if (configurator != null) {
             builder.configurator(configurator);
         }
-        ClientEndpointConfig config = builder.decoders(Arrays.asList(annotation.decoders()))
+        return builder.decoders(Arrays.asList(annotation.decoders()))
                 .encoders(Arrays.asList(annotation.encoders()))
                 .preferredSubprotocols(Arrays.asList(annotation.subprotocols())).build();
-
-        return config;
     }
 
 
@@ -357,7 +355,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
                         redirectLocation = path.resolve(redirectLocation);
                     }
 
-                    String redirectScheme = redirectLocation.getScheme().toLowerCase();
+                    String redirectScheme = redirectLocation.getScheme().toLowerCase(Locale.ENGLISH);
 
                     if (redirectScheme.startsWith("http")) {
                         redirectLocation = new URI(redirectScheme.replace("http", "ws"), redirectLocation.getUserInfo(),
@@ -388,7 +386,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
 
             // Sub-protocol
             List<String> protocolHeaders = handshakeResponse.getHeaders().get(Constants.WS_PROTOCOL_HEADER_NAME);
-            if (protocolHeaders == null || protocolHeaders.size() == 0) {
+            if (protocolHeaders == null || protocolHeaders.isEmpty()) {
                 subProtocol = null;
             } else if (protocolHeaders.size() == 1) {
                 subProtocol = protocolHeaders.get(0);
@@ -444,7 +442,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
         WsRemoteEndpointImplClient wsRemoteEndpointClient = new WsRemoteEndpointImplClient(channel);
 
         WsSession wsSession = new WsSession(clientEndpointHolder, wsRemoteEndpointClient, this, extensionsAgreed,
-                subProtocol, Collections.<String, String>emptyMap(), secure, clientEndpointConfiguration);
+                subProtocol, Collections.emptyMap(), secure, clientEndpointConfiguration);
 
         WsFrameClient wsFrameClient = new WsFrameClient(response, channel, wsSession, transformation);
         // WsFrame adds the necessary final transformations. Copy the
@@ -577,7 +575,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
             return;
         }
         synchronized (endPointSessionMapLock) {
-            if (endpointSessionMap.size() == 0) {
+            if (endpointSessionMap.isEmpty()) {
                 BackgroundProcessManager.getInstance().register(this);
             }
             endpointSessionMap.computeIfAbsent(key, k -> new HashSet<>()).add(wsSession);
@@ -592,11 +590,11 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
             Set<WsSession> wsSessions = endpointSessionMap.get(key);
             if (wsSessions != null) {
                 wsSessions.remove(wsSession);
-                if (wsSessions.size() == 0) {
+                if (wsSessions.isEmpty()) {
                     endpointSessionMap.remove(key);
                 }
             }
-            if (endpointSessionMap.size() == 0) {
+            if (endpointSessionMap.isEmpty()) {
                 BackgroundProcessManager.getInstance().unregister(this);
             }
         }
@@ -666,12 +664,12 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
         headers.put(Constants.WS_KEY_HEADER_NAME, wsKeyValues);
 
         // WebSocket sub-protocols
-        if (subProtocols != null && subProtocols.size() > 0) {
+        if (subProtocols != null && !subProtocols.isEmpty()) {
             headers.put(Constants.WS_PROTOCOL_HEADER_NAME, subProtocols);
         }
 
         // WebSocket extensions
-        if (extensions != null && extensions.size() > 0) {
+        if (extensions != null && !extensions.isEmpty()) {
             headers.put(Constants.WS_EXTENSIONS_HEADER_NAME, generateExtensionHeaders(extensions));
         }
 
@@ -688,7 +686,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
                 header.append(';');
                 header.append(param.getName());
                 String value = param.getValue();
-                if (value != null && value.length() > 0) {
+                if (value != null && !value.isEmpty()) {
                     header.append('=');
                     header.append(value);
                 }
@@ -854,7 +852,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
             log.warn(sm.getString("wsWebSocketContainer.invalidHeader", line));
             return;
         }
-        // Header names are case insensitive so always use lower case
+        // Header names are case-insensitive so always use lower case
         String headerName = line.substring(0, index).trim().toLowerCase(Locale.ENGLISH);
         // Multi-value headers are stored as a single header and the client is
         // expected to handle splitting into individual values
@@ -868,7 +866,7 @@ public class WsWebSocketContainer implements WebSocketContainer, BackgroundProce
         // All ISO-8859-1
         StringBuilder sb = new StringBuilder();
 
-        char c = 0;
+        char c;
         while (response.hasRemaining()) {
             c = (char) response.get();
             sb.append(c);
