@@ -23,11 +23,10 @@ import javax.websocket.server.ServerEndpointConfig;
 class WsMappingResult {
 
     private final ServerEndpointConfig config;
-    private final Map<String,String> pathParams;
+    private final Map<String, String> pathParams;
 
 
-    WsMappingResult(ServerEndpointConfig config,
-            Map<String,String> pathParams) {
+    WsMappingResult(ServerEndpointConfig config, Map<String, String> pathParams) {
         this.config = config;
         this.pathParams = pathParams;
     }
@@ -38,7 +37,7 @@ class WsMappingResult {
     }
 
 
-    Map<String,String> getPathParams() {
+    Map<String, String> getPathParams() {
         return pathParams;
     }
 }
