@@ -50,7 +50,7 @@ public class TestHttpServlet extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
+        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
 
         // Map the test Servlet
         LargeBodyServlet largeBodyServlet = new LargeBodyServlet();
@@ -64,8 +64,7 @@ public class TestHttpServlet extends TomcatBaseTest {
                resHeaders);
 
         Assert.assertEquals(HttpServletResponse.SC_OK, rc);
-        Assert.assertEquals(LargeBodyServlet.RESPONSE_LENGTH,
-                resHeaders.get("Content-Length").get(0));
+        Assert.assertEquals(LargeBodyServlet.RESPONSE_LENGTH, resHeaders.get("Content-Length").get(0));
     }
 
 
@@ -91,7 +90,7 @@ public class TestHttpServlet extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
+        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
 
         Bug57602ServletOuter outer = new Bug57602ServletOuter();
         Tomcat.addServlet(ctx, "Bug57602ServletOuter", outer);
@@ -163,7 +162,7 @@ public class TestHttpServlet extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
+        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
 
         Wrapper w = Tomcat.addServlet(ctx, "TestServlet", servlet);
         // Not all need/use this but it is simpler to set it for all
@@ -180,17 +179,27 @@ public class TestHttpServlet extends TomcatBaseTest {
         Assert.assertEquals(HttpServletResponse.SC_OK, rc);
         out.recycle();
 
-        Map<String,List<String>> headHeaders = new HashMap<>();
+        Map<String,List<String>> headHeaders = new CaseInsensitiveKeyMap<>();
         rc = headUrl(path, out, headHeaders);
         Assert.assertEquals(HttpServletResponse.SC_OK, rc);
 
+        // Date header is likely to be different so just remove it from both GET and HEAD.
+        getHeaders.remove("date");
+        headHeaders.remove("date");
+        /*
+         * There are some headers that are optional for HEAD. See RFC 9110, section 9.3.2. If present, they must be the
+         * same for both GET and HEAD. If not present in HEAD, remove them from GET.
+         */
+        for (String header : TesterConstants.OPTIONAL_HEADERS_WITH_HEAD) {
+            if (!headHeaders.containsKey(header)) {
+                getHeaders.remove(header);
+            }
+        }
+
         // Headers should be the same (apart from Date)
         Assert.assertEquals(getHeaders.size(), headHeaders.size());
         for (Map.Entry<String, List<String>> getHeader : getHeaders.entrySet()) {
             String headerName = getHeader.getKey();
-            if ("date".equalsIgnoreCase(headerName)) {
-                continue;
-            }
             Assert.assertTrue(headerName, headHeaders.containsKey(headerName));
             List<String> getValues = getHeader.getValue();
             List<String> headValues = headHeaders.get(headerName);
@@ -220,7 +229,7 @@ public class TestHttpServlet extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
+        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
 
         // Map the test Servlet
         Tomcat.addServlet(ctx, "servlet", servlet);
@@ -301,7 +310,7 @@ public class TestHttpServlet extends TomcatBaseTest {
         tomcat.getConnector().setAllowTrace(true);
 
         // No file system docBase required
-        StandardContext ctx = (StandardContext) tomcat.addContext("", null);
+        StandardContext ctx = (StandardContext) getProgrammaticRootContext();
 
         // Map the test Servlet
         Tomcat.addServlet(ctx, "servlet", new SimpleServlet());
@@ -355,7 +364,7 @@ public class TestHttpServlet extends TomcatBaseTest {
 
     private class Client extends SimpleHttpClient {
 
-        public Client(String request, boolean isHttp09) {
+        Client(String request, boolean isHttp09) {
             setRequest(new String[] {request});
             setUseHttp09(isHttp09);
         }
@@ -449,7 +458,7 @@ public class TestHttpServlet extends TomcatBaseTest {
 
         private final boolean useWriter;
 
-        public ResetBufferServlet(boolean useWriter) {
+        ResetBufferServlet(boolean useWriter) {
             this.useWriter = useWriter;
         }
 
@@ -480,7 +489,7 @@ public class TestHttpServlet extends TomcatBaseTest {
 
         private final boolean useWriter;
 
-        public ResetServlet(boolean useWriter) {
+        ResetServlet(boolean useWriter) {
             this.useWriter = useWriter;
         }
 
@@ -515,7 +524,7 @@ public class TestHttpServlet extends TomcatBaseTest {
 
         private final int bytesToWrite;
 
-        public NonBlockingWriteServlet(int bytesToWrite) {
+        NonBlockingWriteServlet(int bytesToWrite) {
             this.bytesToWrite = bytesToWrite;
         }
 
@@ -534,7 +543,7 @@ public class TestHttpServlet extends TomcatBaseTest {
             private final ServletOutputStream sos;
             private int bytesToWrite;
 
-            public NonBlockingWriteListener(AsyncContext ac, int bytesToWrite) throws IOException {
+            NonBlockingWriteListener(AsyncContext ac, int bytesToWrite) throws IOException {
                 this.ac = ac;
                 this.sos = ac.getResponse().getOutputStream();
                 this.bytesToWrite = bytesToWrite;
