@@ -66,6 +66,12 @@ public class TestJaspicCallbackHandlerInAuthenticator {
     }
 
 
+    /*
+     * This shouldn't happen in real usage. In the very unlikely event there is more than one CallerPrincipalCallback,
+     * it should return the same Principal each time.
+     *
+     * If there are multiple CallerPrincipalCallbacks, Tomcat uses the name from the most recent.
+     */
     @Test
     public void testCallerPrincipalCallback() throws Exception {
         CallbackHandler callbackHandler = createCallbackHandler(null);
@@ -80,30 +86,44 @@ public class TestJaspicCallbackHandlerInAuthenticator {
         });
         callbackHandler.handle(new Callback[] { cpc2 });
         Set<Object> credentials = clientSubject.getPrivateCredentials();
-        Assert.assertTrue(credentials.size() == 2);
-        Set<String> names = new HashSet<>(Arrays.asList(new String[] { "name1", "name2" }));
+        Assert.assertTrue(credentials.size() == 1);
+        Set<String> names = new HashSet<>(Arrays.asList(new String[] { "name2" }));
         for (Object o : credentials) {
             names.remove(((GenericPrincipal) o).getName());
         }
         Assert.assertTrue(names.isEmpty());
     }
 
+
+    /*
+     * This shouldn't happen in real usage. In the very unlikely event there is more than one GroupPrincipalCallback,
+     * the groups from each should be merged into the final Principal.
+     *
+     * If there are multiple CallerPrincipalCallbacks, Tomcat uses the name from the most recent.
+     */
     @Test
     public void testGroupPrincipalCallback() throws Exception {
         CallbackHandler callbackHandler = createCallbackHandler(null);
         Subject clientSubject = new Subject();
         CallerPrincipalCallback cpc = new CallerPrincipalCallback(clientSubject, "name");
-        GroupPrincipalCallback gpc = new GroupPrincipalCallback(clientSubject,
+        GroupPrincipalCallback gpc1 = new GroupPrincipalCallback(clientSubject,
                 new String[] { "group1", "group2" });
-        callbackHandler.handle(new Callback[] { cpc, gpc });
+        callbackHandler.handle(new Callback[] { cpc, gpc1 });
+        GroupPrincipalCallback gpc2 = new GroupPrincipalCallback(clientSubject,
+                new String[] { "group3", "group4" });
+        callbackHandler.handle(new Callback[] { cpc, gpc2 });
         Set<Object> credentials = clientSubject.getPrivateCredentials();
         Assert.assertTrue(credentials.size() == 1);
         GenericPrincipal gp = (GenericPrincipal) credentials.iterator().next();
         Assert.assertEquals("name", gp.getName());
+        Assert.assertEquals(4, gp.getRoles().length);
         Assert.assertTrue(gp.hasRole("group1"));
         Assert.assertTrue(gp.hasRole("group2"));
+        Assert.assertTrue(gp.hasRole("group3"));
+        Assert.assertTrue(gp.hasRole("group4"));
     }
 
+
     @Test
     public void testPasswordValidationCallback() throws Exception {
         CallbackHandler callbackHandler = createCallbackHandler(null);
