@@ -163,8 +163,13 @@ public class TestSendFile extends TomcatBaseTest {
         tomcat.start();
 
         ByteChunk bc = new ByteChunk();
-        getUrl("http://localhost:" + getPort() + "/test/?" + Globals.SENDFILE_SUPPORTED_ATTR
-                + "=true", bc, null);
+        try {
+            getUrl("http://localhost:" + getPort() + "/test/?" + Globals.SENDFILE_SUPPORTED_ATTR
+                    + "=true", bc, null);
+        } catch (IOException e) {
+            // Ignore possible IOE due to file delete on the server
+            System.out.println("Ignored: " + e.getMessage());
+        }
 
         CountDownLatch latch = new CountDownLatch(2);
         List<Throwable> throwables = new CopyOnWriteArrayList<>();
