@@ -17,9 +17,11 @@
 package org.apache.catalina.core;
 
 import java.io.IOException;
+import java.io.PrintWriter;
 import java.util.ArrayList;
 import java.util.List;
 
+import javax.servlet.RequestDispatcher;
 import javax.servlet.ServletException;
 import javax.servlet.ServletRequestEvent;
 import javax.servlet.ServletRequestListener;
@@ -39,13 +41,47 @@ import org.apache.tomcat.util.descriptor.web.ErrorPage;
 
 public class TestStandardHostValve extends TomcatBaseTest {
 
+    private static final String FAIL_NO_MESSAGE = "FAIL - NO MESSAGE";
+    private static final String EMPTY_NO_MESSAGE = "EMPTY - NO MESSAGE";
+
     @Test
-    public void testErrorPageHandling() throws Exception {
+    public void testErrorPageHandling400() throws Exception {
+        doTestErrorPageHandling(400, "", "/400");
+    }
+
+
+    @Test
+    public void testErrorPageHandling400WithException() throws Exception {
+        doTestErrorPageHandling(400, "java.lang.IllegalStateException", "/400");
+    }
+
+
+    @Test
+    public void testErrorPageHandling500() throws Exception {
+        doTestErrorPageHandling(500, "", "/500");
+    }
+
+
+    @Test
+    public void testErrorPageHandlingDefault() throws Exception {
+        doTestErrorPageHandling(501, "", "/default");
+    }
+
+
+    @Test
+    public void testErrorPageHandlingException() throws Exception {
+        doTestErrorPageHandling(0, IOException.class.getCanonicalName(), "/IOE");
+    }
+
+
+    private void doTestErrorPageHandling(int error, String exception, String report)
+            throws Exception {
+
         // Set up a container
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Add the error page
         Tomcat.addServlet(ctx, "error", new ErrorServlet());
@@ -55,12 +91,24 @@ public class TestStandardHostValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "report", new ReportServlet());
         ctx.addServletMappingDecoded("/report/*", "report");
 
+        // Add the handling for 400 responses
+        ErrorPage errorPage400 = new ErrorPage();
+        errorPage400.setErrorCode(Response.SC_BAD_REQUEST);
+        errorPage400.setLocation("/report/400");
+        ctx.addErrorPage(errorPage400);
+
         // And the handling for 500 responses
         ErrorPage errorPage500 = new ErrorPage();
         errorPage500.setErrorCode(Response.SC_INTERNAL_SERVER_ERROR);
         errorPage500.setLocation("/report/500");
         ctx.addErrorPage(errorPage500);
 
+        // And the handling for IOEs
+        ErrorPage errorPageIOE = new ErrorPage();
+        errorPageIOE.setExceptionType(IOException.class.getCanonicalName());
+        errorPageIOE.setLocation("/report/IOE");
+        ctx.addErrorPage(errorPageIOE);
+
         // And the default error handling
         ErrorPage errorPageDefault = new ErrorPage();
         errorPageDefault.setLocation("/report/default");
@@ -68,18 +116,30 @@ public class TestStandardHostValve extends TomcatBaseTest {
 
         tomcat.start();
 
-        doTestErrorPageHandling(500, "/500");
-        doTestErrorPageHandling(501, "/default");
+        // Request a page that triggers an error
+        ByteChunk bc = new ByteChunk();
+        int rc = getUrl("http://localhost:" + getPort() + "/error?errorCode=" + error + "&exception=" + exception,
+                bc, null);
+
+        if (error > 399) {
+            // Specific status code expected
+            Assert.assertEquals(error, rc);
+        } else {
+            // Default error status code expected
+            Assert.assertEquals(500, rc);
+        }
+        String[] responseLines = (bc.toString().split(System.lineSeparator()));
+        // First line should be the path
+        Assert.assertEquals(report, responseLines[0]);
+        // Second line should not be the null message warning
+        Assert.assertNotEquals(FAIL_NO_MESSAGE, responseLines[1]);
     }
 
 
     @Test(expected=IllegalArgumentException.class)
     public void testInvalidErrorPage() throws Exception {
-        // Set up a container
-        Tomcat tomcat = getTomcatInstance();
-
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Add a broken error page configuration
         ErrorPage errorPage500 = new ErrorPage();
@@ -95,7 +155,7 @@ public class TestStandardHostValve extends TomcatBaseTest {
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Add the error page
         Tomcat.addServlet(ctx, "error", new ErrorServlet());
@@ -131,26 +191,13 @@ public class TestStandardHostValve extends TomcatBaseTest {
     }
 
 
-    private void doTestErrorPageHandling(int error, String report)
-            throws Exception {
-
-        // Request a page that triggers an error
-        ByteChunk bc = new ByteChunk();
-        int rc = getUrl("http://localhost:" + getPort() +
-                "/error?errorCode=" + error, bc, null);
-
-        Assert.assertEquals(error, rc);
-        Assert.assertEquals(report, bc.toString());
-    }
-
-
     @Test
     public void testIncompleteResponse() throws Exception {
         // Set up a container
         Tomcat tomcat = getTomcatInstance();
 
         // No file system docBase required
-        Context ctx = tomcat.addContext("", null);
+        Context ctx = getProgrammaticRootContext();
 
         // Add the error page
         Tomcat.addServlet(ctx, "error", new ExceptionServlet());
@@ -160,13 +207,13 @@ public class TestStandardHostValve extends TomcatBaseTest {
         Tomcat.addServlet(ctx, "report", new ReportServlet());
         ctx.addServletMappingDecoded("/report/*", "report");
 
-        // And the handling for 500 responses
+        // Add the handling for 500 responses
         ErrorPage errorPage500 = new ErrorPage();
         errorPage500.setErrorCode(Response.SC_INTERNAL_SERVER_ERROR);
         errorPage500.setLocation("/report/500");
         ctx.addErrorPage(errorPage500);
 
-        // And the default error handling
+        // Add the default error handling
         ErrorPage errorPageDefault = new ErrorPage();
         errorPageDefault.setLocation("/report/default");
         ctx.addErrorPage(errorPageDefault);
@@ -194,7 +241,29 @@ public class TestStandardHostValve extends TomcatBaseTest {
         protected void doGet(HttpServletRequest req, HttpServletResponse resp)
                 throws ServletException, IOException {
             int error = Integer.parseInt(req.getParameter("errorCode"));
-            resp.sendError(error);
+            if (error > 399) {
+                resp.sendError(error);
+            }
+
+            Throwable t = null;
+            String exception = req.getParameter("exception");
+            if (exception != null && exception.length() > 0) {
+                try {
+                    t = (Throwable) Class.forName(exception).getConstructor().newInstance();
+                } catch (ReflectiveOperationException e) {
+                    // Should never happen but in case it does...
+                    t = new IllegalArgumentException();
+                }
+                if (error < 400) {
+                    if (t instanceof RuntimeException) {
+                        throw (RuntimeException) t;
+                    } else if (t instanceof IOException) {
+                        throw (IOException) t;
+                    } else if (t instanceof ServletException) {
+                        throw (ServletException) t;
+                    }
+                }
+            }
         }
     }
 
@@ -221,7 +290,16 @@ public class TestStandardHostValve extends TomcatBaseTest {
                 throws ServletException, IOException {
             String pathInfo = req.getPathInfo();
             resp.setContentType("text/plain");
-            resp.getWriter().print(pathInfo);
+            PrintWriter pw = resp.getWriter();
+            pw.println(pathInfo);
+
+            String message = (String) req.getAttribute(RequestDispatcher.ERROR_MESSAGE);
+            if (message == null) {
+                message = FAIL_NO_MESSAGE;
+            } else if (message.length() == 0) {
+                message = EMPTY_NO_MESSAGE;
+            }
+            pw.println(message);
         }
     }
 }
