@@ -19,6 +19,7 @@ package org.apache.catalina.filters;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
+import java.lang.reflect.InvocationTargetException;
 import java.security.Principal;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -48,8 +49,8 @@ import javax.servlet.http.PushBuilder;
 
 public class TesterHttpServletRequest implements HttpServletRequest {
 
-    private Map<String, Object> attributes = new HashMap<>();
-    private Map<String, List<String>> headers = new HashMap<>();
+    private final Map<String, Object> attributes = new HashMap<>();
+    private final Map<String, List<String>> headers = new HashMap<>();
     private String method;
     private String scheme;
     private String serverName;
@@ -72,8 +73,8 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public void setCharacterEncoding(String env)
-            throws UnsupportedEncodingException {
+    public void setCharacterEncoding(String env) throws UnsupportedEncodingException {
+        throw new RuntimeException("Not implemented");
     }
 
     @Override
@@ -110,9 +111,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return an empty Hashmap.
+     */
     @Override
-    public Map<String,String[]> getParameterMap() {
-        throw new RuntimeException("Not implemented");
+    public Map<String, String[]> getParameterMap() {
+        return new HashMap<>();
     }
 
     @Override
@@ -183,9 +189,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return false.
+     */
     @Override
     public boolean isSecure() {
-        throw new RuntimeException("Not implemented");
+        return false;
     }
 
     @Override
@@ -251,7 +262,7 @@ public class TesterHttpServletRequest implements HttpServletRequest {
 
     @Override
     public Enumeration<String> getHeaders(String name) {
-        throw new RuntimeException("Not implemented");
+        return Collections.enumeration(headers.get(name));
     }
 
     @Override
@@ -293,9 +304,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return null.
+     */
     @Override
     public String getQueryString() {
-        throw new RuntimeException("Not implemented");
+        return null;
     }
 
     @Override
@@ -308,9 +324,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return null.
+     */
     @Override
     public Principal getUserPrincipal() {
-        throw new RuntimeException("Not implemented");
+        return null;
     }
 
     @Override
@@ -318,9 +339,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return null.
+     */
     @Override
     public String getRequestURI() {
-        throw new RuntimeException("Not implemented");
+        return null;
     }
 
     @Override
@@ -333,9 +359,14 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return null.
+     */
     @Override
     public HttpSession getSession(boolean create) {
-        throw new RuntimeException("Not implemented");
+        return null;
     }
 
     @Override
@@ -379,8 +410,8 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public AsyncContext startAsync(ServletRequest servletRequest,
-            ServletResponse servletResponse) throws IllegalStateException {
+    public AsyncContext startAsync(ServletRequest servletRequest, ServletResponse servletResponse)
+            throws IllegalStateException {
         throw new RuntimeException("Not implemented");
     }
 
@@ -410,14 +441,12 @@ public class TesterHttpServletRequest implements HttpServletRequest {
     }
 
     @Override
-    public boolean authenticate(HttpServletResponse response)
-            throws IOException, ServletException {
+    public boolean authenticate(HttpServletResponse response) throws IOException, ServletException {
         throw new RuntimeException("Not implemented");
     }
 
     @Override
-    public void login(String username, String password)
-            throws ServletException {
+    public void login(String username, String password) throws ServletException {
         throw new RuntimeException("Not implemented");
     }
 
@@ -436,10 +465,19 @@ public class TesterHttpServletRequest implements HttpServletRequest {
         throw new RuntimeException("Not implemented");
     }
 
+    /**
+     * {@inheritDoc}
+     * <p>
+     * This test implementation is hard coded to return a new instance of the httpUpgradeHandlerClass.
+     */
     @Override
-    public <T extends HttpUpgradeHandler> T upgrade(
-            Class<T> httpUpgradeHandlerClass) throws IOException, ServletException {
-        throw new RuntimeException("Not implemented");
+    public <T extends HttpUpgradeHandler> T upgrade(Class<T> httpUpgradeHandlerClass)
+        throws IOException, ServletException {
+        try {
+            return httpUpgradeHandlerClass.getDeclaredConstructor().newInstance();
+        } catch (NoSuchMethodException | InvocationTargetException | InstantiationException | IllegalAccessException ignore) {
+        }
+        return null;
     }
 
     @Override
