@@ -125,7 +125,7 @@ public class TestRequestFilterValve {
                 if (usePeerAddress) {
                     request.setRemoteAddr(ADDR_OTHER);
                     request.getCoyoteRequest().peerAddr().setString(property);
-                    ((RemoteAddrValve) valve).setUsePeerAddress(true);
+                    valve.setUsePeerAddress(true);
                     msg.append(" peer='" + property + "'");
                 } else {
                     request.setRemoteAddr(property);
@@ -141,7 +141,7 @@ public class TestRequestFilterValve {
                 if (usePeerAddress) {
                     request.setRemoteAddr(ADDR_OTHER);
                     request.getCoyoteRequest().peerAddr().setString(property);
-                    ((RemoteCIDRValve) valve).setUsePeerAddress(true);
+                    valve.setUsePeerAddress(true);
                     msg.append(" peer='" + property + "'");
                 } else {
                     request.setRemoteAddr(property);
@@ -170,11 +170,11 @@ public class TestRequestFilterValve {
         }
         if (addConnectorPort) {
             if (valve instanceof RemoteAddrValve) {
-                ((RemoteAddrValve) valve).setAddConnectorPort(true);
+                valve.setAddConnectorPort(true);
             } else if (valve instanceof RemoteHostValve) {
-                ((RemoteHostValve) valve).setAddConnectorPort(true);
+                valve.setAddConnectorPort(true);
             } else if (valve instanceof RemoteCIDRValve) {
-                ((RemoteCIDRValve) valve).setAddConnectorPort(true);
+                valve.setAddConnectorPort(true);
             } else {
                 Assert.fail("Can only set 'addConnectorPort' for RemoteAddrValve, RemoteHostValve and RemoteCIDRValve");
             }
