@@ -66,6 +66,7 @@ import org.apache.tomcat.util.descriptor.web.SecurityConstraint;
 import org.apache.tomcat.util.net.SSLHostConfigCertificate.Type;
 import org.apache.tomcat.util.net.jsse.JSSEImplementation;
 import org.apache.tomcat.util.net.openssl.OpenSSLImplementation;
+import org.apache.tomcat.util.net.openssl.OpenSSLStatus;
 
 public final class TesterSupport {
 
@@ -245,6 +246,11 @@ public final class TesterSupport {
         return true;
     }
 
+    public static boolean isOpenSSLVariant(String sslImplementationName, OpenSSLStatus.Name name) {
+        return "org.apache.tomcat.util.net.openssl.panama.OpenSSLImplementation".equals(sslImplementationName)
+                && name.equals(OpenSSLStatus.getName());
+    }
+
     public static void configureClientCertContext(Tomcat tomcat) {
         initSsl(tomcat);
 
